%% parameters governing spike detection
ops.spkDetectSignal = 'SNLE'; % signal used to detect spikes
ops.relSpkThr = 6;           % threshold for detecting spikes by NLE or voltage, in units of signal standard deviation
ops.deadTime = 0.5;           % min interval bewtween spikes, in ms

%% waveform alignment parameters
ops.alignWin = [-0.25 0.25];  % window around detection peak to search for dominant voltage peak to align to, in ms. alignWin = [] --> no alignment (NOT recommended)
ops.maxShift = 0.22;          % max spk time shift that can be applied during alignment, in ms
ops.derivWindow = 0.07;       % window for calulating slope near voltage peaks, in ms (used for alignment)
ops.slopeWt = 0.5;            % weight given to pre-peak slope when identifying dominant peak
ops.polarity = 0;        % type of voltage peak to align to (1 = positive, -1 = negative; 0 means no preference)

%% properties of spike waveforms used in clustering
ops.waveLength = 1.2;         % length of spk waves, in ms
ops.peakLoc = 0.5;            % time of spk peak within spk wave, in ms
ops.wavePad = 0.4;            % "pad" or buffer around spk wave that can be used for post-clustering realignment, in ms
ops.upsample = 1;             % factor by which data are upsampled (with sinc interpolation) prior to clustering
ops.highCut = 9000;           % amplifier hig freq cutoff (Hz), only used in sinc interpolation (ignore if upsample = 1)
ops.sincLength = 12;          % length of sinc function for interpolation (ignore if upsample = 1)

%% noise thresholds (a wire is "noisy" if any of these thresholds is crossed)
% note: noise detection operates only within alignWin
ops.noisePeak = 100;          % peak amplitude threshold for noise (whitened data, so units are standard deviations)
ops.noiseMean = 40;           % average amplitude threshold for noise (whitened data)
ops.noiseMaxD = 2;            % first derivative threhsold for noise (whitened data, units: SD/ms)
ops.noiseWireCount = 2;       % minimum # wires classified as "noisy" to trigger event rejection

%% misc parameters
ops.verbose = true;           % determines whether clustering progress is reported during execution
ops.batchSize = 32768;        % size of data batches for processing, in samples
ops.batchesPerBlock = 48;     % number of batches to load at once (for parallel processing)
ops.spkRange = [-0.25 0.5];   % for removing spikes for calculation of whitening filter, in ms relative to spk time
ops.pcaWin = [-0.3 0.4];      % window around spike time for data used to caluclate clustering principal components 
ops.numFeatures = 10;         % number of PCA dimensions used in clustering