function ExportToPlx(spkDat, plxFile)

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
pts = (1:wL) + wP;
Fs = spkDat.Fs * spkDat.upsample;
spkDat.waves = spkDat.waves(pts,:,:);

% delete any repeated timestamps
[~, ia] = unique(spkDat.ts);
repeatTs = unique(spkDat.ts(setdiff(1:length(spkDat.ts), ia)));
delIdx = [];
for i = 1:length(repeatTs)
    loc = find(spkDat.ts == repeatTs(i));
    delIdx = [delIdx loc(spkDat.id(loc) == 0)];
    loc(spkDat.id(loc) == 0) = [];
    if length(loc) > 1
        delIdx = [delIdx loc(2:end)];
    end
end
spkDat.ts(delIdx) = [];
spkDat.id(delIdx) = [];
spkDat.waves(:,:,delIdx) = [];
spkDat.ts = spkDat.ts * spkDat.upsample;

%% Make plxInfo, chInfo
plxInfo.comment = '';
plxInfo.ADFs = Fs;
plxInfo.numWires = nChan;
plxInfo.numEvents = 0;
plxInfo.numSlows =0;
plxInfo.waveLength = wL;   %
plxInfo.peakLoc = pk;  %
plxInfo.year       = 1;
plxInfo.month      = 1;
plxInfo.day        = 1;
plxInfo.hour       = 1;
plxInfo.minute     = 1;
plxInfo.second     = 1;
plxInfo.waveFs = Fs;
plxInfo.dataLength= spkDat.ts(end) + wL;
plxInfo.Trodalness =nChan;
plxInfo.dataTrodalness=1;
plxInfo.bitsPerSpikeSample=16;
plxInfo.bitsPerSlowSample=16;
plxInfo.SpikeMaxMagnitudeMV=10000;
plxInfo.SlowMaxMagnitudeMV=10000;
plxInfo.SpikePreAmpGain=1;
plxInfo.pad = zeros(46,1);
plxInfo.TSCounts= zeros(650,1);
plxInfo.WFCounts= zeros(650,1);
plxInfo.EVCounts= zeros(512,1);
for i=1:4
    chInfo(i).wireName='goo';
    chInfo(i).tetName=['Tetrode ',num2str(i)];
    chInfo(i).wireNum= i;
    chInfo(i).WFRate= Fs;
    chInfo(i).SIG=1;
    chInfo(i).refWire=0;
    chInfo(i).gain=2000;
    chInfo(i).filter=0;
    chInfo(i).thresh=50;
    chInfo(i).sortWidth=wL;
    chInfo(i).comment= 'Hello';
    chInfo(i).numUnits = length(unique(spkDat.id)); % this will count the unsorted (id = 0) as a unit!
end

%% Write to plx file
fid=fopen(plxFile, 'w');

% make sure the comment is 128 characters long
if length(plxInfo.comment) > 128
    plxInfo.comment = plxInfo.comment(1:128);
else
    numBlanks = 128 - length(plxInfo.comment);
    plxInfo.comment = [plxInfo.comment, blanks(numBlanks)];
end

fwrite(fid, 1480936528, 'int32', 0, 'l');         % magic number at start of .plx file; this is what was in Alex's .plx files
fwrite(fid, 105, 'int32', 0, 'l');                % version number
fwrite(fid, plxInfo.comment, 'char', 0, 'l');     % comment
fwrite(fid, plxInfo.ADFs, 'int32', 0, 'l');       % sampling rate of AD converter; used to get timestamps(seconds) = timestamps(clock ticks) / ADFs
fwrite(fid, plxInfo.numWires, 'int32', 0, 'l');   % number of wires (1, 2, or 4 for single wires, stereotrodes, or tetrodes respectively)
fwrite(fid, plxInfo.numEvents, 'int32', 0, 'l');  % number of event channels
fwrite(fid, plxInfo.numSlows, 'int32', 0, 'l');   % number of slow channels (I'm not sure what this entry or the previous one are actually for - both are zero in Alex's code)
fwrite(fid, plxInfo.waveLength, 'int32', 0, 'l'); % number of points per waveform
fwrite(fid, plxInfo.peakLoc, 'int32', 0, 'l');    % points before waveform peak

fwrite(fid, plxInfo.year, 'int32', 0, 'l');       % date (year, month, day, hour, minute)
fwrite(fid, plxInfo.month, 'int32', 0, 'l');
fwrite(fid, plxInfo.day, 'int32', 0, 'l');
fwrite(fid, plxInfo.hour, 'int32', 0, 'l'); 
fwrite(fid, plxInfo.minute, 'int32', 0, 'l');
fwrite(fid, plxInfo.second, 'int32', 0, 'l');

fwrite(fid, 0, 'int32', 0, 'l');                  % fast read (not sure what this is)
fwrite(fid, plxInfo.waveFs, 'int32', 0, 'l');     % sampling rate of the waveform (may be different from ADFs)
fwrite(fid, plxInfo.dataLength, 'double', 0, 'l'); % last timestamp in clock ticks. Length in seconds = dataLength / ADFs

% fwrite(fid, plxInfo.next4fields, 'char*1', 0, 'l');
fwrite(fid, plxInfo.Trodalness, 'uint8', 0, 'l'); % 1 for single wires, 2 for stereotrodes, 4 for tetrodes
fwrite(fid, plxInfo.dataTrodalness, 'uint8', 0, 'l'); % not exactly sure how this differs from Trodalness above
fwrite(fid, plxInfo.bitsPerSpikeSample, 'uint8', 0, 'l');  % ADC resolution for spike waveforms in bits
fwrite(fid, plxInfo.bitsPerSlowSample, 'uint8', 0, 'l');   % ADC resolution for slow-channel data in bits

fwrite(fid, plxInfo.SpikeMaxMagnitudeMV, 'uint16', 0, 'l'); % zero-to-peak voltage in mV for the spike waveform
fwrite(fid, plxInfo.SlowMaxMagnitudeMV, 'uint16', 0, 'l');  % zero-to-peak voltage in mV for the slow-channel adc values
fwrite(fid, plxInfo.SpikePreAmpGain, 'uint16', 0, 'l');     % pre-amp gain; 1 for standard Berke lab rigs

fwrite(fid, zeros(1, 46), 'uint8', 0, 'l');    % pad 46 bytes

TSCounts=zeros(1, 650);WFCounts=zeros(1, 650);
for clust=1:4
    for wire=1:nChan
        TSCounts((4+(wire-1)*4+clust))=sum(spkDat.id==clust);
        WFCounts((4+(wire-1)*4+clust))=sum(spkDat.id==clust);
    end
end

fwrite(fid, int32(TSCounts), 'int32', 0, 'l');  % TSCounts (130x5 array that we're not using)
fwrite(fid, int32(WFCounts), 'int32', 0, 'l');  % WFCounts (130x5 array that we're not using)
fwrite(fid, zeros(1, 512), 'int32', 0, 'l');  % EVCounts (512 element vector that we're not using)

for wire=1:plxInfo.numWires
    writePLXChanHeader( fid, chInfo(wire) );
end
h = waitbar(0,'Please wait...');
numSpikes = length(spkDat.ts);
numWires  = nChan;    
for iSpike = 1 : numSpikes
    for iWire = 1 : numWires
   
        fwrite(fid, 1,'int16', 0, 'l');    % not sure why these constants are written, but it worked in Alex's python code
        fwrite(fid, 0,'int16', 0, 'l');
        fwrite(fid, spkDat.ts(iSpike),'uint32', 0, 'l');    % write the timestamp
        fwrite(fid, iWire, 'int16', 0, 'l');        
        fwrite(fid, spkDat.id(iSpike), 'int16', 0, 'l');
        fwrite(fid, 1, 'int16', 0, 'l');
        fwrite(fid, wL, 'int16', 0, 'l');
        fwrite(fid, squeeze(spkDat.waves(:, iWire, iSpike)), 'int16', 0, 'l');
        
    end
    if ~rem(iSpike,10000)
        waitbar(iSpike / numSpikes,h, ['Saving Data...',num2str(floor(100*iSpike/numSpikes)),'%']);
    end
    
end

fclose(fid);

close(h);