function FilterLabChart(datFile, varargin)

% hard-coded parameters
bytesPerSample = 2;
wname = 'db4';      % specifies Daubechies(4) wavelet filter

% set default values for varargs
maxLevel = 6; % This sets the (high-pass) cutoff frequency for wavelet filtering.
              % cutoff frequency = Fs/(2^(maxLevel+1)) (Fs = sampling rate)
              % For a sampling rate of 30000/sec, maxLevel 6 gives a cutoff frequency of ~234 Hz
              
trodes = [];         % list of "trodes" (typically tetrodes) to be filtered
timeRange = [0 Inf]; % time range of recording (in seconds) to filter
blockDur = 10;       % size of data chunks (in sec) to be processed at a time
polarity = 1;       % flip the spikes upside down, if that's the way you like it
wavelet = true;      % for LFP only, make lfp = true and wavelet = false

pathParts = strsplit(datFile, filesep);
pathParts{end} = [pathParts{end}(1:end-4) '-filtered'];
saveDir = strjoin(pathParts, filesep);
pathParts = strsplit(datFile, filesep);
pathParts{end} = [pathParts{end}(1:end-4) '-LFP'];
lfpDir = strjoin(pathParts, filesep);
verbose = true;
lfp = true;
% lfpDir = [];
filtOrderLfp = 1000; % not used unless decimate uses 'fir' (commented out)
lfpFs = 500;
badChan = [];

for i = 1 : 2 : length(varargin)
    
    switch lower(varargin{i})
        case 'maxlevel'
            maxLevel = varargin{i+1};
        case 'trodes',
            trodes = varargin{i+1};
        case 'timerange',
            timeRange = varargin{i+1};
        case 'blockdur',
            blockDur = varargin{i+1};
        case 'polarity',
            polarity = varargin{i+1};
        case 'savedir'
            saveDir = varargin{i+1};
        case 'verbose'
            verbose = varargin{i+1};
        case 'lfp'
            lfp = varargin{i+1};
        case 'filtorderlfp'
            filtOrderLfp = varargin{i+1};
        case 'lfpfs'
            lfpFs = varargin{i+1};
        case 'lfpdir'
            lfpDir = varargin{i+1};
        case 'badchan'
            badChan = varargin{i+1};
        case 'wavelet'
            wavelet = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to FilterIntan')
    end
    
end

if ~exist(saveDir, 'dir') & wavelet
    mkdir(saveDir);
end

if isempty(lfpDir)
    lfpDir = saveDir;
end

if ~exist(lfpDir, 'dir') & lfp
    mkdir(lfpDir);
end

dat = readtable(datFile);

gainConvert = 1/3.12e-4;
Fs = 1/diff(dat.ChannelTitle_(1:2));
chanNames = dat.Properties.VariableNames;
chanNames = chanNames(2:6);
% dat = int16(gainConvert*dat{:,2:16});
dat = dat{:,2:6};

% create base hsdHeader
headerBase.comment = '';
headerBase.version = 4;
headerBase.sampling_rate = Fs;
headerBase.vScale = 0.312;
headerBase.bytesPerSample = bytesPerSample;
headerBase.dataOffset = 20480;

% generate trode list
% tet = cellfun(@(n) n(1)=='T', chanNames);
% stim = cellfun(@(n) n(1)=='S', chanNames);
% chanNames(tet) = cellfun(@(x) ['t' x(8:end)], chanNames(tet), 'UniformOutput', false);
% chanNames(stim) = cellfun(@(x) ['s' x(5) '_' x(6)], chanNames(stim), 'UniformOutput', false);
% trodeName = unique(cellfun(@(x) x(1:2), chanNames, 'UniformOutput', false));

% nTrodes =  length(trodeName);
% for i = 1:nTrodes
%    trode(i).name = trodeName{i};
%    trode(i).wires = find(cellfun(@(x) strcmp(x(1:2), trode(i).name), chanNames));
% end
nTrodes = 1;
trodeName = {'t1'};
trode.name = trodeName{1};
trode.wires = 1:5;

% LFP
if lfp
    
    r = round(Fs / lfpFs);
    
    for i = 1:nTrodes
        if exist([lfpDir filesep trode(i).name '.hsdf'], 'file')
            delete([lfpDir filesep trode(i).name '.hsdf']);
        end
        header = headerBase;
        header.num_channels = length(trode(i).wires);
        header.sampling_rate = Fs / r;
        for j = 1:header.num_channels
            header.channel(j).chip = [];
            header.channel(j).chip_channel = [];
            header.channel(j).impedance = [];
            header.channel(j).name = chanNames{trode(i).wires(j)};
            header.channel(j).low_cut = [];
            header.channel(j).high_cut = [];
        end
        
        % filter and downsample data for LFP
        chan1 = int16(gainConvert*decimate(dat(:,trode(i).wires(1))', r));
        lfpDat = zeros(length(trode(i).wires), length(chan1));
        lfpDat(1,:) = chan1;
        for j = 2:length(trode(i).wires)
            lfpDat(j,:) = int16(gainConvert*decimate(dat(:,trode(i).wires(j))', r));
        end
        
        % save LFP data
        writeHsdHeader_ver4([lfpDir filesep trode(i).name '.hsdf'], header);
        fOut = fopen([lfpDir filesep trode(i).name '.hsdf'], 'a');
        fwrite(fOut, lfpDat, 'int16');
        fclose(fOut)
        
    end
end

% wavelet (high-pass) filtering for spikes
if wavelet
    
    for i = 1:nTrodes
        if exist([saveDir filesep trode(i).name '.hsd'], 'file')
            delete([saveDir filesep trode(i).name '.hsd']);
        end
        header = headerBase;
        header.num_channels = length(trode(i).wires);
        for j = 1:header.num_channels
            header.channel(j).chip = [];
            header.channel(j).chip_channel = [];
            header.channel(j).impedance = [];
            header.channel(j).name = chanNames{trode(i).wires(j)};
            header.channel(j).low_cut = [];
            header.channel(j).high_cut = [];
        end
        
        % wavelet filter data
        [c,l] = wavedec(dat(:,trode(i).wires(1))', maxLevel, wname); % get wavelet decomposition
        c = wthcoef('a', c, l);                             % zero out approximation coefficients
        chan1 = int16(waverec(c, l, wname));             % reconstruct signal
        wvDat = zeros(length(trode(i).wires), length(chan1));
        wvDat(1,:) = chan1;
        for j = 2:length(trode(i).wires)
            [c,l] = wavedec(dat(:,trode(i).wires(j))', maxLevel, wname); % get wavelet decomposition
            c = wthcoef('a', c, l);                             % zero out approximation coefficients
            wvDat(j,:) = int16(waverec(c, l, wname));             % reconstruct signal
        end
    
        % apply common average referencing (will actually use median, not mean)
        wvDat = bsxfun(@minus, wvDat, median(wvDat, 1));
        
        % save data
        writeHsdHeader_ver4([saveDir filesep trode(i).name '.hsd'], header);
        fOut = fopen([saveDir filesep trode(i).name '.hsd'], 'a');
        fwrite(fOut, wvDat, 'int16');
        fclose(fOut)
    end
end
