function SpikeSort(datDir, varargin)

verbose = true;
saveDir = datDir;
preprocessRange = [0 600];
timeRange = [0 Inf];

lfp = true;
lowpass = -1;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'verbose'
            verbose = varargin{i+1};
        case 'savedir'
            saveDir = varargin{i+1};
        case 'preprocessrange'
            preprocessRange = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1};
        case 'lfp'
            lfp = varargin{i+1};
        case 'lowpass'
            lowpass = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to SpikeSort');
    end
end

% taskFile = dir([datDir filesep '*metadata.txt']);
% if length(taskFile) > 0
%     f = fopen([datDir filesep taskFile(1).name]);
%     metaData = textscan(f, 'folder: %s type: %s');
%     fclose(f);
%     folder = metaData{1,1};
%     task = metaData{1,2};
% end

fileDat = dir([datDir filesep 'IM*']);
idx = arrayfun(@(f) f.isdir, fileDat);
folder = arrayfun(@(f) f.name, fileDat(idx), 'UniformOutput', false);
folderInfo = cellfun(@(f) strsplit(f, {'-', '_'}), folder, 'UniformOutput', false);
task = cellfun(@(f) f{2}, folderInfo, 'UniformOutput', false);
time = cellfun(@(f) str2num(f{end}), folderInfo);
[~, iSort] = sort(time);
folder = folder(iSort);
task = task(iSort);
uTask = unique(task);
for k = 1:length(uTask)
    idx = find(strcmp(uTask{k}, task));
    if length(idx) > 1
        for i = 1:length(idx)
            task{idx(i)} = [task{idx(i)} '-' num2str(i)];
        end
    end
end

% 1) wavelet filter data and save filtered data from each trode in a separate file
filterDir = cell(1, length(folder));
if exist([saveDir filesep 'filtered']) ~= 7
    mkdir([saveDir filesep 'filtered']);
end
if lfp & exist([saveDir filesep 'LFP']) ~= 7
    mkdir([saveDir filesep 'LFP']);
end
for i = 1:length(folder)
    if verbose
        fprintf(['task/phase: ' task{i} '\n'])
    end
    filterDir{i} = [saveDir filesep 'filtered' filesep task{i}];
    lfpDir = [saveDir filesep 'LFP' filesep task{i}];
    taskDir = [datDir filesep folder{i}];
    FilterIntan(taskDir, 'saveDir', filterDir{i}, 'verbose', verbose, 'timeRange', timeRange, 'lfp', lfp, 'lfpDir', lfpDir);
end

% 2) detect and cluster spikes on all trodes in all tasks/phases of the recording session
sortDir = [saveDir filesep 'sorted-raw'];
if exist(sortDir) ~= 7
    mkdir(sortDir);
end
trodeList = dir([filterDir{1} filesep '*.hsd']);
trodeList = arrayfun(@(t) t.name, trodeList, 'UniformOutput', false);
ConfigSort
ops.verbose = verbose;
for k = 1:length(trodeList)
    trodeName = strsplit(trodeList{k}, '.');
    if verbose
        fprintf(['Beginning sort of ' trodeName{1}]) 
    end
    trodeFile = cellfun(@(f) [f filesep trodeList{k}], filterDir, 'UniformOutput', false);
    spkDat = ClusterSpikes(trodeFile, ops, 'preprocessRange', preprocessRange, 'timeRange', timeRange, 'fieldName', {'taskList'}, 'fieldDat', {task});
    trodeName = strsplit(trodeList{k}, '.');
    save([sortDir filesep trodeName{1} '.mat'], 'spkDat', 'trodeFile', '-v7.3')
    clear spkDat
end