function SpikeSortHsd(datDir, varargin)

verbose = true;
saveDir = datDir;
preprocessRange = [0 600];
timeRange = [0 Inf];

lfp = true;
lowpass = -1;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'verbose'
            verbose = varargin{i+1};
        case 'savedir'
            saveDir = varargin{i+1};
        case 'preprocessrange'
            preprocessRange = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1};
        case 'lfp'
            lfp = varargin{i+1};
        case 'lowpass'
            lowpass = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to SpikeSort');
    end
end

hsdFileDat = dir([datDir filesep '*.hsd']);
if length(hsdFileDat) > 1
    disp('WARNING: more than 1 hsd file found; processing the first one only')
end
hsdFile = [datDir filesep hsdFileDat(1).name];

% 1) wavelet filter data and save filtered data from each trode in a separate file
filterDir = [saveDir filesep 'filtered'];
lfpDir = [saveDir filesep 'LFP'];
FilterHsd(hsdFile, 'saveDir', filterDir, 'verbose', verbose, 'timeRange', timeRange, 'lfp', lfp, 'lfpDir', lfpDir)

% 2) detect and cluster spikes on all trodes in all tasks/phases of the recording session
sortDir = [saveDir filesep 'sorted-raw'];
if exist(sortDir) ~= 7
    mkdir(sortDir);
end
trodeList = dir([filterDir filesep '*.hsd']);
trodeList = arrayfun(@(t) t.name, trodeList, 'UniformOutput', false);
ConfigSort
ops.verbose = verbose;
for k = 1:length(trodeList)
    trodeName = strsplit(trodeList{k}, '.');
    if verbose
        fprintf(['Beginning sort of ' trodeName{1}]) 
    end
    trodeFile = [filterDir filesep trodeList{k}];
    spkDat = ClusterSpikes(trodeFile, ops, 'preprocessRange', preprocessRange, 'timeRange', timeRange, 'fieldName', {'taskList'}, 'fieldDat', {{'RL'}});
    trodeName = strsplit(trodeList{k}, '.');
    save([sortDir filesep trodeName{1} '.mat'], 'spkDat', 'trodeFile', '-v7.3')
    clear spkDat
end