function hsd_header = getHsdHeader_ver4(hsdFile)

% New hsd version 4 for saving filtered data (not generated at rig)
% 4/3/2017      M. Farries
 
%  started by Jason, 7/26/06
%  edited by Greg, 14-Nov-2006
%  edited by Dan Leventhal, 9/17/2010

% % % HSD simple data format for high-speed neurophysiological
% % % data acquisition. Created 2006 by Joshua Berke, Jason Breck, and
% % % Gregory Gage and in the laboratory of Joshua Berke, University
% % % of Michigan, Ann Arbor. Data consists of continuous streams of raw
% % % I16 A/D values, range +-10V, from NI M-series cards via LabVIEW.
% % % 
% % % This text description begins the file.
% % % User-entered description of this experiment starts at 2 * 1024 bytes.
% % % Main header fields begin at 3 * 1024 bytes.
% % % Channel header fields begin at 5 * 1024 bytes.
% % % Data begin at 20 * 1024 bytes.
% % % 
% % % once at the beginning of the HSD file: (begins at 3k)
% % % 
% % %        uint16       Header Version Number (this text describes version 3 !!)
% % %        uint16       Sampling rate (Hz)
% % %        uint16       Number of channels in this file
% % %        char[256] Original name of this file (including the time/date string)
% % %        char[256] Name of auxilliary file 1 (e.g. BOX file)
% % %        char[256] Name of auxilliary file 2 (e.g. AVI file)
% % %        char[256] Name of auxilliary file 3 (e.g. AVI-timestamps file)
% % %        char[256] Name of auxilliary file 4
% % %        char[256] Name of auxilliary file 5
% % %        char[256] Name of auxilliary file 6
% % %        char[100] Subject Name
% % %        char[10]   Date (format "YYYY-MM-DD")
% % %        char[5]    Time (24 hour format "HH:MM")
% % %        char[20]   recordingType - 'tetrode21', 'probe1x32'
% % %        double     downsampled_rate
% % %        char[107] PADDING
% % % 
% % % then, for each channel: (begins at 5k)
% % % 
% % %        uint16      Original Input Wire Number  (e.g. wires 1-81)
% % %        uint16      Good Wire (1 = yes, 0 = No)
% % %        uint16      Channel Type (1=tetrode, 2=stereotrode, 3=eeg, 4=wire)
% % %        uint16      Channel number of this type (0 = none)
% % %        uint16      Wire number of this channel (0 = none)
% % %        uint16      Bank number of this wire (1 = BankA, 2 = BankB, ...)
% % %        uint16      Gain setting for this wire
% % %        uint16      Low cut frequency of hardware filters (Hz)
% % %        uint16      High cut frequency of hardware filters (Hz)
% % %        char[64]  Wire name
% % % 
% % % then, the data (begin at 20k)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               PARAMETERS                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%samples_per_buffer = 100000;
%   % (this is how many samples to read in and plot)
%channel_to_plot = 21;
%sample_offset = 0; %Fs * time;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

main_header_offset = 3 * 1024;
comment_offset = 2 * 1024;
channel_header_offset = 5 * 1024;
data_offset = 20 * 1024;

fin = fopen(hsdFile, 'r');

% Begin reading the file.
%  note that the beginning of the file is the
%  textual description of the file format,
%  and that begins with "HSD "
magic_string = fread(fin, 4, '*char')';
if strcmp(magic_string, 'HSD ')
    %disp('  Magic String "HSD " was found');
else
    disp('  WARNING: Magic String "HSD " not found!');
    disp(['     instead, I found ' magic_string]);
end

% read the comment 
fseek(fin, comment_offset, 'bof');
hsd_header.comment = deblank(fread(fin, 1024, '*char')');

% read the main information
fseek(fin, main_header_offset, 'bof');
hsd_header.version       = fread(fin, 1, 'uint16', 0, 'b');
hsd_header.sampling_rate = fread(fin, 1, 'uint16', 0, 'b');
hsd_header.vScale = fread(fin, 1, 'float32', 0, 'b');
hsd_header.bytesPerSample = fread(fin, 1, 'uint16', 0, 'b');
hsd_header.num_channels  = fread(fin, 1, 'uint16', 0, 'b');

% read the channel information
fseek(fin, channel_header_offset, 'bof');
for which_channel = 1:hsd_header.num_channels
    

    hsd_header.channel(which_channel).chip = fread(fin, 1, 'uint16', 0, 'b');
    hsd_header.channel(which_channel).chip_channel  = fread(fin, 1, 'uint16', 0, 'b');
    hsd_header.channel(which_channel).impedance  = fread(fin, 1, 'uint16', 0, 'b');
    hsd_header.channel(which_channel).low_cut  = fread(fin, 1, 'uint16', 0, 'b');     
    hsd_header.channel(which_channel).high_cut  = fread(fin, 1, 'uint16', 0, 'b');
    hsd_header.channel(which_channel).name            = deblank(fread(fin, 64, '*char')');
end

hsd_header.dataOffset = data_offset;

fclose(fin);

