function [idx1 idx2] = CorrespondingSpikes(spk1, spk2, maxDiff)

% 8/30/2016     M. Farries

% This function tries to find a one-to-one correspondence between elements
% of two arrays, "spk1" and "spk2." Elements of one array are "matched" to
% the closest elements of the other array, but no element in one array is
% allowed to match more than one element of the other, and the difference
% between matching elements cannot exceed maxDiff.

% OUTPUTS
%   idx1, idx2 - indicies of matching elements of each input array

if isempty(spk1) | isempty(spk2)
    idx1 = [];
    idx2 = [];
    return
end
if size(spk1, 2) == 1
    spk1 = spk1';
end
if size(spk2, 1) == 1
    spk2 = spk2';
end

spkDiff = abs(bsxfun(@minus, spk1, spk2));

% find indices of longer spike train with min distance to each spike of shorter train
nSpk = [length(spk1) length(spk2)];
[~, sel] = min(nSpk);
[d idxL] = min(spkDiff, [], sel);
[n, ~, b] = histcounts(idxL, (1:nSpk(sel) + 1) - 0.5);

% if any spike in longer train "matches" more than one spike in the shorter
% train, match to the one that is closest
if size(idxL, 2) == 1
    idxL = idxL';
end
delList = [];
multimatches = find(n > 1);
for i = 1:length(multimatches)
    matchIdx = find(idxL == idxL(multimatches(i)));
    [~, minMatch] = min(d(matchIdx));
    matchIdx(minMatch(1)) = [];
    delList = [delList matchIdx];
end

idxS = setdiff(1:nSpk(sel), delList);
idxL(delList) = [];
d(delList) = [];

% throw out matches whose difference is bigger than maxDiff
delList = find(d > maxDiff);
idxS(delList) = [];
idxL(delList) = [];

idx = zeros(2,length(idxS));
idx(sel, :) = idxS;
idx(mod(sel,2) + 1, :) = idxL;
idx1 = idx(1,:);
idx2 = idx(2,:);