function xc = CrossCorr(spkDat, refUnit, testUnit, varargin)

nSamp = 10000;
binSpec = [];
binEdges = -100.5:100.5;
noLaser = true;

for i = 1:2:length(varargin)
    switch varargin{i}
        case 'nSamp'
            nSampTarget = varargin{i+1};
        case 'binEdges'
            binEdges = varargin{i+1};
        case 'binSpec'
            binSpec = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to CrossCorr');
    end
end

if ~isempty(binSpec)
    numBins = binSpec(1);
    binWidth = binSpec(2);
    binEdges = (1:numBins + 1)*binWidth;
    binEdges = binEdges - binEdges(end)/2 - binWidth/2;
end

t = binEdges(2:end) - diff(binEdges)/2;
loc = find(spkDat.id == refUnit);
refSpk = 1000 * spkDat.ts(loc) / spkDat.Fs; % convert to spk time in ms
loc = find(spkDat.id == testUnit);
testSpk = 1000 * spkDat.ts(loc) / spkDat.Fs; % convert to spk time in ms

laserTask = find(cellfun(@(t) ~isempty(strfind(lower(t), 'laser')), spkDat.taskList));
if noLaser & ~isempty(laserTask)
    for i = 1:length(laserTask)
        t1 = 1000 * spkDat.taskStart(laserTask(i));
        t2 = 1000 * spkDat.taskEnd(laserTask(i));
        refSpk(refSpk > t1 & refSpk < t2) = [];
        testSpk(testSpk > t1 & testSpk < t2) = [];
    end
end

nSamp = min([nSamp length(refSpk)]);
samp = randsample(length(refSpk), nSamp);
refSpk = refSpk(samp);

counts = zeros(1, length(binEdges) - 1);
for i = 1:nSamp
    counts = counts + histcounts(testSpk - refSpk(i), binEdges);
end

zeroBin = find(abs(t) == min(abs(t)));
if refUnit == testUnit
    counts(zeroBin) = 0;
end
xc.t = t;
xc.y = counts / nSamp;


