function data = LoadAuxData(datDir, varargin)

% hard-coded parameters
vScale = 0.0000374;
bytesPerSample = 2;

% default values of optional arguments
timeRange = [0 20];
lowpassCut = 100;
filtOrder = 20;

for i = 1 : 2 : length(varargin) 
    switch lower(varargin{i})
        case 'timerange'
            timeRange = varargin{i+1};
        case 'lowpasscut'
            lowpassCut = varargin{i+1};
        case 'filtorder'
            filtOrder = varargin{i+1};
        otherwise
            disp('Invalid optional argument passed to LoadAuxData')
    end
end


% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);
Fs = rhdInfo.Fs;

if lowpassCut < Fs/2
    b = fir1(filtOrder, 2*pi*lowpassCut / Fs, 'low');
end


% extract "custom name" auxillary channels
chanNumbers = arrayfun(@(x) str2num(x.native_name(end)), rhdInfo.aux);
data.chanNames = arrayfun(@(x) x.custom_name, rhdInfo.aux, 'UniformOutput', false);
datInfo = dir([datDir filesep 'aux-' rhdInfo.aux(1).native_name '.dat']);
datalength = datInfo.bytes / bytesPerSample;

timeRange(1) = max(0, timeRange(1));
timeRange(2) = min(datalength / Fs, timeRange(2));
times = (timeRange(1) + 1/Fs):(1/Fs):timeRange(2);
firstSample = round(timeRange(1) * Fs);
% nSamples = floor(diff(timeRange) * Fs);
nSamples = length(times);
data.t = times;
    
% open Intan data files for reading
fIn = arrayfun(@(j) fopen([datDir filesep 'aux-' rhdInfo.aux(j).native_name '.dat']), chanNumbers);
    
% load data
data.a = zeros(length(chanNumbers), nSamples);
for j = 1:length(chanNumbers)
    fseek(fIn(j), firstSample * bytesPerSample, 'bof');
    data.a(j,:) = fread(fIn(j), nSamples, 'uint16')*vScale;
    if lowpassCut < Fs/2
        data.a(j,:) = filtfilt(b, 1, data.a(j,:));
    end
end
        
% close Intan data files
arrayfun(@(f) fclose(f), fIn);

% downsample filtered data to (above!) Nyquist rate 
if lowpassCut < Fs/2
%    targetFs = 2*lowpassCut;
    targetFs = 500;
    dn = round(Fs/targetFs);
    pts = 1:dn:nSamples;
    data.t = data.t(pts);
    data.a = data.a(:, pts);
end