function ts_shift = AlignWave(wave, peakLoc, varargin)

% REQUIRED ARGUMENTS
%   wave    - clip of data containing a single spike waveform, # samples
%   peakLoc - target location of waveform peak

% OUTPUT
%   ts_shift - timing shift, in sample numbers, required to align the spike
%              waveform to peakLoc

[wL nChan] = size(wave);

derivWindow = 2;
slopeWt = 0.5;
alignWin = [1 wL] - peakLoc;
polarity = 0;

for i = 1:2:length(varargin)
    switch varargin{i}
        case 'alignWin'
            alignWin = varargin{i+1} + peakLoc;
        case 'derivWindow'
            derivWindow = varargin{i+1};
        case 'slopeWt'
            slopeWt = varargin{i+1};
        case 'polarity'
            polarity = varargin{i+1};
        case 'alignOps'
            ops = varargin{i+1};
            alignWin = ops.alignWin;
            derivWindow = ops.derivWindow;
            slopeWt = ops.slopeWt;
            polarity = ops.polarity;
            
        otherwise
            disp('invalid optional argument passed to AlignWave')
            return
    end
end
alignWin = alignWin + peakLoc;
wave = bsxfun(@minus, wave, median(wave));
d = wave(1 + derivWindow:end, :) - wave(1:end - derivWindow, :);
peaks = FindPeaks(wave, 1, polarity);
peaks(1:derivWindow, :) = false;
[loc wire] = ind2sub(size(peaks), find(peaks));
ampl = abs(wave(peaks));
slope = abs(d(peaks(derivWindow + 1:end,:)));
peakStr = ampl + slopeWt * slope;
validPk = loc >= alignWin(1) & loc <= alignWin(2);
loc = loc(validPk);
peakStr = peakStr(validPk);
alignLoc = loc(find(peakStr == max(peakStr)));

if isempty(alignLoc)
    ts_shift = 0;
else
    ts_shift = alignLoc(1) - peakLoc;
end
