function peaks = FindPeaks(dat, s, varargin)

% M. Farries    4/5/2017

% Simplified version of Murat Okatan's get_peaks
% Finds peaks is dat at scale s, which should be an odd number.
% dat is a matrix, nSamples X nChan.
% Optional 3rd argument: "polarity" of the peaks being sought: +1 = positive peaks, -1 = negative peaks
% Returns a logical array of size dat, with "true" where peaks are located.

pol = 0;
if length(varargin) > 0
    pol = sign(varargin{1}); % polarity of peaks being sought
end

if any(isnan(dat))
    peaks = [];
    return
end
    

if s > 1
    dat = filtfilt(ones(1,s)/s, 1, dat);
end

d = diff(dat);
peaks = false(size(dat));
peaks(2:end-1,:) = logical(1 - sign(d(1:end-1,:) .* d(2:end,:)));

% remove peaks that have the wrong polarity, if peak polarity was specified
if pol ~=0
    peaks(2:end-1,:) = peaks(2:end-1,:) & pol*d(1:end-1,:) >= 0;
end

% deal with special case of consecutive values being equal
for i = find(any(d == 0))
    zeroLoc = find(d(:,i) == 0); % locations where d = 0
    endLoc = find(diff(zeroLoc) > 1); % locations of the ends of sequences of d = 0
    startLoc = endLoc + 1; % locations of the starts of sequences of d = 0
    endLoc = [zeroLoc(endLoc); zeroLoc(end)];
    startLoc = [zeroLoc(1); zeroLoc(startLoc)];
    peaks(zeroLoc, i) = false;
    peaks(zeroLoc+1, i) = false;
    for j = 1:length(startLoc) % loop through blocks of consecutive equal values
        if startLoc(j) > 1 & endLoc(j) < size(d, 1)
            peakLoc = round(mean([startLoc(j) endLoc(j)]));
            peaks(peakLoc,i) = logical(1 - sign(d(startLoc(j)-1,i) * d(endLoc(j)+1,i)));
            if pol ~=0
                peaks(peakLoc,i) = peaks(peakLoc,i) & pol*d(startLoc(j)-1,i) > 0;
            end
        end
    end
end