function err = SpkError(spkWaves, template, wireSD, varargin)

% size(spkWaves) should be [waveLength numWires numSpikes]
% size(template) should be [waveLength numWires]

useMinErr = false;
if isempty(wireSD)
    wireSD = median(std(spkWaves, 1),3);
end
useRelErr = false; % error measured relative to max average spike ampl (across wires);
minAmplThr = 1; % in units of standard deviation
relAmplThr = 0.5; % relative to wire with biggest spike
criticalWires = [];

for i = 1:2:length(varargin)
    switch varargin{i}
        case 'useMinErr'
            useMinErr = varargin{i+1};
        case 'useRelErr'
            useRelErr = varargin{i+1};
        case 'minAmplThr'
            minAmplThr = varargin{i+1};
        case 'relAmplThr'
            relAmplThr = varargin{i+1};
        case 'chan'
            criticalWires = varargin{i+1};
    end
end

[wL nChan nSpks] = size(spkWaves);

% identify template critical wires, keep only that portion of the template
wireAmpl = max(abs(template));
[maxAmpl maxWire] = max(wireAmpl);
if isempty(criticalWires)
    criticalWires = union(maxWire, find(wireAmpl > relAmplThr*maxAmpl & (wireAmpl./wireSD) > minAmplThr));
end
template = template(:, criticalWires);
wireSD = wireSD(criticalWires);
scale = ones(wL, length(criticalWires), nSpks);
if useRelErr
    scale = scale * maxAmpl;
end

% trim spkWaves to specified window, keeping only critical wires
spkWaves = spkWaves(:, criticalWires, :);

% compute normalized mean squared error between spkWaves and template, take min across wires
waveDiff = bsxfun(@minus, spkWaves, template);
% next step optional, consider commenting out
% waveDiff = bsxfun(@minus, waveDiff, mean(waveDiff,3));
waveDiff = bsxfun(@rdivide, waveDiff, wireSD);
waveDiff = waveDiff ./ scale;
if useMinErr
    err = squeeze(min(mean(waveDiff.^2, 1), [], 2));
else
    err = squeeze(mean(mean(waveDiff.^2, 1), 2));
end
%err = squeeze(mean(mean(waveDiff.^2, 1), 2));
