function spkDat = AlignClusterMeans(spkDat, varargin)

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
chanList = 1:nChan;
clustList = setdiff(unique(spkDat.id), 0);
shift = -8*spkDat.upsample : 8*spkDat.upsample;
if ~isempty(spkDat.alignWin)
    win = spkDat.alignWin;
else
    win = [1 - pk, pk - 1];
end
win = 1000 * win / (spkDat.Fs * spkDat.upsample);

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'clust'
            clustList = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'win'
            win = varargin{i+1};
        case 'shift'
            shift = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to AlignClusterMeans');
    end
end

shift = intersect(sort(shift), -wP:wP);
win = round(spkDat.Fs * spkDat.upsample * win / 1000);
maxWin = [shift(1) + 1 - pk, wL - pk - shift(end)];
win(1) = max([win(1) maxWin(1)]);
win(2) = min([win(2) maxWin(2)]);
nPts = range(win) + 1;
pts = (1:nPts) + win(1) + pk + wP - 1;

% compute average waveforms
nClust = length(clustList);
nChanIn = length(chanList);
template = zeros(nPts, nChanIn, nClust);
for i = 1:nClust
    n = clustList(i);
    loc = find(spkDat.id == n);
    template(:,:,i) = mean(spkDat.waves(pts, chanList, loc), 3);
end

% adjust spike times
pk = 1 - win(1);
dt = arrayfun(@(i) AlignWave(template(:,:,i), pk), 1:nClust);
dt(~ismember(dt, shift)) = 0;
wL = wL + 2*wP;
for i = 1:nClust
    n = clustList(i);
    loc = find(spkDat.id == n);
    spkDat.ts(loc) = spkDat.ts(loc) + dt(i);
    if dt(i) ~= 0
        wv = spkDat.waves(:,:,loc);
        spkDat.waves(:,:,loc) = zeros(wL, nChan, length(loc));
        pts = (1:wL) + dt(i);
        pts = pts(pts > 0 & pts <= wL);
        spkDat.waves(pts - dt(i), :, loc) = wv(pts, :, :);
    end
end

if length(find(spkDat.ts - spkDat.ts0 > spkDat.wavePad)) > 0;
    disp('WARNING: total shift exceeds wavePad on some spikes--reload waves recommended')
end