function AlignReview(spkDat, dt, varargin)

% convert waveform data from int16 to double-precision floating point
spkDat.waves = double(spkDat.waves);

maxScale = 1;
sameScale = false;
convertToVolt = true;
nSampTarget = 100;
clustList = setdiff(unique(spkDat.id), 0);
dtRange = unique(dt);
Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nsamp'
            nSampTarget = varargin{i+1};
        case 'converttovolt'
            convertToVolt = varargin{i+1};
        case 'maxscale'
            maxScale = varargin{i+1};
        case 'clust'
            clustList = varargin{i+1};
        case 'samescale'
            sameScale = varargin{i+1};
        case 'dtrange'
            dtRange = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to AlignReview');
    end
end

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
vScale = spkDat.vScale;
dtRange = setdiff(dtRange, 0);
nClust = length(clustList);

% remove clusters with no time adjustments to display
delIdx = [];
for i = 1:nClust
    loc = find(spkDat.id == clustList(i));
    if isempty(intersect(dtRange, unique(dt(loc))))
        delIdx = [delIdx i];
    end
end
clustList(delIdx) = [];
nClust = length(clustList);
if nClust == 0
    disp('No timeshifts of that kind are available to display')
end

% assemble plot data, calculate y range
pts = (1:wL) + wP;
yRange = zeros(nClust, 2);
avgWave = zeros(wL, nChan, nClust);
wvA = cell(1, nClust);
wvU = cell(1, nClust);
for i = 1:nClust
    
    % compute average waveform for cluster
    loc = find(spkDat.id == clustList(i));
    avgWave(:,:,i) = mean(spkDat.waves(pts,:,loc), 3);
    
    % select sample of waveforms to plot
    dtTmp = dt(loc);
    loc = loc(ismember(dtTmp, dtRange));
    nSpk = length(loc);
    nSamp = min([nSampTarget nSpk]);
    samp = randsample(nSpk, nSamp);
    loc = loc(samp);
    wvU{i} = spkDat.waves(pts, :, loc);
    wvA{i} = zeros(wL, nChan, nSamp);
    dtTmp = dt(loc);
    for k = 1:nSamp
        p = pts + dtTmp(k);
        p(p < 1) = [];
        p(p > wL + 2*wP) = [];
        wvA{i}(p - dtTmp(k) - wP, :, k) = spkDat.waves(p, :, loc(k));
    end
    
    % compute yRange
    if convertToVolt
        wvU{i} = vScale * wvU{i};
        wvA{i} = vScale * wvA{i};
        avgWave(:,:,i) = vScale * avgWave(:,:,i);
    end
    avgMin = min(min(avgWave(:,:,i)));
    avgMax = max(max(avgWave(:,:,i)));
    avgRange = avgMax - avgMin;
    tmpMin = min([min(min(wvU{i}, [], 3)) min(min(wvA{i}, [], 3))]);
    tmpMax = max([max(max(wvA{i}, [], 3)) max(max(wvA{i}, [], 3))]);
    yRange(i,1) = max([tmpMin, avgMin - avgRange * maxScale]);
    yRange(i,2) = min([tmpMax, avgMax + avgRange * maxScale]);
end

if sameScale
    yRange(:,1) = min(yRange(:,1));
    yRange(:,2) = max(yRange(:,2));
end

% make figure panel
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 26;
horizSpace = 35;
plotWidth = 300;
plotHeight = 280;
panelHeight = vertSpace + nChan * (vertSpace + plotHeight);
panelWidth = horizSpace + 2 * nClust * (horizSpace + plotWidth);
fig = figure('Position', [100 500 panelWidth panelHeight]); %[left bottom width height];
spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = plotWidth/panelWidth;
ht = plotHeight/panelHeight;

% plot data for each cluster
t = 1000 * ((1:wL) - pk)/wvFs;
for i = 1:nClust
    
    % plot prealignment waveforms
    col = 2*i - 1;
    for w = 1:nChan
        subplot('Position', [spH+(col-1)*(wd+spH) spV+(nChan-w)*(ht+spV)  wd ht]) %[left bottom width height]
        if w==1
            title(['unit ' num2str(clustList(i)) ' before realignment'])
        end
        hold on
        plot(t, squeeze(wvU{i}(:,w,:)), 'LineWidth', 1, 'color', 'k')
        plot(t, avgWave(:,w,i), 'LineWidth', 3, 'color', 'r')
        yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
        plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
        ylim(yR);
        xlim([t(1) t(end)]);
    end
    
    % plot postalignment waveforms
    col = 2*i;
    for w = 1:nChan
        subplot('Position', [spH+(col-1)*(wd+spH) spV+(nChan-w)*(ht+spV)  wd ht]) %[left bottom width height]
        if w==1
            title(['unit ' num2str(clustList(i)) ' after realignment'])
        end
        hold on
        plot(t, squeeze(wvA{i}(:,w,:)), 'LineWidth', 1, 'color', 'k')
        plot(t, avgWave(:,w,i), 'LineWidth', 3, 'color', 'r')
        yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
        plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
        ylim(yR);
        xlim([t(1) t(end)]);
    end
    
end