function dt = AlignTest(spkDat, varargin)

% aligns the waveforms in each cluster to the average waveform for that
% cluster

spkDat.waves = double(spkDat.waves);
[wL, nChan, ~] = size(spkDat.waves);
chanList = 1:nChan;
clustList = setdiff(unique(spkDat.id), 0);
shift = [-0.2 0.2];
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
win = 1000 * [1 - pk wL - pk] / (spkDat.Fs * spkDat.upsample);

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'clust'
            clustList = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'shift'
            shift = varargin{i+1};
        case 'win'
            win = varargin{i+1};
        otherwise
            disp('invalid argument passed to AlignTest')
    end
end

shift = round(shift * (spkDat.Fs * spkDat.upsample) / 1000);
shift(1) = max(shift(1), -wP);
shift(2) = min(shift(2), wP);
shift = shift(1):shift(2);
win = round(spkDat.Fs * spkDat.upsample * win / 1000);
maxWin = [shift(1) + 1 - pk - wP, wL + wP - pk - shift(end)];
win(1) = max([win(1) maxWin(1)]);
win(2) = min([win(2) maxWin(2)]);
nPts = range(win) + 1;
pts = (1:nPts) + win(1) + pk + wP - 1;
nChanIn = length(chanList);
sd = [];
for i = 1:nChanIn
    sd = [sd; ones(nPts,1) * spkDat.wireSd(chanList(i))];
end

nShift = length(shift);
p = bsxfun(@plus, pts, shift');
p = reshape(p, nPts*nShift, 1);

dt = zeros(size(spkDat.ts));
nClust = length(clustList);
for i = 1:nClust
    
    % generate template
    loc = find(spkDat.id == clustList(i));
    template = mean(spkDat.waves(pts, chanList, loc), 3);
    template = reshape(template, nPts*nChanIn, 1);
    
    % find dt that minimizes error between template and wave
    for k = loc
        wv = spkDat.waves(p, chanList, k);
        wv = reshape(wv, nShift, nPts*nChanIn);
        err = bsxfun(@minus, wv, template');
        err = bsxfun(@rdivide, err, sd');
        err = mean(err.^2, 2);
        minLoc = find(err == min(err));
        dt(k) = shift(minLoc(1));
    end
    
end
