function CleanReview(spkDat, cleanDat, clust, errCriterion, varargin)

maxScale = 2;
sameScale = true;
convertToVolt = true;
nSampTarget = 300;
nSampReject = 25;
nSampAccept = 25;
minIsi = 1;
Fs = spkDat.Fs;
spkDat.waves = double(spkDat.waves);
wvFs = Fs * spkDat.upsample;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nsamp'
            nSampTarget = varargin{i+1};
        case 'nsampreject'
            nSampReject = varargin{i+1};
        case 'nsampaccept'
            nSampAccept = varargin{i+1};
        case 'converttovolt'
            convertToVolt = varargin{i+1};
        case 'maxscale'
            maxScale = varargin{i+1};
        case 'samescale'
            sameScale = varargin{i+1};
        case 'minisi'
            minIsi = varargin{i+1};             
        otherwise
            disp('invalid optional argument passed to CleanReview');
    end
end

clustList = arrayfun(@(x) x.id, cleanDat);
if ~ismember(clust, clustList)
    fprintf('\nCluster %d is not present in cleanDat\n\n', clust)
    return
end
cid = find(clustList == clust);
if errCriterion <= 0
    errCriterion = min(cleanDat(cid).errCriteria)
end

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
vScale = spkDat.vScale;

% choose plot samples
locPre = find(spkDat.id == clust);
spkTimes = 1000 * spkDat.ts(locPre) / Fs; % spike times in ms
isi = diff(spkTimes);
isiViolPre = 100 * length(find(isi < minIsi)) / length(isi);
nPre = length(locPre);
nSampPre = min([nSampTarget nPre]);
sampPre = locPre(randsample(nPre, nSampPre));
accept = cleanDat(cid).err < errCriterion;
locPost = locPre(accept);
spkTimes = 1000 * spkDat.ts(locPost) / Fs; % spike times in ms
isi = diff(spkTimes);
isiViolPost = 100 * length(find(isi < minIsi)) / length(isi);
nPost = length(locPost);
nSampPost = min([nSampTarget nPost]);
sampPost = locPost(randsample(nPost, nSampPost));
nAccept = min([nSampAccept nPost]);
[~, iSort] = sort(cleanDat(cid).err(accept), 'descend');
sampA = locPost(iSort(1:nAccept));
reject = cleanDat(cid).err >= errCriterion;
nReject = min([nSampReject length(cleanDat(cid).err(reject))]);
[~, iSort] = sort(cleanDat(cid).err(reject));
locRej = locPre(reject);
sampR = locRej(iSort(1:nReject));

% assemble plot data, calculate y Range
pts = (1:wL) + wP;
yRange = zeros(4, 2);
refWave = mean(spkDat.waves(pts,:,locPost), 3);
if convertToVolt
    refWave = vScale * refWave;
end
avgWave = mean(spkDat.waves(pts,:,locPre), 3);
if convertToVolt
    avgWave = vScale * avgWave;
end
avgRange = [min(min(avgWave)) max(max(avgWave))];
refRange = [min(min(refWave)) max(max(refWave))];
refMin = min([refRange(1) avgRange(1)]);
refMax = max([refRange(2) avgRange(2)]);
refRange = refMax - refMin;
wvPre = spkDat.waves(pts,:,sampPre);
if convertToVolt
    wvPre = vScale * wvPre;
end
tmpMin = min([min(min(wvPre, [], 3)) refMin]);
tmpMax = max([max(max(wvPre, [], 3)) refMax]);
yRange(1,1) = max([tmpMin, refMin - refRange * maxScale]);
yRange(1,2) = min([tmpMax, refMax + refRange * maxScale]);

wvPost = spkDat.waves(pts,:,sampPost);
if convertToVolt
    wvPost = vScale * wvPost;
end
tmpMin = min([min(min(wvPost, [], 3)) refMin]);
tmpMax = max([max(max(wvPost, [], 3)) refMax]);
yRange(2,1) = max([tmpMin, refMin - refRange * maxScale]);
yRange(2,2) = min([tmpMax, refMax + refRange * maxScale]);

wvA = spkDat.waves(pts,:,sampA);
if convertToVolt
    wvA = vScale * wvA;
end
avA = mean(wvA, 3);
tmpMin = min([min(min(wvA, [], 3)) refMin]);
tmpMax = max([max(max(wvA, [], 3)) refMax]);
yRange(3,1) = max([tmpMin, refMin - refRange * maxScale]);
yRange(3,2) = min([tmpMax, refMax + refRange * maxScale]);

wvR = spkDat.waves(pts,:,sampR);
if convertToVolt
    wvR = vScale * wvR;
end
avR = mean(wvR, 3);
tmpMin = min([min(min(wvR, [], 3)) refMin]);
tmpMax = max([max(max(wvR, [], 3)) refMax]);
yRange(4,1) = max([tmpMin, refMin - refRange * maxScale]);
yRange(4,2) = min([tmpMax, refMax + refRange * maxScale]);

if sameScale
    yRange(:,1) = min(yRange(:,1));
    yRange(:,2) = max(yRange(:,2));
end

% make figure panel
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 26;
horizSpace = 35;
plotWidth = 350;
plotHeight = 300;
panelHeight = vertSpace + 4 * (vertSpace + plotHeight);
panelWidth = horizSpace + 5 * (horizSpace + plotWidth);
titleStr = ['cluster ' num2str(clust)];
fig = figure('Position', [100 500 panelWidth panelHeight], 'Name', titleStr, 'NumberTitle', 'off'); %[left bottom width height];
spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = plotWidth/panelWidth;
ht = plotHeight/panelHeight;

% plot uncleaned cluster
t = 1000 * ((1:wL) - pk) / wvFs;
i = 1; % i denotes plot column, i = 1:5
for w = 1:nChan
    subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
    hold on
    plot(t, squeeze(wvPre(:,w,:)), 'LineWidth', 1, 'color', 'k')
    plot(t, avgWave(:,w), 'LineWidth', 3, 'color', 'r')
    pts = (cleanDat(cid).win(w,1):cleanDat(cid).win(w,2)) + pk;
    plot(t(pts), avgWave(pts,w), 'LineWidth', 3, 'color', 'g')
    xlim([t(1) t(end)]);
    yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
    plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
    ylim(yR);
    if w == 1
        title(['original cluster: ' num2str(nPre) ' spikes'])
        isiStr = [num2str(isiViolPre, '%1.2f') '%'];
        xr = xlim;
        xPos = 0.85*range(xr) + xr(1);
        yPos = 0.95*range(yR) + yR(1);
        text(xPos, yPos, isiStr, 'FontSize', 12, 'BackgroundColor', 'w', 'Color', 'r', 'FontWeight', 'Bold');
    end
end

% plot cleaned cluster
i = 2; % i denotes plot column, i = 1:5
for w = 1:nChan
    subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
    hold on
    plot(t, squeeze(wvPost(:,w,:)), 'LineWidth', 1, 'color', 'k')
    plot(t, refWave(:,w), 'LineWidth', 3, 'color', 'r')
    pts = (cleanDat(cid).win(w,1):cleanDat(cid).win(w,2)) + pk;
    plot(t(pts), refWave(pts,w), 'LineWidth', 3, 'color', 'g')
    xlim([t(1) t(end)]);
    yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
    plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
    ylim(yR);
    if w == 1
        title(['cleaned cluster: ' num2str(nPost) ' spikes'])
        isiStr = [num2str(isiViolPost, '%1.2f') '%'];
        xr = xlim;
        xPos = 0.85*range(xr) + xr(1);
        yPos = 0.95*range(yR) + yR(1);
        text(xPos, yPos, isiStr, 'FontSize', 12, 'BackgroundColor', 'w', 'Color', 'r', 'FontWeight', 'Bold');
    end
end

% plot worst accepted spikes
i = 3; % i denotes plot column, i = 1:5
for w = 1:nChan
    subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
    if w == 1
        title([num2str(nAccept) ' worst accepted spikes'])
    end
    hold on
    plot(t, squeeze(wvA(:,w,:)), 'LineWidth', 1, 'color', 'k')
    plot(t, refWave(:,w), 'LineWidth', 3, 'color', 'g')
    plot(t, avA(:,w), 'LineWidth', 3, 'color', 'b')
    xlim([t(1) t(end)]);
    yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
    plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
    ylim(yR);
end

% plot best rejected spikes
i = 4; % i denotes plot column, i = 1:5
for w = 1:nChan
    subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
    if w == 1
        title([num2str(nReject) ' best rejected spikes'])
    end
    hold on
    plot(t, squeeze(wvR(:,w,:)), 'LineWidth', 1, 'color', 'k')
    plot(t, refWave(:,w), 'LineWidth', 3, 'color', 'g')
    plot(t, avR(:,w), 'LineWidth', 3, 'color', 'm')
    xlim([t(1) t(end)]);
    yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
    plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
    ylim(yR);
end

% plot summary data
i = 5;
w = 1; % w now denotes the plot row, w = 1:4
subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
plot(cleanDat(cid).errCriteria, 100*cleanDat(cid).fracReject, 'LineWidth', 3, 'color', 'k')
hold on
maxY = max(100*cleanDat(cid).fracReject);
ylim([0 1.05* maxY]);
xlim([floor(min(cleanDat(cid).errCriteria)) max(cleanDat(cid).errCriteria)]);
xR = xlim;
plot([errCriterion errCriterion], ylim, '--', 'color', 'r')
labelStr = '% rejected as a function of error criterion';
text(xR(1) + 0.2*range(xR), maxY, labelStr, 'FontSize', 12, 'FontWeight', 'Bold')

w = 2; % w now denotes the plot row, w = 1:4
subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
plot(cleanDat(cid).errCriteria, 100*cleanDat(cid).isiViol, 'LineWidth', 3, 'color', 'k')
hold on
maxY = max(100*cleanDat(cid).isiViol);
if maxY(1) > 0
    ylim([0 1.1* maxY(1)]);
end
xlim([floor(min(cleanDat(cid).errCriteria)) max(cleanDat(cid).errCriteria)]);
xR = xlim;
plot([errCriterion errCriterion], ylim, '--', 'color', 'r')
labelStr = 'ISI violation a function of error criterion';
text(xR(1) + 0.2*range(xR), 1.05*maxY, labelStr, 'FontSize', 12, 'FontWeight', 'Bold')

w = 3; % w now denotes the plot row, w = 1:4
subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
binEdges = linspace(0, errCriterion, 50);
histogram(cleanDat(cid).err(accept), binEdges)
xlim([binEdges(1) binEdges(end)])
yR = ylim;
labelStr = 'error distribution (accepted spikes)';
text(binEdges(1) + 0.4*range(binEdges), yR(1)+0.95*range(yR), labelStr, 'FontSize', 12, 'FontWeight', 'Bold')

w = 4; % w now denotes the plot row, w = 1:4
subplot('Position', [spH+(i-1)*(wd+spH) spV+(4-w)*(ht+spV)  wd ht]) %[left bottom width height]
xMax = quantile(cleanDat(cid).err(reject), 0.99);
binEdges = linspace(errCriterion, xMax, 50);
histogram(cleanDat(cid).err(reject), binEdges)
xlim([binEdges(1) binEdges(end)])
yR = ylim;
labelStr = 'error distribution (rejected spikes)';
text(binEdges(1) + 0.4*range(binEdges), yR(1)+0.95*range(yR), labelStr, 'FontSize', 12, 'FontWeight', 'Bold')