function cleanDat = CleanTest(spkDat, varargin)

minIsi = 1; % in milliseconds
Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;
winIn = 'auto';
clustList = setdiff(unique(spkDat.id), 0);
clustListIn = clustList;
verbose = true;
spkDat.waves = double(spkDat.waves);
[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
win = 1000 * [1 - pk wL - pk] / wvFs;
chanList = 1:nChan;
subtractMean = true;
errQuantiles = [0.01 0.05 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 0.95 0.99];
coreErrIdx = 3;
sdCriterion = 0.25;
winPad = 4;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'minisi'
            minIsi = varargin{i+1};
        case 'clust'
            clustListIn = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'verbose'
            verbose = varargin{i+1};
        case 'win'
            winIn = varargin{i+1};
        case 'errquantiles'
            errQuantiles = varargin{i+1};
        case 'sdcriterion'
            sdCriterion = varargin{i+1};
        case 'winpad'
            winPad = varargin{i+1};
        otherwise
            disp('Invalid optional argument passed to CleanTest')
    end
end

clustList = intersect(clustList, clustListIn);
nClust = length(clustList);
nChan = length(chanList);

sd = [];
maxWin = [1 - pk, wL - pk];
if isnumeric(winIn)
    winIn = round(wvFs * winIn / 1000);
    winIn(1) = max([winIn(1) maxWin(1)]);
    winIn(2) = min([winIn(2) maxWin(2)]);
end
for i = 1:size(spkDat.waves, 2)
    sd = [sd; ones(wL + 2*wP, 1) * spkDat.wireSd(i)];
end
nPts = size(spkDat.waves,1)*size(spkDat.waves,2);

% initial error distribution
errCriteria = cell(1, nClust);
coreErr = zeros(1, nClust);
for i = 1:nClust
    n = clustList(i);
    loc = find(spkDat.id == n);
    for w = chanList
        avg = mean(spkDat.waves((1:wL) + wP, w, loc), 3) / spkDat.wireSd(w);
        winPts = find(abs(avg) > sdCriterion);
        if isempty(winPts)
            win = [];
        else
            win = [winPts(1)-winPad winPts(end)+winPad] - pk;
            win(1) = max([win(1) maxWin(1)]);
            win(2) = min([win(2) maxWin(2)]);
        end
        if isnumeric(winIn)
            win = winIn;
        end
        pts = (win(1):win(2)) + pk + wP;
        wv = squeeze(spkDat.waves(pts, w, loc)) / spkDat.wireSd(w);
        if subtractMean
            wv = bsxfun(@minus, wv, mean(wv, 1));
        end
        template = mean(wv, 2);
        sqErr{w} = bsxfun(@minus, wv, template).^2;
    end
    err = mean(cell2mat(sqErr'), 1);
    errCriteria{i} = arrayfun(@(q) quantile(err, q), errQuantiles);
    coreErr(i) = errCriteria{i}(coreErrIdx);
    errCriteria{i} = sort(errCriteria{i}, 'descend');
end

for i = 1:nClust
    n = clustList(i);
    cleanDat(i).id = n;
    loc = find(spkDat.id == n);
    cleanDat(i).fracReject = [];
    cleanDat(i).isiViol = [];
    cleanDat(i).errCriteria = errCriteria{i};
    nSpk = length(loc);
    goodLoc = 1:nSpk;
    isi = 1000*diff(spkDat.ts(loc(goodLoc))) / Fs;
    isiViol0 = length(find(isi < minIsi)) / length(isi);
    if isnumeric(winIn)
         cleanDat(i).win = zeros(length(chanList), 2);
         cleanDat(i).win(:,2) = -1;
    end
    for e = errCriteria{i}
        cleanDat(i).win = zeros(size(spkDat.waves, 2), 2);
        cleanDat(i).win(:,2) = -1; 
        sqErr = cell(1, size(spkDat.waves, 2));
        for w = chanList
            avg = mean(spkDat.waves((1:wL) + wP, w, loc(goodLoc)), 3) / spkDat.wireSd(w);
            winPts = find(abs(avg) > sdCriterion);
            if isempty(winPts)
                win = cleanDat(i).win(w,:);
            else
                win = [winPts(1)-winPad winPts(end)+winPad] - pk;
                win(1) = max([win(1) maxWin(1)]);
                win(2) = min([win(2) maxWin(2)]);
            end
            if isnumeric(winIn)
                win = winIn;
            end
            cleanDat(i).win(w,:) = win;
            pts = (win(1):win(2)) + pk + wP;
            wv = squeeze(spkDat.waves(pts, w, loc)) / spkDat.wireSd(w);
            if subtractMean
                wv = bsxfun(@minus, wv, mean(wv, 1));
            end
            template = mean(wv(:, goodLoc), 2);
            sqErr{w} = bsxfun(@minus, wv, template).^2;
        end
        err = mean(cell2mat(sqErr'), 1);
        if e == coreErr(i)
            cleanDat(i).err = err;
        end
        goodLoc = find(err < e);
        fR = (nSpk - length(goodLoc)) / nSpk;
        cleanDat(i).fracReject = [cleanDat(i).fracReject fR];
        isi = 1000*diff(spkDat.ts(loc(goodLoc))) / Fs;
        iV = length(find(isi < minIsi)) / length(isi);
        cleanDat(i).isiViol = [cleanDat(i).isiViol iV];
    end
    if verbose
        fprintf('cluster %d complete\n', n);
    end
end
