function CorrMatrix(spkDat, varargin)

clustList = setdiff(unique(spkDat.id), 0);
clustListIn = clustList;
timeRange = [0 Inf];
plotRange = [-100 100];
binWidth = 1;
showAuto = false;
nSamp = 1000;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nSamp'
            nSampTarget = varargin{i+1};        
        case 'clust'
            clustListIn = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1};
        case 'plotrange'
            plotRange = varargin{i+1};
        case 'binwidth'
            binWidth = varargin{i+1};
        case 'showauto'
            showAuto = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to PlotTemplates');
    end
end

clustList = intersect(clustList, clustListIn);
nClust = length(clustList);

% make figure panel
nRow = round(sqrt(nClust));
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 35;
horizSpace = 35;
height = 200;
width = 220;
maxPanelHt = 0.8 * scrHeight;
maxPanelWd = 0.8 * scrWidth;
maxRows = floor((maxPanelHt - vertSpace) / (height + vertSpace));
maxColumns = floor((maxPanelWd - horizSpace) / (width + horizSpace));
maxClust = maxRows * maxColumns;
if nClust > maxClust
    disp('** WARNING: not enough space to plot all clusters **');
    nClust = maxClust;
    clustList = clustList(1:nClust);
end

panelHeight = vertSpace + nClust * (vertSpace + height);
panelWidth = horizSpace + nClust * (horizSpace + width);
figure('Position', [0.1*scrWidth 0.1*scrHeight panelWidth panelHeight]) %[left bottom width height]

spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = width/panelWidth;
ht = height/panelHeight;

binEdges = plotRange(1) - binWidth/2 : binWidth : plotRange(2) + binWidth/2;
t = binEdges(2:end) - diff(binEdges)/2;
zeroBin = find(abs(t) == min(abs(t)));
for i = 1:nClust
    
    n = clustList(i);
    refLoc = find(spkDat.id == n);
    refSpk = spkDat.ts(refLoc) * 1000 / spkDat.Fs;
    refSpk = refSpk(refSpk >= timeRange(1) & refSpk <= timeRange(2));
    nSamp = min([nSamp length(refSpk)]);
    samp = randsample(length(refSpk), nSamp);
    refSpk = refSpk(samp);
    testSpk = spkDat.ts(refLoc) * 1000 / spkDat.Fs;
    ac = zeros(1, length(binEdges) - 1);
    for k = 1:length(refSpk)
        ac = ac + histcounts(testSpk - refSpk(k), binEdges);
    end
    ac = ac / sum(ac);
    ac(zeroBin) = 0;
    subplot('Position', [spH+(i-1)*(wd+spH) spV+(nClust-i)*(ht+spV)  wd ht]) %[left bottom width height]
    bar(t, ac, 'r')
    xlim([binEdges(1) binEdges(end)])
    set(gca, 'YTick',[])
    xR = xlim;
    x1 = xR(1);
    xR = range(xR);
    yR = ylim;
    y1 = yR(1);
    yR = range(yR);
    text(x1+0.025*xR, y1+0.95*yR, ['cluster ' num2str(n)])
     
    for j = i+1:nClust
        m = clustList(j);
        testLoc = find(spkDat.id == m);
        testSpk = spkDat.ts(testLoc) * 1000 / spkDat.Fs;
        xc = zeros(1, length(binEdges) - 1);
        for k = 1:length(refSpk)
            xc = xc + histcounts(testSpk - refSpk(k), binEdges);
        end
        xc = xc / sum(xc);
        subplot('Position', [spH+(j-1)*(wd+spH) spV+(nClust-i)*(ht+spV)  wd ht]) %[left bottom width height]
        title(['cluster ' num2str(m) ' relative to cluster ' num2str(n)])
        bar(t, xc)
        xlim([binEdges(1) binEdges(end)])
        set(gca, 'YTick',[])
        if showAuto
            hold on
            plot(t, ac, 'r')
        end
        xR = xlim;
        x1 = xR(1);
        xR = range(xR);
        yR = ylim;
        y1 = yR(1);
        yR = range(yR);
        text(x1+0.025*xR, y1+0.95*yR, ['cluster ' num2str(m) ' relative to cluster ' num2str(n)])
        
    end
    
end