function CorrMatrix2(unit, varargin)

timeRange = [0 Inf];
plotRange = [-100 100];
binWidth = 1;
showAuto = false;
nSamp = 1000;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nsamp'
            nSampTarget = varargin{i+1};        
        case 'timerange'
            timeRange = varargin{i+1};
        case 'plotrange'
            plotRange = varargin{i+1};
        case 'binwidth'
            binWidth = varargin{i+1};
        case 'showauto'
            showAuto = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to CorrMatrix');
    end
end

nUnit = length(unit);

% make figure panel
nRow = round(sqrt(nUnit));
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 35;
horizSpace = 35;
height = 200;
width = 220;
maxPanelHt = 0.8 * scrHeight;
maxPanelWd = 0.8 * scrWidth;
maxRows = floor((maxPanelHt - vertSpace) / (height + vertSpace));
maxColumns = floor((maxPanelWd - horizSpace) / (width + horizSpace));
maxClust = maxRows * maxColumns;
if nUnit > maxClust
    disp('** WARNING: not enough space to plot all clusters **');
    nUnit = maxClust;
    clustList = clustList(1:nUnit);
end

panelHeight = vertSpace + nUnit * (vertSpace + height);
panelWidth = horizSpace + nUnit * (horizSpace + width);
figure('Position', [0.1*scrWidth 0.1*scrHeight panelWidth panelHeight]) %[left bottom width height]

spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = width/panelWidth;
ht = height/panelHeight;

binEdges = plotRange(1) - binWidth/2 : binWidth : plotRange(2) + binWidth/2;
t = binEdges(2:end) - diff(binEdges)/2;
zeroBin = find(abs(t) == min(abs(t)));
for i = 1:nUnit
    
    refSpk = unit(i).spkTimes * 1000;
    testSpk = refSpk;
    refSpk = refSpk(refSpk >= timeRange(1) & refSpk <= timeRange(2));
    nSamp = min([nSamp length(refSpk)]);
    samp = randsample(length(refSpk), nSamp);
    refSpk = refSpk(samp);
    ac = zeros(1, length(binEdges) - 1);
    for k = 1:length(refSpk)
        ac = ac + histcounts(testSpk - refSpk(k), binEdges);
    end
    ac = ac / sum(ac);
    ac(zeroBin) = 0;
    subplot('Position', [spH+(i-1)*(wd+spH) spV+(nUnit-i)*(ht+spV)  wd ht]) %[left bottom width height]
    bar(t, ac, 'r')
    xlim([binEdges(1) binEdges(end)])
    set(gca, 'YTick',[])
    if i == 1
        title(unit(i).name)
    end
     
    for j = i+1:nUnit
        
        testSpk = unit(j).spkTimes * 1000;
        xc = zeros(1, length(binEdges) - 1);
        for k = 1:length(refSpk)
            xc = xc + histcounts(testSpk - refSpk(k), binEdges);
        end
        xc = xc / sum(xc);
        subplot('Position', [spH+(j-1)*(wd+spH) spV+(nUnit-i)*(ht+spV)  wd ht]) %[left bottom width height]
        bar(t, xc)
        xlim([binEdges(1) binEdges(end)])
        set(gca, 'YTick',[])
        if i == 1
            title(unit(j).name)
        end
        if showAuto
            hold on
            plot(t, ac, 'r')
        end
        
    end
    
end