function ErrHist(cleanDat, varargin)

clustList = arrayfun(@(x) x.id, cleanDat);
clustListIn = clustList;
errRange = [0 3];

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'clust'
            clustListIn = varargin{i+1};
        case 'range'
            errRange = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to PlotTemplates');
    end
end

clustList = intersect(clustList, clustListIn);
nClust = length(clustList);
binEdges = linspace(errRange(1), errRange(2), 100);

% make figure panel
nRow = round(sqrt(nClust));
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 35;
horizSpace = 35;
height = 200;
width = 220;
maxPanelHt = 0.8 * scrHeight;
maxPanelWd = 0.8 * scrWidth;
maxRows = floor((maxPanelHt - vertSpace) / (height + vertSpace));
maxColumns = floor((maxPanelWd - horizSpace) / (width + horizSpace));
maxClust = maxRows * maxColumns;
if nClust > maxClust
    disp('** WARNING: not enough space to plot all clusters **');
    nClust = maxClust;
    clustList = clustList(1:nClust);
end
nRow = min([nRow maxRows]);
nCol = ceil(nClust/nRow);
panelHeight = vertSpace + nRow * (vertSpace + height);
panelWidth = horizSpace + nCol * (horizSpace + width);
figure('Position', [0.1*scrWidth 0.1*scrHeight panelWidth panelHeight]) %[left bottom width height]

spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = width/panelWidth;
ht = height/panelHeight;


% plot average waveforms ("templates")
for i = 1:nClust
    n = clustList(i);
    idx = find(arrayfun(@(x) x.id, cleanDat) == n);
    col = mod(i-1, nCol);
    row = floor((i - 0.5)/nCol);
    subplot('Position', [spH+col*(wd+spH) spV+(nRow-1-row)*(ht+spV)  wd ht]) %[left bottom width height]
    nSpk = length(cleanDat(idx).err);
    title(['unit ' num2str(n) ': ' num2str(nSpk) ' spikes'])
    hold on
    histogram(cleanDat(idx).err, binEdges);
    set(gca, 'YTick', []);
end