function waves = LoadUnitWaves(unit, baseDir, varargin)

unit = unit(1);
unitInfo = strsplit(unit.name, ' ');
trode = unitInfo{3};

[wL nChan] = size(unit.meanWaveform);
pk = unit.peakLoc;
uFs = unit.Fs;
tStart = unit.taskStart;
tEnd = unit.taskEnd;

% hard-code custom waveform stats here
wL = 72;

task = '';
batchSize = 32768;
verbose = true;
sincLength = 12;
nSamp = 50;
samp = [];

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'task'
            task = varargin{i+1};
        case 'nsamp'
            nSamp = varargin{i+1};
        case 'samp'
            samp = varargin{i+1};
        otherwise
            disp('Invalid optional argument passed to LoadUnitWaves')
    end
end

if isempty(task)
    task = unit.taskList;
end

datDir = cell(1, length(task));
dirNames = dir([baseDir filesep 'filtered']);

for i = 1:length(task)
    idx = find(arrayfun(@(d) strcmp(lower(d.name), lower(task{i})), dirNames));
    datDir{i} = [baseDir 'filtered' filesep dirNames(idx).name filesep];
end

% get the hsd header
hsdHeader = getHsdHeader_ver4([datDir{1} trode '.hsd']);
Fs = hsdHeader.sampling_rate;
bytesPerSample = hsdHeader.bytesPerSample;
dataOffset = hsdHeader.dataOffset;
vScale = hsdHeader.vScale;
upsample = round(uFs / Fs);
if upsample ~= 1
    disp('upsampling not yet supported by this function');
    return
end

spkLoc = cell(1, length(task));
tmpSpk = [];
taskIdx = zeros(1, length(task));
for i = 1:length(task)
   taskIdx(i) = find(cellfun(@(t) strcmp(t, task{i}), unit.taskList));
   spk = unit.spkTimes;
   tmpSpk = [tmpSpk spk(spk > tStart(taskIdx(i)) & spk < tEnd(taskIdx(i)))];
end
if strcmp(samp, 'all')
    samp = 1:length(tmpSpk);
elseif isempty(samp)
    samp = randsample(1:length(tmpSpk), min(nSamp, length(tmpSpk)));
end
tmpSpk = tmpSpk(samp);
waves = zeros(wL, nChan, length(samp));
n=1;
for i = 1:length(task)
    spkLoc = tmpSpk(tmpSpk > tStart(taskIdx(i)) & tmpSpk < tEnd(taskIdx(i)));
    spkLoc = round((spkLoc - tStart(taskIdx(i))) * Fs);
    f = fopen([datDir{i} trode '.hsd']);
    for k = 1:length(spkLoc)
        pos = dataOffset + (spkLoc(k) - pk) * nChan * bytesPerSample;
        fseek(f, pos, 'bof');
        waves(:,:,n) = double(fread(f, [nChan, wL], 'int16'))' * vScale;
        n = n + 1;
    %    waves = cat(3, waves, double(fread(f, [nChan, wL], 'int16'))' * vScale);
    end
    fclose(f);
end
