function spkDat = ManualSplit(spkDat, clust, varargin)

signal = 'snle';
timeRange = [0 Inf];
nChan = size(spkDat.waves, 2);
chan = [];
time = 0;
splitThr = 'auto';
bimThr = 0.1;
split = false;
pol = 1;
valRange = [0.005 0.995]; % in quantiles of signal value

nYbins = 100;
tBinWidth = 10; % seconds
tOverlap = 2;   % # of neighbor bins (in both directions)

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'signal'
            signal = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1};
        case 'chan'
            chan = varargin{i+1};
        case 'splitthr'
            splitThr = varargin{i+1};
        case 'bimthr'
            bimThr = varargin{i+1};    
        case 'split'
            split = varargin{i+1};
        case 'overlap'
            tOverlap = varargin{i+1};
        case 'thrpol'
            pol = varargin{i+1};
        case 'pol'
            pol = varargin{i+1};
        case 'binwidth'
            tBinWidth = varargin{i+1};
        case 'time'
            time = varargin{i+1};
        case 'numbins'
            nYbins = varargin{i+1};
        case 'valrange';
            valRange = varargin{i+1};
    end     
end

tR = timeRange * spkDat.Fs * 60; % convert timeRange from minutes to sample number
loc = find(spkDat.id == clust);
ts = spkDat.ts(loc);
loc = loc(ts >= tR(1) & ts <=tR(2));
ts = spkDat.ts(loc);

t1 = floor(ts(1)/(tBinWidth*spkDat.Fs)) * tBinWidth;
t2 = ceil(ts(end)/(tBinWidth*spkDat.Fs)) * tBinWidth;
tBinEdges = t1:tBinWidth:t2;
[~, ~, bin] = histcounts(ts / spkDat.Fs, tBinEdges);

thr = spkDat.spkThr(spkDat.chan(loc));
if nChan == 1
    thr = thr';
end

if strcmp(lower(signal), 'snle')
    signal = (spkDat.peakVal(loc)' - thr) ./ thr;
else
    [wL, nChan, ~] = size(spkDat.waves);
    pk = spkDat.peakLoc + spkDat.wavePad;
    vScale = spkDat.vScale;
    wvFs = spkDat.Fs * spkDat.upsample;
    t = 1000 * ((1:wL) - pk) / wvFs;
    if isempty(chan)
        chan = 1;
    end
    if length(time) == 1
        time = [time time];
    end
    [~, p1] = min(abs(t-time(1)));
    [~, p2] = min(abs(t-time(2)));
    signal = squeeze(mean(double(spkDat.waves(p1:p2, chan, loc)), 1)) * vScale;   
end

sigRange = quantile(signal, valRange);
yBins = linspace(sigRange(1), sigRange(2), nYbins + 1);
sigHist = zeros(length(tBinEdges) -1, nYbins);
bimScore = zeros(1, length(tBinEdges) - 1);
splitVal = zeros(1, length(tBinEdges) - 1);
if ~isempty(loc)
    for j = 1:length(bimScore)
        sigHist(j,:) = histcounts(signal(bin == j), yBins);
        sel = bin >= j-tOverlap & bin <=j+tOverlap;
        [bimScore(j) splitVal(j)] = Bimodality(signal(sel));
    end
end

if ~split
    sL = MakePanelPlot(2, 1);
    subplot('Position', sL(:,1)')
    hold on
    binCenters = (tBinEdges(2:end) - diff(tBinEdges)/2)/60;
    pcolor(binCenters,yBins(1:end-1),sigHist');
    shading interp;
    splitVal(bimScore < bimThr) = nan;
    plot(binCenters, splitVal, 'r', 'linewidth', 2)
    ylim([yBins(1) yBins(end)-diff(yBins([1 2]))])
    xlim(binCenters([1 end]))
    if isnumeric(splitThr)
        plot(binCenters([1 end]), [splitThr splitThr], '--w', 'linewidth', 1)
    end
    subplot('Position', sL(:,2)')
    hold on
    plot(binCenters, bimScore, 'k', 'linewidth', 2)
    yL = ylim;
    plot(binCenters([1 end]), [bimThr bimThr], '--r', 'linewidth', 1)
    xlim(binCenters([1 end]))
else
    id = max(spkDat.id) + 1;
    newLoc = [];
    for j = 1:length(bimScore)
        binSig = signal(bin == j);
        binLoc = loc(bin == j);
        if isnumeric(splitThr)
            newLoc = [newLoc binLoc(pol*binSig < pol*splitThr)];
        else
            newLoc = [newLoc binLoc(pol*binSig < pol*splitVal(j))];
        end
    end
    spkDat.id(newLoc) = id;
end
