function MergeReview(spkDat, mergeDat, varargin)

% convert waveform data from int16 to double-precision floating point
spkDat.waves = double(spkDat.waves);

maxScale = 1;
sameScale = true;
convertToVolt = true;
nSampTarget = 100;
showIdx = 1:size(mergeDat,1);
Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;
minIsi = 1;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nsamp'
            nSampTarget = varargin{i+1};
        case 'converttovolt'
            convertToVolt = varargin{i+1};
        case 'maxscale'
            maxScale = varargin{i+1};
        case 'showidx'
            showIdx = varargin{i+1};
        case 'samescale'
            sameScale = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to MergeReview');
    end
end

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
vScale = spkDat.vScale;
if isstruct(mergeDat)
    nClust = length(mergeDat);
    clustList = arrayfun(@(x) x.clust, mergeDat);
    dt = arrayfun(@(x) x.dt, mergeDat);
    dist = arrayfun(@(x) x.dist, mergeDat);
    chanList = mergeDat(1).chanList;
    refClust = mergeDat(1).refClust;
else
    refClust = mergeDat(1);
    clustList = mergeDat(2:end);
    nClust = length(clustList);
    dt = zeros(1, nClust);
    dist = nan(1, nClust);
    chanList = [];
end

if isequal(1:nChan, sort(chanList))
    chanList = [];
end

% assemble plot data, calculate y range
pts = (1:wL) + wP;
yRange = zeros(nClust, 2);
refLoc = find(spkDat.id == refClust);
refWave = mean(spkDat.waves(pts,:,refLoc), 3);
if convertToVolt
    refWave = vScale * refWave;
end
refRange = [min(min(refWave)) max(max(refWave))];
avgWave = zeros(wL, nChan, nClust);

samp = cell(1, nClust);
for i = 1:nClust
    
    % compute average waveform
    n = clustList(i);
    p = pts + dt(i);
    loc = find(spkDat.id == n);
    avgWave(:,:,i) = mean(spkDat.waves(p,:,loc), 3);
    if convertToVolt
        avgWave(:,:,i) = vScale * avgWave(:,:,i);
    end
    
    % select sample of waveforms to plot
    nSpk = length(loc);
    nSamp = min([nSampTarget nSpk]);    
    samp{i} = randsample(nSpk, nSamp);
    samp{i} = loc(samp{i});
    wv = spkDat.waves(pts,:,samp{i});
    wv = permute(wv, [2 1 3]);
    if convertToVolt
        wv = vScale * wv;
    end
    tmpMin = min([min(min(wv, [], 3)) refRange(1)]);
    tmpMax = max([max(max(wv, [], 3)) refRange(2)]);
    
    % compute yRange
    avgRange = max(range(avgWave(:,:,i)));
    yRange(i,1) = max([tmpMin, refRange(1) - avgRange * maxScale]);
    yRange(i,2) = min([tmpMax, refRange(2) + avgRange * maxScale]);
    
end

if sameScale
    yRange(:,1) = min([yRange(:,1)]);
    yRange(:,2) = max(yRange(:,2));
end

% autocorrelogram for reference cell
autoRef = CrossCorr(spkDat, refClust, refClust, 'binSpec', [400 0.5]);
autoRef.y = length(autoRef.y) * autoRef.y / sum(autoRef.y);

% make figure panel
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 26;
horizSpace = 35;
plotWidth = 300;
plotHeight = 280;
panelHeight = vertSpace + (nChan + 1) * (vertSpace + plotHeight);
panelWidth = horizSpace + nClust * (horizSpace + plotWidth);
fig = figure('Position', [100 500 panelWidth panelHeight]); %[left bottom width height];
spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = plotWidth/panelWidth;
ht = plotHeight/panelHeight;

% plot data for each cluster
t = 1000 * ((1:wL) - pk)/ wvFs;
for i = 1:nClust
    
    n = clustList(i);
    p = pts + dt(i);
    d = round(dist(i), 3);
  %  wv = zeros(wL, nChan, length(samp{i}));
  %  wv(p - dt(i),:,:) = spkDat.waves(p,:,samp{i});
    wv = spkDat.waves(p,:,samp{i});
    if convertToVolt
        wv = vScale * wv;
    end
    
    % compute ISI violation
    isi = 1000 * diff(spkDat.ts(refLoc)) / Fs;
    origViol = 100 * length(find(isi < minIsi)) / length(isi);
    addLoc = find(spkDat.id == n);
    newLoc = [refLoc addLoc];
    ts = sort(spkDat.ts(newLoc));
    isi = 1000 * diff(ts) / Fs;
    newViol = 100 * length(find(isi < minIsi)) / length(isi);
    
    % plot wire waveforms
    for w = 1:nChan
        yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
        subplot('Position', [spH+(i-1)*(wd+spH) spV+(nChan+1-w)*(ht+spV)  wd ht]) %[left bottom width height]
        if w==1
            title(['unit ' num2str(n) ' - dist: ' num2str(d) ', dt: ' num2str(1000*dt(i)/wvFs)])
            str = [num2str(origViol, 2) ' --> ' num2str(newViol, 2)];
            xLoc = 0.02*range(t) + t(1);
            yLoc = 0.95*range(yR) + yR(1);
            text(xLoc, yLoc, str, 'FontSize', 10, 'BackgroundColor', 'w', 'FontWeight', 'Bold', 'color', 'r');
        end
        hold on
        plot(t, squeeze(wv(:,w,:)), 'LineWidth', 1, 'color', 'k')
        plot(t, refWave(:,w), 'LineWidth', 3, 'color', 'g')
        plot(t, avgWave(:,w,i), 'LineWidth', 3, 'color', 'r')
        plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
        if ismember(w, chanList)
            scatter(t(1) + 0.99*range(t), yR(1) + 0.99*range(yR), 'r', 'filled') 
        end
        ylim(yR);
        xlim([t(1) t(end)])
    end
    
    % plot cross correlation with ref cell and ref autocorrelogram
    binSpec = [400 0.5];
    xc = CrossCorr(spkDat, n, refClust, 'binSpec', binSpec);
    xc.y = length(xc.y) * xc.y / sum(xc.y);
    subplot('Position', [spH+(i-1)*(wd+spH) spV  wd ht]) %[left bottom width height]
    hold on
    plot(xc.t, xc.y, 'LineWidth', 1, 'color', 'b')
    plot(autoRef.t, autoRef.y, 'LineWidth', 1, 'color', 'r')
    xlim([xc.t(1) xc.t(end)])
    ax = gca;
    ax.YTick = [];
    ax.XLabel.String = 'time (ms)';
end
