function PlotEventData(trodeFile, t0, timeWin, varargin)

fig = [];
titleBase = '';
returnData = false;
makePlot = true;
dataType = 'int16';

hsdInfo    = dir(trodeFile);
hsdHeader  = getHsdHeader_ver4( trodeFile );
Fs         = hsdHeader.sampling_rate;
dataOffset = hsdHeader.dataOffset;
numWires   = hsdHeader.num_channels;   % total number of wires in the .hsd file
bytes_per_sample = hsdHeader.bytesPerSample;
datalength = (hsdInfo.bytes - dataOffset) / (bytes_per_sample * numWires);
wireList = 1:numWires;
vS = hsdHeader.vScale;

for i = 1:2:length(varargin)
    switch varargin{i}
        case 'returnData'
            returnData = varargin{i+1};
        case 'makePlot'
            makePlot = varargin{i+1};
        case 'fig'
            fig = varargin{i+1};
        case 'title'
            titleBase = varargin{i+1};
        case 'wireList'
            wireList = varargin{i+1};    
    end
            
end

[pathstr trodeStr ext] = fileparts(trodeFile);
    sL = MakePanelPlot(length(wireList), 1, 'yGap', 10, 'figName', trodeStr, 'size', [480 480]);

nTr = length(t0);
yR = [Inf -Inf];
for n = 1:nTr
    
% load data from hsd file
win = t0(n) + timeWin;
win(1) = max(win(1), 0);
win(2) = min(win(2), datalength/Fs);
startSample = floor(win(1) * Fs) + 1;
numSamples = round(diff(win) * Fs);
data = readHSD(trodeFile, numWires, dataOffset, Fs, [], 'usesamplelimits', [startSample, numSamples]);
times = timeWin(1) + (1:numSamples)/Fs;
y1 = vS*min(min(data));
y2 = vS*max(max(data));
yRtmp = [y1 - 0.1*(y2-y1) y2 - 0.1*(y2-y1)];
yR = [min([yR(1) yRtmp(1)]) max([yR(2) yRtmp(2)])];

    
    for i = 1:length(wireList)
        k = wireList(i);
        subplot('Position', sL(:,i)')
        hold on
        plot(times, vS * data(k,:))
        ax = gca;
        ax.Box = 'on';
        if i < length(wireList)
            ax.XTickLabel = [];
        else
            xlabel('seconds')
        end
        ax.XGrid = 'on';
        ylabel('mV')
        xlim(timeWin)
    end    
end