function PlotPeakDistribution(spkDat,varargin)


    h=figure('units','normalized','outerposition',[0 0 1 1]);

spkDat.waves = double(spkDat.waves);

maxScale = Inf;
refWave = [];
sameScale = false;
showMean = true;
convertToVolt = true;
quantiles = [];
minIsi = 1; % in milliseconds
nSampTarget = 500;
rateBin = 10;
timeRange = [0 Inf];
clustList = 1:length(unique(spkDat.id));
Fs = spkDat.Fs;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'showmean'
            showMean = varargin{i+1};
        case 'converttovolt'
            convertToVolt = varargin{i+1};
        case 'maxscale'
            maxScale = varargin{i+1};
        case 'compare'
            refWave = varargin{i+1}; % should have dimensions (nSamples, nChan)
        case 'samescale'
            sameScale = varargin{i+1};
        case 'quantiles'
            quantiles = varargin{i+1};
        case 'minisi'
            minIsi = varargin{i+1};
        case 'nsamp'
            nSampTarget = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1}; % recording time range to plot, in minutes
        case 'clust'
            clustList = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to PlotClusters');
    end
end

clustList = intersect(clustList, setdiff(unique(spkDat.id), 0));
nClust = length(clustList);
[wL, nChan, ~] = size(spkDat.waves);
vScale = spkDat.vScale;
pk = spkDat.peakLoc;
[wL, nChan, ~] = size(spkDat.waves);
wP = spkDat.wavePad;
wL = wL - 2*wP;
pts = (1:wL) + wP;

for i = 1:nClust
    
    % compute average waveform
    n = clustList(i);
    loc{i} = find(spkDat.id == n);
    
    nSpk = length(loc{i});
    if nSpk > 0
        avgWave(:,:,i) = mean(spkDat.waves(pts,:,loc{i}), 3);
    end
    if convertToVolt
        avgWave(:,:,i) = vScale * avgWave(:,:,i);
    end
    
    [~, maxChan] = max(abs(avgWave(pk,:,i)));

    
    subplot(2,nClust,i)
    [n xout] = hist(spkDat.peakVal(loc{i}),0:5:2000);
    bar(xout,n,1,'FaceColor','b','EdgeColor','b');xlim([0 200])
    hold on;
    for iWire = maxChan%1:nChan
        line([spkDat.spkThr(iWire) spkDat.spkThr(iWire)],[0 max(n)],'linestyle','--','color','r')
    end
    title(['Unit ',num2str(clustList(i))],'FontSize',16)
    
    

    subplot(2,nClust,i+nClust)

      % plot firing rate and spike amplitude
    t1 = 0;
    if isfinite(timeRange(1))
        t1 = timeRange(1);
    end
    if isfinite(timeRange(2))
        t2 = timeRange(2);
    elseif length(spkDat.ts) > 0
        t2 = ceil(spkDat.ts(end)/(rateBin*Fs))*rateBin;
    else
        t2 = 0;
    end
    if (t2 - t1) / rateBin < 20
        rateBin = (t2 - t1) / 20;
    end
    spkTimes = [];
    if length(loc{i} > 2)
        spkTimes = spkDat.ts(loc{i}) / Fs;
    end
    binEdges = t1:rateBin:t2;
    [rate, ~, bin] = histcounts(spkTimes, binEdges);     rate = rate / rateBin;
    binCenters = (binEdges(2:end) - diff(binEdges)/2)/60;
    ampl =[];
    if ~isempty(loc{i})
        pol = sign(avgWave(pk,maxChan,i));
        for j = 1:length(rate)
            ampl(j,:) = hist(spkDat.peakVal(loc{i}(bin == j)),0:5:2000);
            medAmp(j) = nanmedian(spkDat.peakVal(loc{i}(bin == j)));
        end
    end
    pcolor(binCenters,0:5:2000,ampl');ylim([0 200]);hold on
    plot(binCenters,medAmp,'color','w')
    for iWire = maxChan%1:nChan
        line([0 max(n)],[spkDat.spkThr(iWire) spkDat.spkThr(iWire)],'linestyle','--','color','r','linewidth',2)
    end
      for task=1:length(spkDat.taskEnd)-1
            line([spkDat.taskEnd(task)/60 spkDat.taskEnd(task)/60],[0 200],'linestyle','--','color','y','linewidth',2)
        end
    
     shading interp;
end

set(h,'color','w')

end