function PlotTemplates(spkDat, varargin)

% convert waveform data from int16 to double-precision floating point
spkDat.waves = double(spkDat.waves);

sameScale = true;
convertToVolt = true;
clustList = setdiff(unique(spkDat.id), 0);
clustListIn = clustList;

for i = 1:2:length(varargin)
    switch varargin{i}
        case 'convertToVolt'
            convertToVolt = varargin{i+1};
        case 'sameScale'
            sameScale = varargin{i+1};
        case 'clust'
            clustListIn = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to PlotTemplates');
    end
end

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
vScale = spkDat.vScale;
clustList = intersect(clustList, clustListIn);
nClust = length(clustList);

% compute average waveforms for each cluster
pts = (1:wL) + wP;
template = zeros(wL, nChan, nClust);
nSpk = zeros(nClust, 1);
yRange = zeros(nClust, 2);
for i = 1:nClust
    n = clustList(i);
    loc = find(spkDat.id == n);
    nSpk(i) = length(loc);
    template(:,:,i) = mean(spkDat.waves(pts, :, loc), 3);
    if convertToVolt
        template(:,:,i) = vScale * template(:,:,i);
    end
    yRange(i,1) = min(min(template(:,:,i)));
    yRange(i,2) = max(max(template(:,:,i)));
end

if sameScale
    yRange(:,1) = min(yRange(:,1));
    yRange(:,2) = max(yRange(:,2));
end

% make figure panel
nRow = round(sqrt(nClust));
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 35;
horizSpace = 35;
height = 300;
width = 330;
maxPanelHt = 0.8 * scrHeight;
maxPanelWd = 0.8 * scrWidth;
maxRows = floor((maxPanelHt - vertSpace) / (height + vertSpace));
maxColumns = floor((maxPanelWd - horizSpace) / (width + horizSpace));
maxClust = maxRows * maxColumns;
if nClust > maxClust
    disp('** WARNING: not enough space to plot all clusters **');
    nClust = maxClust;
    clustList = clustList(1:nClust);
end
nRow = min([nRow maxRows]);
nCol = ceil(nClust/nRow);
panelHeight = vertSpace + nRow * (vertSpace + height);
panelWidth = horizSpace + nCol * (horizSpace + width);
figure('Position', [0.1*scrWidth 0.1*scrHeight panelWidth panelHeight]) %[left bottom width height]

spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = width/panelWidth;
ht = height/panelHeight;

% plot average waveforms ("templates")
t = 1000 * ((1:wL) - pk)/spkDat.Fs;
for i = 1:nClust
    col = mod(i-1, nCol);
    row = floor((i - 0.5)/nCol);
    subplot('Position', [spH+col*(wd+spH) spV+(nRow-1-row)*(ht+spV)  wd ht]) %[left bottom width height]
    title(['unit ' num2str(clustList(i)) ': ' num2str(nSpk(i)) ' spikes'])
    hold on
    plot(t, template(:,:,i), 'LineWidth', 2)
    yR = yRange(i,:) + range(yRange(i,:)) * [-0.05 0.05];
    plot([0 0], yR, 'LineWidth', 1, 'color', 'k')
    ylim(yR);
    xlim([t(1) t(end)])
end