function data = PlotTrodeData(trodeFile, timeWin, varargin)

fig = [];
titleBase = '';
returnData = false;
makePlot = true;
dataType = 'int16';

hsdInfo    = dir(trodeFile);
hsdHeader  = getHsdHeader_ver4( trodeFile );
Fs         = hsdHeader.sampling_rate;
dataOffset = hsdHeader.dataOffset;
numWires   = hsdHeader.num_channels;   % total number of wires in the .hsd file
bytes_per_sample = hsdHeader.bytesPerSample;
datalength = (hsdInfo.bytes - dataOffset) / (bytes_per_sample * numWires);
wireList = 1:numWires;
vS = hsdHeader.vScale;

for i = 1:2:length(varargin)
    switch varargin{i}
        case 'returnData'
            returnData = varargin{i+1};
        case 'makePlot'
            makePlot = varargin{i+1};
        case 'fig'
            fig = varargin{i+1};
        case 'title'
            titleBase = varargin{i+1};
        case 'wireList'
            wireList = varargin{i+1};    
    end
            
end

% load data from hsd file
timeWin(1) = max(timeWin(1), 0);
timeWin(2) = min(timeWin(2), datalength/Fs);
startSample = floor(timeWin(1) * Fs) + 1;
numSamples = round(diff(timeWin) * Fs);
data = readHSD(trodeFile, numWires, dataOffset, Fs, [], 'usesamplelimits', [startSample, numSamples]);
times = timeWin(1) + (1:numSamples)/Fs;
y1 = vS*min(min(data));
y2 = vS*max(max(data));
yR = [y1 - 0.1*(y2-y1) y2 - 0.1*(y2-y1)];

if makePlot
    [pathstr trodeStr ext] = fileparts(trodeFile);
    sL = MakePanelPlot(length(wireList), 1, 'yGap', 10, 'figName', trodeStr, 'size', [480 480]);
    for i = 1:length(wireList)
        k = wireList(i);
        subplot('Position', sL(:,i)')
        plot(times, vS * data(k,:))
        ax = gca;
        ax.Box = 'on';
        if i < length(wireList)
            ax.XTickLabel = [];
        else
            xlabel('seconds')
        end
        ax.XGrid = 'on';
        ylabel('mV')
        xlim(timeWin)
    end    
    hold off
end

if ~returnData
    clear data;
else
    data = vS * data;
end