function ReclassifyReview(spkDat, reclassDat, varargin)

% convert waveform data from int16 to double-precision floating point
spkDat.waves = double(spkDat.waves);

minIsi = 1;
[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
vScale = spkDat.vScale;
maxScale = 1;
sameScale = true;
convertToVolt = true;
nSampTarget = 100;
errorRange = [-Inf Inf];
if(length(reclassDat) > 1)
    disp('Only displaying 1st reclassified cluster of reclassDat')
    reclassDat = reclassDat(1);
end
origClust = reclassDat.id(1);
clustList = reclassDat.id(2:end);
nClust = length(clustList);
chanList = reclassDat.chanList;
if isequal(1:nChan, sort(chanList))
    chanList = [];
end
showIdx = 1:nClust;
minErrorOnly = true;
Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nsamp'
            nSampTarget = varargin{i+1};
        case 'converttovolt'
            convertToVolt = varargin{i+1};
        case 'maxscale'
            maxScale = varargin{i+1};
        case 'showidx'
            showIdx = varargin{i+1};
        case 'samescale'
            sameScale = varargin{i+1};
        case 'error'
            errorRange = varargin{i+1};
        case 'minerroronly'
            minErrorOnly = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to ReclassifyReview');
    end
end

minSamp = nSampTarget;
minSamp = 1;



if length(errorRange) == 1
    errorRange = [-Inf errorRange];
end
minDt = min(min(reclassDat.dt));
maxDt = max(max(reclassDat.dt));

% reclassify waves
if minErrorOnly
    [~,idLoc] = min(reclassDat.error');
    rcLoc = arrayfun(@(x) find(idLoc == x), 2:nClust+1, 'UniformOutput', false);
else
    rcLoc{1} = 1:length(reclassDat.loc);
end
for i = 1:nClust
    error{i} = reclassDat.error(rcLoc{i}, i+1);
    loc = find(error{i} >= errorRange(1) & error{i} <= errorRange(2));
    rcLoc{i} = rcLoc{i}(loc);
    error{i} = error{i}(loc);
end
nRc = cellfun(@(x) length(x), rcLoc);
[nRc, iSort] = sort(nRc, 'descend');
iSort = iSort(showIdx);
nRc = nRc(showIdx);
rcLoc = rcLoc(iSort);
error = error(iSort);
clustList = clustList(iSort);
delIdx = find(nRc < minSamp);
nRc(delIdx) = [];
rcLoc(delIdx) = [];
error(delIdx) = [];
clustList(delIdx) = [];
nClust = length(clustList);

% compile data on error in original cluster
nsLoc = find(reclassDat.dt(:,1) == 0);
origError = reclassDat.error(nsLoc, 1);
maxErr = quantile(origError(origError<Inf), 0.99);
errBinEdges = linspace(0, maxErr, 101);
oeAll = histcounts(origError, errBinEdges);
oeAll = oeAll / sum(oeAll);
errBinCenters = errBinEdges(2:end) - diff(errBinEdges);

% assemble plot data, calculate y Range
pts = (1:wL) + wP;
yRange = zeros(nClust, 2);
loc = find(spkDat.id == origClust);
origClustAvg = mean(spkDat.waves(pts,:,loc), 3);
if convertToVolt
    origClustAvg = vScale * origClustAvg;
end
refRange = [min(min(origClustAvg)) max(max(origClustAvg))];

newClustAvg = zeros(wL, nChan, nClust);
samp = cell(1, nClust);
samp2 = cell(1, nClust);
dt = cell(1, nClust);
neAll = zeros(nClust, length(errBinCenters));
oeRc = zeros(nClust, length(errBinCenters));
for i = 1:nClust
    
    % compute average waveform for destination cluster
    n = clustList(i);
    m = find(reclassDat.id == n);
    loc = find(spkDat.id == n);
    newClustAvg(:,:,i) = mean(spkDat.waves(pts,:,loc), 3);
    if convertToVolt
        newClustAvg(:,:,i) = vScale * newClustAvg(:,:,i);
    end
    
    % select sample of waveforms to plot
    dt{i} = reclassDat.dt(rcLoc{i}, m);
    idx = reclassDat.loc(rcLoc{i});    
    nSpk = length(idx);
    nSamp = min([nSampTarget nSpk]);    
    samp2{i} = randsample(nSpk, nSamp);
    samp{i} = idx(samp2{i});
    
    % get full distribution of error in destination cluster
    neAll(i,:) = histcounts(reclassDat.error(:,m), errBinEdges);
    neAll(i,:) = neAll(i,:) / sum(neAll(i,:));
    oeRc(i,:) = histcounts(reclassDat.error(rcLoc{i}, 1), errBinEdges);
    oeRc(i,:) = oeRc(i,:) / sum(oeRc(i,:));
    
    % get yRange of sampled waveforms
    wv = spkDat.waves(pts,:,samp{i});
    wv = permute(wv, [2 1 3]);
    if convertToVolt
        wv = vScale * wv;
    end
    tmpMin = min([min(min(wv, [], 3)) refRange(1)]);
    tmpMax = max([max(max(wv, [], 3)) refRange(2)]);
    
    % compute plot yRange
    avgRange = max(range(newClustAvg(:,:,i)));
    yRange(i,1) = max([tmpMin, refRange(1) - avgRange * maxScale]);
    yRange(i,2) = min([tmpMax, refRange(2) + avgRange * maxScale]);
    
end

if sameScale
    yRange(:,1) = min([yRange(:,1)]);
    yRange(:,2) = max(yRange(:,2));
end

% make figure panel
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 26;
horizSpace = 35;
plotWidth = 300;
plotHeight = 280;
panelHeight = vertSpace + (nChan + 1) * (vertSpace + plotHeight);
panelWidth = horizSpace + 2 * nClust * (horizSpace + plotWidth);
fig = figure('Position', [100 500 panelWidth panelHeight]); %[left bottom width height];
spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = plotWidth/panelWidth;
ht = plotHeight/panelHeight;

% plot data for each cluster
t = 1000 * ((1:wL) - pk)/wvFs;
for i = 1:nClust
    
    % 1) unshifted waves in original cluster
    n = clustList(i);
    wv = spkDat.waves(pts, :, samp{i});
    if convertToVolt
        wv = vScale * wv;
    end
    col = 2 * (i-1) + 1;
    
    % plot wire waveforms
    for w = 1:nChan
        subplot('Position', [spH+(col-1)*(wd+spH) spV+(nChan+1-w)*(ht+spV)  wd ht]) %[left bottom width height]
        if w==1
            nSpk = length(find(spkDat.id == origClust));
            title(['original unit ' num2str(origClust) ': ' num2str(nSpk) ' spikes'])
        end
        hold on
        plot(t, squeeze(wv(:,w,:)), 'LineWidth', 1, 'color', 'k')
        plot(t, origClustAvg(:,w), 'LineWidth', 3, 'color', 'r')
        yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
        plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
        if ismember(w, chanList)
            scatter(t(1) + 0.99*range(t), yR(1) + 0.99*range(yR), 'r', 'filled') 
        end
        ylim(yR);
        xlim([t(1) t(end)])
    end
    
    % 2) shifted waves in new cluster
    col = 2*i;
    
    % compute shifted waveforms
    wvNew = zeros(size(wv));
    dtTmp = dt{i}(samp2{i});
    for k = 1:length(samp{i})
        p = pts + dtTmp(k);
        p(p < 1) = [];
        p(p > wL + 2*wP) = [];
        wvNew(p - dtTmp(k) - wP, :, k) = spkDat.waves(p, :, samp{i}(k));
    end
    if convertToVolt
        wvNew = vScale * wvNew;
    end
    
    % compute ISI violation
    origLoc = find(spkDat.id == n);
    isi = 1000 * diff(spkDat.ts(origLoc)) / Fs;
    origViol = 100 * length(find(isi < minIsi)) / length(isi);
    newLoc = [origLoc reclassDat.loc(rcLoc{i})];
    ts = sort(spkDat.ts(newLoc));
    isi = 1000 * diff(ts) / Fs;
    newViol = 100 * length(find(isi < minIsi)) / length(isi);
    
    % plot wire waveforms
    for w = 1:nChan
        subplot('Position', [spH+(col-1)*(wd+spH) spV+(nChan+1-w)*(ht+spV)  wd ht]) %[left bottom width height]
        yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
        if w==1
            title(['new unit ' num2str(n) ': ' num2str(nRc(i)) ' reclassified spikes'])
            str = [num2str(origViol, 2) ' --> ' num2str(newViol, 2)];
            xLoc = 0.02*range(t) + t(1);
            yLoc = 0.95*range(yR) + yR(1);
            text(xLoc, yLoc, str, 'FontSize', 10, 'BackgroundColor', 'w', 'FontWeight', 'Bold', 'color', 'r');
        end
        hold on
        plot(t, squeeze(wvNew(:,w,:)), 'LineWidth', 1, 'color', 'k')
        plot(t, newClustAvg(:,w,i), 'LineWidth', 3, 'color', 'r')
        plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
        if ismember(w, chanList)
            scatter(t(1) + 0.99*range(t), yR(1) + 0.99*range(yR), 'r', 'filled') 
        end
        ylim(yR);
        xlim([t(1) t(end)])
    end
    
    % error histogram, all waveforms
    l0 = spH + 2*(i-1) * (wd+spH);
    wd2 = 0.39 * 2 * wd;
    subplot('Position', [l0 spV wd2 ht]) %[left bottom width height]
    set(gca, 'YTick', [])
    set(gca, 'Box', 'on')
    hold on
    plot(errBinCenters, oeAll, 'LineWidth', 2, 'color', 'b')
    plot(errBinCenters, neAll(i,:), 'LineWidth', 2, 'color', 'r')  
    xlim([errBinCenters(1) errBinCenters(end)])
    xlabel('error');
    xr = xlim;
    yr = ylim;
    str = 'orig unit (all waves)';
    text(0.98*range(xr) + xr(1), 0.95*range(yr) + yr(1), str, 'FontSize', 10, 'BackgroundColor', 'w', 'FontWeight', 'Bold', 'color', 'b', 'HorizontalAlignment', 'right');
    str = 'new unit (all waves)';
    text(0.98*range(xr) + xr(1), 0.9*range(yr) + yr(1), str, 'FontSize', 10, 'BackgroundColor', 'w', 'FontWeight', 'Bold', 'color', 'r', 'HorizontalAlignment', 'right');
    
    % error histogram, reclassified waves
    subplot('Position', [l0 + wd2 + 0.0015 spV wd2 ht]) %[left bottom width height]
    set(gca, 'YTick', [])
    set(gca, 'Box', 'on')
    hold on
    plot(errBinCenters, oeRc(i,:), 'LineWidth', 2, 'color', 'b')
    neRc = histcounts(error{i}, errBinEdges);
    neRc = neRc / sum(neRc);
    plot(errBinCenters, neRc, 'LineWidth', 2, 'color', 'r')
    xlim([errBinCenters(1) errBinCenters(end)])
    xlabel('error');
    yr = ylim;
    str = 'orig unit (reclassified waves)';
    text(0.98*range(xr) + xr(1), 0.95*range(yr) + yr(1), str, 'FontSize', 10, 'BackgroundColor', 'w', 'FontWeight', 'Bold', 'color', 'b', 'HorizontalAlignment', 'right');
    str = 'new unit (reclassified waves)';
    text(0.98*range(xr) + xr(1), 0.9*range(yr) + yr(1), str, 'FontSize', 10, 'BackgroundColor', 'w', 'FontWeight', 'Bold', 'color', 'r', 'HorizontalAlignment', 'right');
    
    % dt histogram
    wd3 = 0.25 * 2 * wd;
    subplot('Position', [l0 + 2*wd2 + 0.003 spV wd3 ht]) %[left bottom width height]
    hold on
    xlim([minDt maxDt])
    histogram(dt{i})
    set(gca, 'YTick', [])
    set(gca, 'Box', 'on')
    plot([0 0], ylim, 'LineWidth', 1, 'color', 'k')
    xlabel('dt (timesteps)');
    
end
