function reclassDat = ReclassifyTest(spkDat, varargin)

spkDat.waves = double(spkDat.waves);
[wL, nChan, ~] = size(spkDat.waves);
chanList = 1:nChan;
clustList = setdiff(unique(spkDat.id), 0);
shift = [-0.2 0.2];
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
win = 1000 * [1 - pk wL - pk] / (spkDat.Fs * spkDat.upsample);
winIn = 'auto';
destClust = [];
sourceClust = [];
sdCriterion = 0.5;
winPad = 0.12;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'destclust'
            destClust = varargin{i+1};
        case 'sourceclust'
            sourceClust = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'shift'
            shift = varargin{i+1};
        case 'win'
            winIn = varargin{i+1};
        case 'sdcriterion'
            sdCriterion = varargin{i+1};
        case 'winpad'
            winPad = varargin{i+1};            
    end
end

nChanIn = length(chanList);
if isempty(destClust)
    destClust = clustList;
end
if isempty(sourceClust)
    sourceClust = clustList;
end
clustList = union(destClust, sourceClust);
shift = round(shift * (spkDat.Fs * spkDat.upsample) / 1000);
shift(1) = max(shift(1), -wP);
shift(2) = min(shift(2), wP);
shift = shift(1):shift(2);
winPad = round(winPad * spkDat.Fs / 1000); % convert from ms to sample #

% determine time window over which templates are compared
maxWin = [1 - pk, wL - pk];
win = zeros(nChan, 2);
win(:,2) = -1;
if isnumeric(winIn) % use a user-specified window
    winIn = round(spkDat.Fs * spkDat.upsample * winIn / 1000);
    winIn(1) = max([winIn(1) maxWin(1)]);
    winIn(2) = min([winIn(2) maxWin(2)]);
    win(chanList, :) = repmat(winIn, nChanIn, 1);
elseif strcmp(winIn, 'auto') % generate consensus window covering important parts of all destClust
    clustAvg = zeros(wL, nChan, length(clustList));
    for i = 1:length(clustList)
        loc = find(spkDat.id == clustList(i));
        clustAvg(:,:,i) = mean(spkDat.waves((1:wL) + wP, :, loc),3);
    end
    
    for w = chanList
        winPts = [];
        tmp = abs(squeeze(clustAvg(:,w,:)) / spkDat.wireSd(w));
        for i = 1:length(clustList)
            winPts = union(winPts, find(tmp(:,i) > sdCriterion));
        end
        if isempty(winPts)
            win(w,:) = [0 -1];
        else
            win(w,:) = [winPts(1)-winPad winPts(end)+winPad] - pk;
        end
        win(w,1) = max([win(w,1) maxWin(1)]);
        win(w,2) = min([win(w,2) maxWin(2)]);
    end
end

pts = [];
for i = 1:nChan
    pts = [pts, (win(i,1):win(i,2)) + pk + wP + (i-1)*(wL + 2*wP)];
end
nPts = length(pts);
msWin = [min(win(:,1)) + shift(1) max(win(:,2)) + shift(end)] + pk + wP;


% generate templates
sd = [];
for i = 1:nChan
    sd = [sd; ones(wL + 2*wP, 1) * spkDat.wireSd(i)];
end
template = zeros(nPts, length(clustList));
for i = 1:length(clustList)
    loc = find(spkDat.id == clustList(i));
    tmp = mean(spkDat.waves(:, :, loc), 3);
    m = mean(tmp(msWin(1):msWin(2), :));
    tmp = bsxfun(@minus, tmp, m);
    tmp = reshape(tmp, (wL + 2*wP)*nChan, 1) ./ sd;
    template(:,i) = tmp(pts);
end

nShift = length(shift);
p = bsxfun(@plus, pts, shift');
p = reshape(p, nPts*nShift, 1);

% compare spikes in designated clusters to reference templates
for i = 1:length(sourceClust)
    
    tmpList = [sourceClust(i) setdiff(destClust, sourceClust(i))];
    reclassDat(i).id = tmpList;
    reclassDat(i).chanList = chanList;
    reclassDat(i).win = win;
    loc = find(spkDat.id == sourceClust(i));
    reclassDat(i).loc = loc;
    reclassDat(i).dt = zeros(length(loc), length(tmpList));
    reclassDat(i).error = zeros(length(loc), length(tmpList));
    
    % assess matches of waveforms to templates
    minLoc = zeros(1, length(tmpList));
    error = zeros(1, length(tmpList));
    for k = 1:length(loc)
        
        % align waveform to each template in tmpList using mean squared error
        wv = spkDat.waves(:, :, loc(k));
        m = mean(wv(msWin(1):msWin(2), :));
        wv = bsxfun(@minus, wv, m);
        wv = reshape(wv, (wL + 2*wP)*nChan, 1) ./ sd;
        wv = wv(p);
        wv = reshape(wv, nShift, nPts);        
        [~, n] = ismember(tmpList, clustList);
        for j = 1:length(tmpList)
            err = bsxfun(@minus, wv, template(:, n(j))');
            err = mean(err.^2, 2);
            tmpLoc = find(err == min(err));
            minLoc(j) = tmpLoc(1);
            error(j) = err(tmpLoc(1));
        end
        dt = shift(minLoc);
        reclassDat(i).dt(k,:) = dt;
        reclassDat(i).error(k,:) = error;

    end
    
end