function reclassDat = ReclassifyTestTmp(spkDat, varargin)

% spkDat.waves = double(spkDat.waves);
[wL, nChan, ~] = size(spkDat.waves);
chanList = 1:nChan;
clustList = setdiff(unique(spkDat.id), 0);
shift = [-0.2 0.2];
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
win = 1000 * [1 - pk wL - pk] / (spkDat.Fs * spkDat.upsample);
winIn = 'auto';
destClust = [];
sourceClust = [];
sdCriterion = 0.5;
winPad = 0.12;
timeRange = [0 Inf];
timeRangeSource = [];
timeRangeDest = [];
forceRC = true;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'destclust'
            destClust = varargin{i+1};
        case 'sourceclust'
            sourceClust = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'shift'
            shift = varargin{i+1};
        case 'win'
            winIn = varargin{i+1};
        case 'sdcriterion'
            sdCriterion = varargin{i+1};
        case 'winpad'
            winPad = varargin{i+1};   
        case 'timerange'
            timeRange = varargin{i+1};
        case 'timerangesource'
            timeRangeSource = varargin{i+1};    
        case 'timerangedest'
            timeRangeDest = varargin{i+1};
        case 'forcereclassify'
            forceRC = varargin{i+1};
    end
end

if isempty(timeRangeSource)
    timeRangeSource = timeRange;
end
if isempty(timeRangeDest)
    timeRangeDest = timeRange;
end

nChanIn = length(chanList);
if isempty(destClust)
    destClust = clustList;
end
if isempty(sourceClust)
    sourceClust = clustList;
end

destClust = intersect(destClust, clustList);
sourceClust = intersect(sourceClust, clustList);
% clustList = union(sourceClust, destClust);

% generate templates for destination clusters
sd = [];
for i = 1:nChan
    sd = [sd ones(wL + 2*wP, 1) * spkDat.wireSd(i)];
end
trDest = timeRangeDest * 60 *spkDat.Fs; % convert time range from minutes to sample #
templateD = zeros(wL + 2*wP, nChan, length(destClust));
locTime = find(spkDat.ts >= trDest(1) & spkDat.ts <= trDest(2));
for i = 1:length(destClust)
    loc = intersect(locTime, find(spkDat.id == destClust(i)));
    templateD(:,:,i) = mean(spkDat.waves(:,:,loc), 3) ./ sd;
end

% generate templates for source clusters (if needed)
trSource = timeRangeSource * 60 *spkDat.Fs; % convert time range from minutes to sample #
locTime = find(spkDat.ts >= trSource(1) & spkDat.ts <= trSource(2));
if forceRC
    tmpl = templateD;
else
    templateS = zeros(wL + 2*wP, nChan, length(sourceClust));
    for i = 1:length(sourceClust)
        loc = intersect(locTime, find(spkDat.id == sourceClust(i)));
        templateS(:,:,i) = mean(spkDat.waves(:,:,loc), 3) ./ sd;
    end
    tmpl = cat(3, templateD, templateS);
end

% determine time window over which templates are compared
maxWin = [1 - pk, wL - pk];
winPad = round(winPad * spkDat.Fs / 1000); % convert from ms to sample #
win = zeros(nChan, 2);
win(:,2) = -1;
if isnumeric(winIn) % use a user-specified window
    winIn = round(spkDat.Fs * spkDat.upsample * winIn / 1000);
    winIn(1) = max([winIn(1) maxWin(1)]);
    winIn(2) = min([winIn(2) maxWin(2)]);
    win(chanList, :) = repmat(winIn, nChanIn, 1);
elseif strcmp(winIn, 'auto') % generate consensus window covering important parts of all destClust 
    for w = chanList
        winPts = [];
        tmp = abs(squeeze(tmpl(:,w,:)));
        for i = 1:length(destClust)
            winPts = union(winPts, find(tmp(:,i) > sdCriterion));
        end
        if isempty(winPts)
            win(w,:) = [0 -1];
        else
            win(w,:) = [winPts(1)-winPad winPts(end)+winPad] - pk - wP;
        end
        win(w,1) = max([win(w,1) maxWin(1)]);
        win(w,2) = min([win(w,2) maxWin(2)]);
    end
end

% generate list of timeshifts to consider (in units of point #)
shift = round(shift * (spkDat.Fs * spkDat.upsample) / 1000);
shift(1) = max(shift(1), -wP);
shift(2) = min(shift(2), wP);
shift = shift(1):shift(2);
zeroShift = find(shift == 0);

% mean-subtract templates 
msWin = [min(win(:,1)) + shift(1) max(win(:,2)) + shift(end)] + pk + wP;
for i = 1:length(destClust)
     m = mean(templateD(msWin(1):msWin(2), :, i));
     templateD(:,:,i) = bsxfun(@minus, templateD(:,:,i), m);
end
if ~forceRC
    for i = 1:length(sourceClust)
         m = mean(templateS(msWin(1):msWin(2), :, i));
         templateS(:,:,i) = bsxfun(@minus, templateS(:,:,i), m);
    end
end

% make each template 1-D, using only points inside windows of interest
pts = [];
for i = 1:nChan
    pts = [pts, (win(i,1):win(i,2)) + pk + wP + (i-1)*(wL + 2*wP)];
end
nPts = length(pts);
templateD = reshape(templateD, (wL + 2*wP)*nChan, []);
templateD = templateD(pts,:);
if ~forceRC
    templateS = reshape(templateS, (wL + 2*wP)*nChan, []);
    templateS = templateS(pts,:);
end
nShift = length(shift);
p = bsxfun(@plus, pts, shift');
p = reshape(p, nPts*nShift, 1);
sd = reshape(sd, (wL + 2*wP)*nChan, 1);

% extract waveforms of source clusters [INCOMPLETE]
locActive = intersect(locTime, find(ismember(spkDat.id, sourceClust)));
id = spkDat.id(locActive);
waves = double(spkDat.waves(:,:,locActive));

% compare spikes in designated clusters to reference templates
for i = 1:length(sourceClust)
    
    tmpList = [sourceClust(i) destClust];
    reclassDat(i).id = tmpList;
    reclassDat(i).chanList = chanList;
    reclassDat(i).win = win;
    loc = find(id == sourceClust(i));
    reclassDat(i).loc = locActive(loc);
    reclassDat(i).dt = zeros(length(loc), length(tmpList));
    reclassDat(i).error = zeros(length(loc), length(tmpList));
    
    % assess matches of waveforms to templates
    minLoc = zeros(1, length(tmpList));
    error = zeros(1, length(tmpList));
    for k = 1:length(loc)
        
        % align waveform to each template in tmpList using mean squared error
        wv = waves(:, :, loc(k));
        m = mean(wv(msWin(1):msWin(2), :));
        wv = bsxfun(@minus, wv, m);
        wv = reshape(wv, (wL + 2*wP)*nChan, 1) ./ sd;
        wv = wv(p);
        wv = reshape(wv, nShift, nPts);
        if forceRC
            minLoc(1) = zeroShift;
            error(1) = Inf;
        else
            err = bsxfun(@minus, wv, templateS(:, i)');
            err = mean(err.^2, 2);
            tmpLoc = find(err == min(err));
            minLoc(1) = tmpLoc(1);
            error(1) = err(tmpLoc(1));
        end
        for j = 1:length(destClust)
            err = bsxfun(@minus, wv, templateD(:, j)');
            err = mean(err.^2, 2);
            tmpLoc = find(err == min(err));
            minLoc(j+1) = tmpLoc(1);
            error(j+1) = err(tmpLoc(1));
        end
        dt = shift(minLoc);
        reclassDat(i).dt(k,:) = dt;
        reclassDat(i).error(k,:) = error;

    end
    
end