function spkDat = ReclassifyWaves(spkDat, reclassDat, varargin)

origClust = arrayfun(@(x) x.id(1), reclassDat);
destClust = setdiff(unique(spkDat.id), 0);
errorCriterion = Inf;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'origclust'
            origClust = varargin{i+1};
        case 'destclust'
            destClust = varargin{i+1};
        case 'error'
            errorCriterion = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to ReclassifyWaves');
    end
end

mask = ismember(arrayfun(@(x) x.id(1), reclassDat), origClust);
reclassDat = reclassDat(mask);

dt = zeros(1, length(spkDat.ts));
for i = 1:length(reclassDat)
    destLoc = find(ismember(reclassDat(i).id(2:end), destClust)) + 1;
    [~, idLoc] = min(reclassDat(i).error');
    for j = 1:length(destLoc)
        rcLoc = find(idLoc == destLoc(j));
        error = reclassDat(i).error(rcLoc, destLoc(j));
        rcLoc = rcLoc(error <= errorCriterion);
        spkLoc = reclassDat(i).loc(rcLoc);
        dt(spkLoc) = reclassDat(i).dt(rcLoc, destLoc(j))';
        spkDat.id(spkLoc) = reclassDat(i).id(destLoc(j));
        spkDat.ts(spkLoc) = spkDat.ts(spkLoc) + dt(spkLoc);
    end
end

shiftList = find(dt ~= 0);
[wL, nChan, ~] = size(spkDat.waves);
for i = shiftList
    wv = zeros(wL, nChan);
    pts = (1:wL) + dt(i);
    pts = pts(pts > 0 & pts <= wL);
    wv(pts - dt(i), :) = spkDat.waves(pts, :, i);
    spkDat.waves(:,:,i) = wv;
end

if ~isempty(find(spkDat.ts - spkDat.ts0 > spkDat.wavePad, 1))
    disp('WARNING: total shift exceeds wavePad on some spikes--reload waves recommended')
end