function spkDat = ResortSpikes(spkDat, trodeFile, ops)

pk = ops.peakLoc;
wL = ops.waveLength;
verbose = ops.verbose;
numFeatures = ops.numFeatures;
batchSize = ops.batchSize; % not currently used--just loads all of trodeFile into RAM.

% delete any repeated timestamps
[~, ia] = unique(spkDat.ts);
repeatTs = unique(spkDat.ts(setdiff(1:length(spkDat.ts), ia)));
delIdx = [];
for i = 1:length(repeatTs)
    loc = find(spkDat.ts == repeatTs(i));
    delIdx = [delIdx loc(spkDat.id(loc) == 0)];
    loc(spkDat.id(loc) == 0) = [];
    if length(loc) > 1
        delIdx = [delIdx loc(2:end)];
    end
end
spkDat.ts(delIdx) = [];
spkDat.id(delIdx) = [];
spkDat.waves(:,:,delIdx) = [];

% These parameters are hard-coded and must be changed across multiple
% functons (should be in hsd header!)
dataType         = 'int16';
machineFormat    = 'b';
bytes_per_sample = getBytesPerSample( dataType );

% get the hsd header
hsdInfo    = dir(trodeFile);
hsdHeader  = getHSDHeader( trodeFile );
Fs         = hsdHeader.main.sampling_rate;
dataOffset = hsdHeader.dataOffset;
nChan   = hsdHeader.main.num_channels;   % total number of wires in the .hsd file
datalength = floor((hsdInfo.bytes - dataOffset) / (bytes_per_sample * nChan)); 
wireList = 1:nChan;

W = spkDat.W;
sortedLoc = find(spkDat.id ~= 0);
ts = spkDat.ts(sortedLoc);

% 1) load and whiten data, extract spikes
tic;
if verbose
    fprintf('\nLoading data...');
end
waves = [];
startSample = min(ts) - pk + 1;
endSample = max(ts) + wL - pk;
numSamples = endSample - startSample + 1;
dat = readHSD(trodeFile, nChan, dataOffset, Fs, [], 'usesamplelimits', [startSample, numSamples]);
if verbose
    fprintf('complete. Elapsed time: %d seconds\n', round(toc));
end

if verbose
    fprintf('Whitening data...');
end
dat = W * dat;
if verbose
    fprintf('complete. Elapsed time: %d seconds\n', round(toc));
end

% 2) extract spike waveforms
if verbose
    fprintf('Extracting spike waveforms...');
end
spk = ts - startSample + 1;
idx = bsxfun(@plus, spk - pk, (1:wL)');
waves = cat(3, waves, reshape(dat(:,idx), nChan, wL,length(spk)));
if verbose
    fprintf('complete. Elapsed time: %d seconds\n', round(toc));
end

% 3) cluster spikes
if verbose
    fprintf('Clustering...\n');
end
features = ms_event_features(waves, numFeatures);
id = isosplit5(features);
clust = unique(id);
nClust = length(clust);
if verbose
    fprintf('\n%d clusters found. Elapsed time: %d seconds\n\n', nClust, round(toc));
end

% relabel clusters in descending order of spike count
nSpk = arrayfun(@(i) length(find(id == i)), clust);
[~, iSort] = sort(nSpk, 'descend');
idNew = id;
for i = 1:nClust 
    loc = find(id == iSort(i));
    idNew(loc) = i;
end
id = idNew;

spkDat.id(sortedLoc) = id;