function spkDat = SplitAll(spkDat, varargin)

Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;
clustList = setdiff(unique(spkDat.id), 0);
[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
win = 1000 * [1 - pk wL - pk] / wvFs;
chanList = 1:nChan;
subtractMean = true;
method = 'isosplit';
whiten = false;
numFeatures = 10;
verbose = true;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'minisi'
            minIsi = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'method'
            method = varargin{i+1};
        case 'win'
            win = varargin{i+1};
        case 'whiten'
            whiten = varargin{i+1};
        case 'numfeatures'
            numFeatures = varargin{i+1};
        case 'clust'
            clustList = varargin{i+1};
        otherwise
            disp('Invalid optional argument passed to SplitTest')
    end
end

clustList = intersect(clustList, setdiff(unique(spkDat.id), 0));
nChan = length(chanList);

maxWin = [1 - pk, wL - pk];
win = round(wvFs * win / 1000);
win(1) = max([win(1) maxWin(1)]);
win(2) = min([win(2) maxWin(2)]);
pts = (win(1):win(2)) + pk + wP;
for i = 1:length(clustList)
    n = clustList(i);
    if verbose
        fprintf('\nAssessing cluster %d\n', n)
    end
    nClust = length(setdiff(unique(spkDat.id), 0));
    loc = find(spkDat.id == n);
    wv = double(permute(spkDat.waves(pts, :, loc), [2 1 3]));
    if whiten
        for j = 1:length(loc)
            wv(:,:,j) = spkDat.W * wv(:,:,j);
        end
    end
    wv = wv(chanList, :, :);
    switch method
        case 'isosplit'
            features = ms_event_features(wv, numFeatures);
            id = isosplit5(features);
    end
    
    % relabel clusters in descending order of spike count
    newClust = unique(id);
    nClustNew = length(newClust);
    nSpk = arrayfun(@(j) length(find(id == j)), newClust);
    [~, iSort] = sort(nSpk, 'descend');
    idNew = id;
    for j = 1:nClustNew 
        loc2 = find(id == iSort(j));
        idNew(loc2) = j;
    end
    id = idNew;
    id(id > 1) = id(id > 1) + nClust - 1;
    id(id == 1) = n;
    spkDat.id(loc) = id;
    if verbose
        if nClustNew == 1
            fprintf('Cluster %d was not split\n', n);
        else
            fprintf('Cluster %d was split into %d clusters\n', n, nClustNew);
        end
    end
end
if verbose
    fprintf('\n')
end