function spkDat = SplitAllTmp(spkDat, varargin)

Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;
clustList = setdiff(unique(spkDat.id), 0);
[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
win = 1000 * [1 - pk wL - pk] / wvFs;
chanList = 1:nChan;
subtractMean = true;
method = 'isosplit';
whiten = false;
numFeatures = 10;
verbose = true;
timeRange = [0 Inf];

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'minisi'
            minIsi = varargin{i+1};
        case 'chan'
            chanList = varargin{i+1};
        case 'method'
            method = varargin{i+1};
        case 'win'
            win = varargin{i+1};
        case 'whiten'
            whiten = varargin{i+1};
        case 'numfeatures'
            numFeatures = varargin{i+1};
        case 'clust'
            clustList = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1};
        otherwise
            disp('Invalid optional argument passed to SplitTest')
    end
end

clustList = intersect(clustList, setdiff(unique(spkDat.id), 0));
nChan = length(chanList);

maxWin = [1 - pk, wL - pk];
win = round(wvFs * win / 1000);
win(1) = max([win(1) maxWin(1)]);
win(2) = min([win(2) maxWin(2)]);
pts = (win(1):win(2)) + pk + wP;

timeRange = timeRange * 60; % convert timeRange from minutes to seconds
tR = timeRange * spkDat.Fs;
locActive = intersect(find(spkDat.ts >= tR(1) & spkDat.ts <= tR(2)), find(ismember(spkDat.id, clustList)));
id = spkDat.id(locActive);
waves = double(permute(spkDat.waves(pts, :, locActive), [2 1 3]));

for i = 1:length(clustList)
    n = clustList(i);
    if verbose
        fprintf('\nAssessing cluster %d\n', n)
    end
    nClust = length(setdiff(unique([spkDat.id id]), 0));
    loc = find(id == n);
    wv = waves(:,:,loc);
    if whiten
        for j = 1:length(loc)
            wv(:,:,j) = spkDat.W * wv(:,:,j);
        end
    end
    wv = wv(chanList, :, :);
    switch method
        case 'isosplit'
            features = ms_event_features(wv, numFeatures);
            idNew = isosplit5(features);
    end
    
    % relabel clusters in descending order of spike count
    newClust = unique(idNew);
    nClustNew = length(newClust);
    nSpk = arrayfun(@(j) length(find(idNew == j)), newClust);
    [~, iSort] = sort(nSpk, 'descend');
    idNew2 = idNew;
    for j = 1:nClustNew 
        loc2 = find(idNew == iSort(j));
        idNew2(loc2) = j;
    end
    idNew = idNew2;
    
    % new, unfinished code
    if all(timeRange == [0 Inf])
        idNew(idNew > 1) = idNew(idNew > 1) + nClust - 1;
        idNew(idNew == 1) = n;
    else
        idNew = idNew + nClust;
    end
    
    
    id(loc) = idNew;
    if verbose
        if nClustNew == 1
            fprintf('Cluster %d was not split\n', n);
        else
            fprintf('Cluster %d was split into %d clusters\n', n, nClustNew);
        end
    end
end
if nClustNew > 1
    spkDat.id(locActive) = id;
end
if verbose
    fprintf('\n')
end