function SplitReview(spkDat, splitDat, varargin)

% convert waveform data from int16 to double-precision floating point
spkDat.waves = double(spkDat.waves);

maxScale = 1;
sameScale = true;
convertToVolt = true;
nSampTarget = 100;
clustList = [splitDat.origId unique(splitDat.newId)];
nClust = length(clustList);
showIdx = 1:nClust;
Fs = spkDat.Fs;
wvFs = Fs * spkDat.upsample;
minIsi = 1;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'nsamp'
            nSampTarget = varargin{i+1};
        case 'converttovolt'
            convertToVolt = varargin{i+1};
        case 'maxscale'
            maxScale = varargin{i+1};
        case 'showidx'
            showIdx = varargin{i+1};
        case 'samescale'
            sameScale = varargin{i+1};
        otherwise
            disp('invalid optional argument passed to MergeReview');
    end
end

[wL, nChan, ~] = size(spkDat.waves);
pk = spkDat.peakLoc;
wP = spkDat.wavePad;
wL = wL - 2*wP;
vScale = spkDat.vScale;

% assemble plot data, calculate y range
wv = cell(1, nClust);
avgWave = zeros(wL, nChan, nClust);
nSpk = zeros(1, nClust);
isiViol = zeros(1, nClust);
pts = (1:wL) + wP;
yRange = zeros(nClust, 2);
loc = splitDat.loc;
spkTimes = 1000 * spkDat.ts(loc) / Fs; % spike times in ms
isi = diff(spkTimes);
isiViol(1) = 100 * length(find(isi < minIsi)) / length(isi);
nSpk(1) = length(loc);
nSamp = min([nSampTarget nSpk(1)]);
samp = randsample(nSpk(1), nSamp);
wv{1} = spkDat.waves(pts,:,loc(samp));
avgWave(:,:,1) = mean(spkDat.waves(pts,:,loc), 3);
if convertToVolt
    wv{1} =  vScale * wv{1};
    avgWave(:,:,1) = vScale * avgWave(:,:,1);
end
avgMin = min(min(avgWave(:,:,1)));
avgMax = max(max(avgWave(:,:,1)));
avgRange = avgMax - avgMin;
yRange(1,1) = max([min(min(wv{1}, [], 3)), avgMin - avgRange * maxScale]);
yRange(1,2) = min([max(max(wv{1}, [], 3)), avgMax + avgRange * maxScale]);
    
for i = 2:nClust
    
    % compute average waveform
    n = clustList(i);
    loc = splitDat.loc(find(splitDat.newId == n));
    spkTimes = 1000 * spkDat.ts(loc) / Fs; % spike times in ms
    isi = diff(spkTimes);
    isiViol(i) = 100 * length(find(isi < minIsi)) / length(isi);
    avgWave(:,:,i) = mean(spkDat.waves(pts,:,loc), 3);
    if convertToVolt
        avgWave(:,:,i) = vScale * avgWave(:,:,i);
    end
    
    % select sample of waveforms to plot
    nSpk(i) = length(loc);
    nSamp = min([nSampTarget nSpk(i)]);    
    samp = randsample(nSpk(i), nSamp);
    wv{i} = spkDat.waves(pts,:,loc(samp));
    if convertToVolt
        wv{i} = vScale * wv{i};
    end
    
    % compute yRange
    avgMin = min(min(avgWave(:,:,i)));
    avgMax = max(max(avgWave(:,:,i)));
    avgRange = avgMax - avgMin;
    yRange(i,1) = max([min(min(wv{i}, [], 3)), avgMin - avgRange * maxScale]);
    yRange(i,2) = min([max(max(wv{i}, [], 3)), avgMax + avgRange * maxScale]);
    
end

if sameScale
    yRange(:,1) = min([yRange(:,1)]);
    yRange(:,2) = max(yRange(:,2));
end

% autocorrelogram for reference cell
autoRef = CrossCorr(spkDat, splitDat.origId, splitDat.origId, 'binSpec', [400 0.5]);
autoRef.y = length(autoRef.y) * autoRef.y / sum(autoRef.y);

% make figure panel
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vertSpace = 26;
horizSpace = 35;
plotWidth = 300;
plotHeight = 280;
panelHeight = vertSpace + (nChan + 1) * (vertSpace + plotHeight);
panelWidth = horizSpace + nClust * (horizSpace + plotWidth);
fig = figure('Position', [100 500 panelWidth panelHeight]); %[left bottom width height];
spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = plotWidth/panelWidth;
ht = plotHeight/panelHeight;

% plot data for each cluster
t = 1000 * ((1:wL) - pk)/ wvFs;
for i = 1:nClust + 1;
    
    % plot wire waveforms
    n = clustList(i);
    for w = 1:nChan
        subplot('Position', [spH+(i-1)*(wd+spH) spV+(nChan+1-w)*(ht+spV)  wd ht]) %[left bottom width height]
        hold on
        plot(t, squeeze(wv{i}(:,w,:)), 'LineWidth', 1, 'color', 'k')
        plot(t, avgWave(:,w,i), 'LineWidth', 3, 'color', 'r')
        yR = yRange(i,:) + [-0.01 0.01] * range(yRange(i,:));
        plot([0 0], yR, 'LineWidth', 1, 'color', 'b');
        ylim(yR);
        xlim([t(1) t(end)])
        if w == 1
            if i == 1
                title(['original cluster ' num2str(n) ': ' num2str(nSpk(i)) ' spikes']);
            else
                title(['new cluster ' num2str(n) ': ' num2str(nSpk(i)) ' spikes']);
            end
            isiStr = [num2str(isiViol(i), '%1.2f') '%'];
            xr = xlim;
            xPos = 0.85*range(xr) + xr(1);
            yPos = 0.95*range(yR) + yR(1);
            text(xPos, yPos, isiStr, 'FontSize', 12, 'BackgroundColor', 'w', 'Color', 'r', 'FontWeight', 'Bold');
        end
    end
    
    % plot ???
    %subplot('Position', [spH+(i-1)*(wd+spH) spV  wd ht]) %[left bottom width height]
end
