function spkDat = UnitToSpkDat(unit, baseDir, varargin)

%% in progress--incomplete!

unitInfo = arrayfun(@(u) strsplit(u.name, ' '), unit, 'UniformOutput', false);
rat = cellfun(@(u) u{1}, unitInfo, 'UniformOutput', false);
date = cellfun(@(u) u{2}, unitInfo, 'UniformOutput', false);
trode = cellfun(@(u) u{3}, unitInfo, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, unitInfo, 'UniformOutput', false);
idStr = cellfun(@(u) [u{1} u{2} u{3}], unitInfo, 'UniformOutput', false);
if length(unique(idStr)) > 1
    disp('Only include units from a single trode')
    return
end

[wL nChan] = size(unit(1).meanWaveform);
pk = unit(1).peakLoc

waveLength = 1.6;               % wavelength, in ms
peakLoc = 0.7;               % peak location, in ms
wavePad = 0.35;              % wavePad, in ms
alignWin = [-0.7 0.7];  % alignWin, in ms (not used much at this juncture)
upsample = 2;           % upsampling ratio
batchSize = 32768;
verbose = true;
sincLength = 12;
wireSd = 500;           % ballpark guess for wire SD, needed for some spikeworks functions (can add option to measure it in this function!)
filterDir = 'a-filtered';

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'peakloc'
            peakLoc = varargin{i+1};             % time of spk peak within spk wave, in ms
        case 'wavelength'
            waveLength = varargin{i+1};             % length of spk waves, in ms
        case 'wavepad'
            wavePad = varargin{i+1};             % data "pad" flanking spk wave that can be used for wave realignment, in ms
        case 'verbose'
            verbose = varargin{i+1};        % determines whether load progress is reported during execution
        case 'batchsize'
            batchSize = varargin{i+1};      % size of data batches for loading, in samples
        case 'upsample'
            upsample = varargin{i+1};       % factor by which data are upsampled (with sinc interpolation)
        case 'vscale'
            vScale = varargin{i+1};         % scale factor converting raw data into mV
        otherwise
            disp('Invalid optional argument passed to ReloadWaves')
    end
end

rat = arrayfun(@(u) u.name(1:5), unit, 'UniformOutput', false);
session = arrayfun(@(u) [u.name(6:9) ' ' u.name(10:11) '-' u.name(12:13)], unit, 'UniformOutput', false);
trode = arrayfun(@(u) lower(u.name(end-3:end-1)), unit, 'UniformOutput', false);
uid = arrayfun(@(u) u.name(end), unit, 'UniformOutput', false);
[sesList idx] = unique(session);
idx = [idx; length(unit) + 1];
n = 0;

% loop through recording sessions covered in unit
tic;
if verbose
    fprintf('\n');
end
for i = 1:length(sesList)
    sesIdx = idx(i):idx(i+1) - 1;
    sesDir = [baseDir rat{sesIdx(1)} '/' sesList{i} '/' filterDir '/'];
    trodeList = trode(sesIdx);
    [trodeList idx2] = unique(trodeList);
    idx2 = [idx2; idx(i+1) - idx(i) + 1];
    if verbose
        fprintf('Session %d of %d\n', i, length(sesList));
    end
    
    % loop through trodes in session
    for j = 1:length(trodeList) 
        trodeIdx = sesIdx(idx2(j):idx2(j+1) - 1);
        trodeFile = [sesDir trode{trodeIdx(1)} '.hsd'];
        n = n + 1;
        if verbose
            fprintf('Trode %d of %d\n', j, length(trodeList))
        end
        
        % get the hsd header
        hsdInfo    = dir(trodeFile);
        hsdHeader  = getHSDHeader( trodeFile );
        Fs         = hsdHeader.main.sampling_rate;
        dataOffset = hsdHeader.dataOffset;
        nChan   = hsdHeader.main.num_channels;   % total number of wires in the .hsd file
        if hsdHeader.main.version < 4
            bytes_per_sample = 2;
            voltRange = [-10 10];
            numBits = 8 * bytes_per_sample;
            spkDat(n).vScale = 1000 * (range(voltRange) / 2^numBits) / hsdHeader.channel(1).gain;
        % else
        %     bytes_per_sample = hsdHeader.x; % for future version of hsdHeader
        %     vScale = hsdHeader.x; % for future version of hsdHeader
        end
        datalength = floor((hsdInfo.bytes - dataOffset) / (bytes_per_sample * nChan)); 
        wireList = 1 : nChan;
        
        % log info in spkDat
        wL = round(waveLength * Fs * upsample / 1000);
        pk = round(peakLoc * Fs * upsample / 1000);
        wP = round(wavePad * Fs * upsample / 1000);
        spkDat(n).alignWin = round(alignWin * Fs * upsample / 1000);
        spkDat(n).peakLoc = pk;
        spkDat(n).upsample = upsample;
        spkDat(n).wavePad = wP;
        spkDat(n).Fs = Fs;
        spkDat(n).wireSd = ones(1, nChan) * wireSd;
        spkDat(n).highCut = hsdHeader.channel(1).high_cut;
        spkDat(n).sincLength = sincLength;
        spkDat(n).unitNames = arrayfun(@(u) u.name, unit(trodeIdx), 'UniformOutput', false);
        spkDat(n).ts = [];
        spkDat(n).id = [];
        for k = 1:length(trodeIdx)
            ts = round(unit(trodeIdx(k)).spkTimes * Fs);
            spkDat(n).ts = [spkDat(n).ts ts];
            spkDat(n).id = [spkDat(n).id ones(1, length(ts)) * k];
        end
        [spkDat(n).ts, iSort] = sort(spkDat(n).ts);
        spkDat(n).id = spkDat(n).id(iSort);
        spkDat(n).ts0 = spkDat(n).ts;
        spkDat(n).tsOrig = spkDat(n).ts;
        
        % load spike waveforms
        ts = spkDat(n).ts;
        startSample = min(ts) - wP - pk;
        endSample = max(ts) + wP + wL - pk;
        startSample = max([1 startSample]);
        endSample = min([endSample datalength]);
        numSamples = endSample - startSample + 1;
        overlap = 4*wL + 2*wP;
        numBatches = ceil((numSamples - 2*wL)/(batchSize - overlap));
        if verbose
            fprintf('Loading spike waveforms, batch ');
            msg = '';
        end
        spkDat(n).waves = zeros(wL + 2*wP, nChan, length(spkDat(n).ts));
        tsLocal = [];
        for b = 1:numBatches
    
            if verbose
                fprintf(repmat('\b', 1, numel(msg)));
                msg = sprintf('%d of %d, time elapsed: %d seconds', b, numBatches, round(toc));
                fprintf(msg);
            end
            
            % load data from hsd file
            dat = readHSD(trodeFile, nChan, dataOffset, Fs, [], 'usesamplelimits', [startSample, batchSize]);
            if upsample > 1
                tmpDat = zeros(size(dat, 1), size(dat, 2) * upsample);
                for w = 1:nChan
                    tmpDat(w, :) = sincInterp(dat(w, :), Fs, spkDat(n).highCut, upsample*Fs, 'sinclength', spkDat(n).sincLength);
                end
                dat = tmpDat;
            end
            
            % extract spike waveforms
            tsLocal = setdiff(ts(ts >= startSample + wP + pk & ts < startSample + batchSize - wP - wL + pk), tsLocal);
            [~, loc] = ismember(tsLocal, ts);
            spk = (tsLocal - startSample + 1) * upsample;
            if ~isempty(spk)        
                idx3 = bsxfun(@plus, spk - pk - wP, (1:wL + 2*wP)');
                wv = reshape(dat(:,idx3), nChan, wL + 2*wP, length(spk)); % #chan X #pts X #spikes
                spkDat(n).waves(:,:,loc) = permute(wv, [2 1 3]); % #chan X #pts X #spikes
            end
    
            startSample = startSample + batchSize - overlap;
    
        end

        if verbose
            fprintf('...load complete\n ');
        end
        
        
    end
    
end
if verbose
    fprintf('\n');
end