function chewDat = ChewCheck(sesDir, varargin)

% Loads data segments on rewarded trials to look for chewing artifacts

chanName = 'ECoG1';
trNum = 1;
timeRange = [-1 20];
band1 = [100 800];
band2 = [3 8];

biteThr = 10000;
minBiteInt = 0.01;
maxBiteInt = 0.5;
minBiteDur = 0.01;
maxBiteDur = 0.5;

for i = 1 : 2 : length(varargin)
    
    switch lower(varargin{i})
        case 'channame'
           chanName = varargin{i+1};
        case 'trnum'
            trNum = varargin{i+1};
        case 'timerange'
            timeRange = varargin{i+1};
        case 'band1'
            band1 = varargin{i+1};
        case 'band2'
            band2 = varargin{i+1};
        case 'bitethr'
            biteThr = varargin{i+1};
        case 'minbiteint'
            minBiteInt = varargin{i+1};
        case 'maxbiteint'
            maxBiteInt = varargin{i+1};
        case 'minbitedur'
            minBiteDur = varargin{i+1};
        case 'maxbitedur'
            maxBiteDur = varargin{i+1};
    end
    
end

if sesDir(end) == filesep
    sesDir = sesDir(1:end-1);
end

pathParts = strsplit(sesDir, '/');
pathParts = pathParts(cellfun(@(s) length(s) > 1, pathParts));
rat = pathParts(cellfun(@(s) strcmp(s(1:2), 'IM'), pathParts));
rat = rat{1};

% load RL behavior, find rewarded trials
load([sesDir filesep 'behavior - RL.mat'])
rwd = TrialFilter(tsRL, 'x1', 'L');
if rwd(end) == length(tsRL.go)
    rwd(end) = [];
end
sni = tsRL.Side_NI(rwd);
cni = tsRL.Center_NI(rwd+1);

% identify RL data folder
fileDat = dir([sesDir filesep rat '-RL*']);
datDir = [sesDir filesep fileDat(1).name];

% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);
Fs = rhdInfo.Fs;

% design filters
filtOrder = 500;
b1 = fir1(filtOrder, 2*pi*band1 / Fs);
b2 = fir1(filtOrder, 2*pi*band2 / Fs);

for k = 1:length(rwd)
    
    % load data segment
    d = PlotIntanData(datDir, 'trode', 'ECoG1', 'returnData', true, 'makePlot', false, 'timeRange', [sni(k) cni(k)]);
    
    % get power in band 1 (should be 100-800 Hz)
    c1 = filtfilt(b1, 1, d.v);
    p1 = abs(hilbert(c1)) .^ 2;
    p1 = p1 / median(p1);
    
    % detect band 1 power modulations in band 2 (should be 3-8 Hz)
    c2 = filtfilt(b2, 1, p1);
    p2 = abs(hilbert(c2)) .^ 2;
    
    % use these modulations to detect "bites"
    bite = p2 > biteThr;
    biteStart = find(diff(bite) > 0);
    biteEnd = find(diff(bite) < 0);
    if bite(1)
        biteEnd(1) = [];
    end
    if bite(end)
        biteStart(end) = [];
    end
    bite = [d.t(biteStart)' d.t(biteEnd)'];
    biteDur = bite(:,2) - bite(:,1);
    
    % eliminate long "bites"
    delIdx = find(biteDur > maxBiteDur);
    bite(delIdx,:) = [];
    biteStart(delIdx) = [];
    biteEnd(delIdx) = [];
    biteDur = bite(:,2) - bite(:,1);
    biteInt = bite(2:end,1) - bite(1:end-1,2);

    % merge bites separated by short intervals
    merge = find(biteInt < minBiteInt);
    if ~isempty(merge)
        endLocs = find(diff(merge) > 1); % locations of the ends of short interval sequences
        startLocs = endLocs + 1; % locations of the starts of short interval sequences
        endLocs = [merge(endLocs); merge(end)] + 1;
        startLocs = [merge(1); merge(startLocs)];
    else
        startLocs = [];
        endLocs = [];
    end
    biteEnd(startLocs) = biteEnd(endLocs);
    bite(startLocs, 2) = bite(endLocs, 2);
    delIdx = [];
    for i = 1:length(startLocs)
        delIdx = [delIdx startLocs(i)+1:endLocs(i)];
    end
    bite(delIdx, :) = [];
    biteStart(delIdx) = [];
    biteEnd(delIdx) = [];
    biteDur = bite(:,2) - bite(:,1);
    biteInt = bite(2:end,1) - bite(1:end-1,2);

    % eliminate short "bites"
    delIdx = find(biteDur < minBiteDur);
    bite(delIdx,:) = [];
    biteStart(delIdx) = [];
    biteEnd(delIdx) = [];
    
%     biteDur = bite(:,2) - bite(:,1);
%     biteInt = bite(2:end,1) - bite(1:end-1,2);
    
%     % identify chewing bouts
%     merge = find(biteInt < maxBiteInt);
%     if ~isempty(merge)
%         endLocs = find(diff(merge) > 1); % locations of the ends of chewing bouts
%         startLocs = endLocs + 1; % locations of the starts of chewing bouts
%         endLocs = [merge(endLocs); merge(end)] + 1;
%         startLocs = [merge(1); merge(startLocs)];
%     else
%         startLocs = [];
%     end
%     chew = [bite(startLocs,1) bite(endLocs,2)];

    chewDat(k).bite = bite;
    
end


% % load data segment
% tR = timeRange + tsRL.Side_NI(rwd(trNum));
% r = tsRL.Side_NI(rwd);
% fp = tsRL.firstFoodPoke(rwd);
% r = r(r>tR(1) & r < tR(2));
% fp = fp(fp>tR(1) & fp < tR(2));
% d = PlotIntanData(datDir, 'trode', 'ECoG1', 'returnData', true, 'makePlot', false, 'timeRange', tR);
% 
% % plot raw data annotated with SI and food port poke events
% figure
% hold on
% plot(d.t, d.v)
% xlim([d.t(1) d.t(end)])
% title(chanName)
% yR = ylim;
% for x = r'
%     plot([x x], yR, 'r', 'LineWidth', 2)
% end
% for x = fp'
%     plot([x x], yR, 'g', 'LineWidth', 2)
% end
% 
% % plot spectrogram
% fRange = [0 2000];
% fRes = 10;
% cRange = [-5 12];
% Fs = 30000;
% [b freq t] = specgram(d.v, round(Fs/fRes), Fs);
% t = t + d.t(1);
% fLoc = freq >= fRange(1) & freq <= fRange(2);
% freq = freq(fLoc);
% p = log(abs(b(fLoc,:)).^2);
% figure
% title(chanName)
% imagesc(t, freq, p, cRange)
% set(gca,'Yscale','lin','Ydir','normal')
% xlabel(['time (sec)'])
% ylabel('frequency (Hz)')
% colormap(jet(200))
% hold on
% plot([t(1) t(end)], [band1(1) band1(1)], 'w--')
% plot([t(1) t(end)], [band1(2) band1(2)], 'w--')
% 
% % plot bandpass filtered data
% c1 = filtfilt(b1, 1, d.v);
% p1 = abs(hilbert(c1)) .^ 2;
% p1 = p1 / median(p1);
% figure
% plot(d.t, p1)
% xlim([d.t(1) d.t(end)])
% hold on
% yR = ylim;
% for x = r'
%     plot([x x], yR, 'r', 'LineWidth', 2)
% end
% for x = fp'
%     plot([x x], yR, 'g', 'LineWidth', 2)
% end
% title(chanName)
% 
% % plot filtered bandpass power with chews/bites marked
% c2 = filtfilt(b2, 1, p1);
% p2 = abs(hilbert(c2)) .^ 2;
% figure
% plot(d.t, p2)
% xlim([d.t(1) d.t(end)])
% hold on
% yR = ylim;
% for x = r'
%     plot([x x], yR, 'r', 'LineWidth', 2)
% end
% for x = fp'
%     plot([x x], yR, 'g', 'LineWidth', 2)
% end
% title(chanName)
% bite = p2 > biteThr;
% biteStart = find(diff(bite) > 0);
% biteEnd = find(diff(bite) < 0);
% bite = [d.t(biteStart)' d.t(biteEnd)'];
% biteDur = bite(:,2) - bite(:,1);
% 
% % eliminate long "bites"
% delIdx = find(biteDur > maxBiteDur);
% bite(delIdx,:) = [];
% biteStart(delIdx) = [];
% biteEnd(delIdx) = [];
% biteDur = bite(:,2) - bite(:,1);
% biteInt = bite(2:end,1) - bite(1:end-1,2);
% 
% % merge bites separated by short intervals
% merge = find(biteInt < minBiteInt);
% if ~isempty(merge)
%     endLocs = find(diff(merge) > 1); % locations of the ends of short interval sequences
%     startLocs = endLocs + 1; % locations of the starts of short interval sequences
%     endLocs = [merge(endLocs); merge(end)] + 1;
%     startLocs = [merge(1); merge(startLocs)];
% else
%     startLocs = [];
% end
% biteEnd(startLocs) = biteEnd(endLocs);
% bite(startLocs, 2) = bite(endLocs, 2);
% delIdx = [];
% for i = 1:length(startLocs)
%     delIdx = [delIdx startLocs(i)+1:endLocs(i)];
% end
% bite(delIdx, :) = [];
% biteStart(delIdx) = [];
% biteEnd(delIdx) = [];
% biteDur = bite(:,2) - bite(:,1);
% biteInt = bite(2:end,1) - bite(1:end-1,2);
% 
% % eliminate short "bites"
% delIdx = find(biteDur < minBiteDur);
% bite(delIdx,:) = [];
% biteStart(delIdx) = [];
% biteEnd(delIdx) = [];
% biteDur = bite(:,2) - bite(:,1);
% biteInt = bite(2:end,1) - bite(1:end-1,2);
% 
% biteAmpl = arrayfun(@(i) mean(p2(biteStart(i):biteEnd(i))), 1:length(biteStart));
% 
% % identify chewing bouts
% merge = find(biteInt < maxBiteInt);
% if ~isempty(merge)
%     endLocs = find(diff(merge) > 1); % locations of the ends of chewing bouts
%     startLocs = endLocs + 1; % locations of the starts of chewing bouts
%     endLocs = [merge(endLocs); merge(end)] + 1;
%     startLocs = [merge(1); merge(startLocs)];
% else
%     startLocs = [];
% end
% chew = [bite(startLocs,1) bite(endLocs,2)];
% 
% y1 = yR(1) + 0.25*diff(yR);
% y2 = yR(1) + 0.5*diff(yR);
% for i = 1:size(bite, 1)
%     plot(bite(i,:), [y1 y1], 'm', 'LineWidth', 3)
% end
% for i = 1:size(chew, 1)
%     plot(chew(i,:), [y2 y2], 'c', 'LineWidth', 3)
% end
