function SleepCheck(sessionDir)

ecogStr = 'eco';
targetEcog = 'ECoG1';

lfpFs = 500;
bytesPerSample = 2;
scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
vScale = 0.000195;

% identify task-based data folders
fileDat = dir([sessionDir filesep 'IM*']);
idx = arrayfun(@(f) f.isdir, fileDat);
folder = arrayfun(@(f) f.name, fileDat(idx), 'UniformOutput', false);
folderInfo = cellfun(@(f) strsplit(f, {'-', '_'}), folder, 'UniformOutput', false);
task = cellfun(@(f) f{end-2}, folderInfo, 'UniformOutput', false);
date = cellfun(@(f) f{end-1}, folderInfo, 'UniformOutput', false);
time = cellfun(@(f) str2num(f{end}), folderInfo);
[~, iSort] = sort(time);
folder = folder(iSort);
task = task(iSort);

% loop through tasks
for i = 1:length(task)
    
    fprintf('\nChecking task %d of %d (%s)...', i, length(task), task{i})
    datDir = [sessionDir filesep folder{i}];
    
    % load RHD info
    rhdFile = [datDir filesep 'info.rhd'];
    rhdInfo = ReadRhdInfo(rhdFile);
    Fs = rhdInfo.Fs;
    r = round(Fs / lfpFs);
    
    % extract "custom name" recorded channels, identify ECoG channels
    chanNames = arrayfun(@(x) x.custom_name, rhdInfo.amp, 'UniformOutput', false);
    ecogChan = find(cellfun(@(x) strcmp(lower(x(1:3)), ecogStr), chanNames));
    if isempty(ecogChan)
        fprintf('no ECoG channels found for task\n')
        continue
    end
    ecogChan = rhdInfo.amp(ecogChan);
    
    % select ECoG channel to use
    chan = find(arrayfun(@(x) strcmp(targetEcog, x.custom_name), ecogChan));
    str = '';
    if isempty(chan)
        chan = 1;
        str = 'target ECoG not found, ';
    end
    
    % load and filter data
    fprintf('%sfiltering %s...', str, ecogChan(chan).custom_name)
    datFile = [datDir filesep 'amp-' ecogChan(chan).native_name '.dat'];
    datInfo = dir(datFile);
    datalength = datInfo.bytes / bytesPerSample;
    recDur = datalength / Fs;
    f = fopen(datFile);
    dat = double(fread(f, datalength, 'int16')) * vScale;
    fclose(f);
    dat = decimate(dat, r);
    
    % plot ECoG spectrogram for SWS identification
    fRange = [0 100];
    fRes = 0.2;
    cRange = [0.2 8];
    [b freq t] = specgram(dat, round(lfpFs/fRes), lfpFs);
    fLoc = freq >= fRange(1) & freq <= fRange(2);
    freq = freq(fLoc);
    p = log(abs(b(fLoc,:)).^2);
    fig = figure('Position', [scrWidth/3 scrHeight/2 500 * 4 420 * 2], 'Name', [num2str(i) ') ' task{i}], 'NumberTitle', 'off');
    imagesc(t, freq, p, cRange)
    set(gca,'Yscale','lin','Ydir','normal')
    xlabel(['time (sec)'])
    ylabel('frequency (Hz)')
    colormap(jet(200))
    fprintf('done')
    
end

fprintf('\n\n')