datRoot = '/Volumes/LaCie/Farries recordings/';
rat = 'IM1056';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false)

iSes = [3];
sesDir = [datRoot rat filesep sesList{iSes} filesep]
ratDir = [datRoot rat];
cal = Calibrate(ratDir);
sesList = dir([ratDir '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false)

iSes = 6;
sesDir = [ratDir filesep sesList{iSes} filesep]
load([sesDir 'behavior - RL.mat'])
rwd = TrialFilter(tsRL, 'x1', 'L');

fileDat = dir([sesDir rat '-RL*']);
datDir = [sesDir fileDat(1).name]

% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);
Fs = rhdInfo.Fs;

%% initialization of variables

% set positions of accelerometer chips on amp board
r1board = [-1.29; -0.01; 0];
r2board = [1.31; 0; 0];

% load data during center nose hold on trial i
i = 1; % trial number
tR = [tsRL.Center_NI(i) tsRL.Center_NO(i)];
data = LoadAuxData(datDir, 'timeRange', tR);
x1 = (data.a(3,:) - cal.v0x1) * cal.mx1;
x2 = (data.a(6,:) - cal.v0x2) * cal.mx2;
y1 = (data.a(2,:) - cal.v0y1) * cal.my1;
y2 = (data.a(5,:) - cal.v0y2) * cal.my2;
z1 = (data.a(1,:) - cal.v0z1) * cal.mz1;
z2 = (data.a(4,:) - cal.v0z2) * cal.mz2;

% caluclate vector norm for both chips
n1 = arrayfun(@(i) norm([x1(i) y1(i) z1(i)]), 1:length(x1));
n2 = arrayfun(@(i) norm([x2(i) y2(i) z2(i)]), 1:length(x2));
figure
hold on
plot(data.t, n1)
plot(data.t, n2)
plot([data.t(1) data.t(end)], [980 980], 'k--');
xlim([data.t(1) data.t(end)]);
ylim([750 1200])

% find times during hold period where acceleration signal has magnitude close to g for some threshold period of time
accThr = 100;
durThr = 0.05;
d1 = abs(n1 - 980);
d2 = abs(n2 - 980);
lowAcc = (d1 < accThr) & (d2 < accThr);
lowStart = find(diff(lowAcc) > 0);
lowEnd = find(diff(lowAcc) < 0);
if lowEnd(1) < lowStart(1)
    lowEnd = lowEnd(2:end);
end
lowStart = lowStart(1:min(length(lowStart), length(lowEnd)));
lowEnd = lowEnd(1:min(length(lowStart), length(lowEnd)));
lowAcc = [data.t(lowStart)' data.t(lowEnd)'];
lowDur = lowAcc(:,2) - lowAcc(:,1);
delIdx = find(lowDur < durThr);
lowStart(delIdx) = [];
lowEnd(delIdx) = [];
lowDur(delIdx) = [];
dAvg1 = arrayfun(@(i) median(d1(lowStart(i):lowEnd(i))), 1:length(lowStart));
dAvg2 = arrayfun(@(i) median(d2(lowStart(i):lowEnd(i))), 1:length(lowStart));
idx = find(mean([dAvg1; dAvg2]) == min(mean([dAvg1; dAvg2])));
initStart = lowStart(idx);
initEnd = lowEnd(idx);
[data.t(initStart), data.t(initEnd)]
g1 = median([x1(initStart:initEnd); y1(initStart:initEnd); z1(initStart:initEnd)], 2);
g2 = median([x2(initStart:initEnd); y2(initStart:initEnd); z2(initStart:initEnd)], 2);
g = mean([g1 g2], 2);
Rz = RotMatrix([0 0 1], g);

% initial orientation vectors
Oz = Rz*[0;0;1]
Oy = Rz*[0;-1;0]

% everything else initialized to zero
x = [0;0;0]; % position vector for center point (of board)
v = [0;0;0]; % linear velocity vector of center point
w = [0;0;0]; % angular velocity vector about center point
t = mean([data.t(initStart), data.t(initEnd)])

% load larger data set, convert to chip acceleration
tR = [t - 1/Fs tsRL.Side_NI(i)+ 0.2];
data = LoadAuxData(datDir, 'timeRange', tR);
t = data.t;
aChip1 = [(data.a(3,:) - cal.v0x1) * cal.mx1; (data.a(2,:) - cal.v0y1) * cal.my1; (data.a(1,:) - cal.v0z1) * cal.mz1];
aChip2 = [(data.a(6,:) - cal.v0x2) * cal.mx2; (data.a(5,:) - cal.v0y2) * cal.my2; (data.a(4,:) - cal.v0z2) * cal.mz2];

% downsample by 4
nPts = floor(size(aChip1,2));
pts = 1:4:nPts;
aChip1 = aChip1(:, pts);
aChip2 = aChip2(:, pts);

% set up param structure
param.dt = 4 / Fs;
param.t = 0;
param.x = x;
param.Oz = Oz;
param.Oy = Oy;
param.v = v;
param.w = w;
param.g = [0;0; norm(g)];
param.r1board = r1board;
param.r2board = r2board;

% compute trajectory
traj = CalculateMotion(aChip1, aChip2, param);

%% timestep walkthrough

% accelerometer position vectors (relative to board center)
r1board = [-1.29; -0.01; 0];
r2board = [1.31; 0; 0];

% 1) convert chip acceleration to box acceleration, subtract g (use locally measured value)
Rz = RotMatrix(Oz, [0;0;1]);
Ry = RotMatrix(Rz*Oy, [0;1;0]);
a1 = Ry * Rz * aChip1(:,1);
a2 = Ry * Rz * aChip2(:,1);
a1 = a1 - [0;0;norm(g)]
a2 = a2 - [0;0;norm(g)]

% convert position vectors of accelerometers to box frame
r1 = Ry * Rz * r1board;
r2 = Ry * Rz * r2board;

% 2) ansatz: linear accel is the average of the two vectors??
a = mean([a1 a2],2);

% 3) subtract mean acceleration and rotation-driven acceleration from a1 and a2
a1 = a1 - a;
a2 = a2 - a;
a1 = a1 + cross(w, cross(w, r1));
a2 = a2 + cross(w, cross(w, r2));

% 4) compute angular acceleration from remainder of a1/a2
A = [0,      r1(3), -r1(2);
    -r1(3),  0,      r1(1);
     r1(2), -r1(1),  0;
     0,      r2(3), -r2(2);
    -r2(3),  0,      r2(1);
     r2(2), -r2(1),  0];
B = [a1; a2];
wd = linsolve(A,B);

% 5) update position and orientation vectors for next timestep
x = x + dt * v;
Oz = Oz + dt * cross(w, Oz);
Oy = Oy + dt * cross(w, Oy);

% 6) update linear and angular velocity vectors for next timestep
v = v + dt * a;
w = w + dt * wd;