function cal = Calibrate(calDir)

% calibrate accelerometers
bytesPerSample = 2;

% calDir = [ratDir filesep 'calibration'];

%% load calibration data: x

% locate calibration data
datDir = dir([calDir filesep 'x*']);
if isempty(datDir)
    disp('calibration data not found')
    return
elseif length(datDir) > 1
    dirId = arrayfun(@(d) d.name(7), datDir, 'UniformOutput', false);
    idx = find(strcmp(dirId, 'L'));
    datDir = [calDir filesep datDir(idx).name];
else
    datDir = [calDir filesep datDir(1).name];
end


% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);
Fs = rhdInfo.Fs;

% load data segment
tR = [0.5 1.5];
data = LoadAuxData(datDir, 'timeRange', tR);

v0z1_x = mean(data.a(1,:));
v0z2_x = mean(data.a(4,:));
v0y1_x = mean(data.a(2,:));
v0y2_x = mean(data.a(5,:));
vgx1 = mean(data.a(3,:));
vgx2 = mean(data.a(6,:));

%% load calibration data: y

% locate calibration data
fileDat = dir([calDir filesep 'y*']);
if isempty(fileDat)
    disp('calibration data not found')
    return
end
datDir = [calDir filesep fileDat(1).name];

% locate calibration data
datDir = dir([calDir filesep 'y*']);
if isempty(datDir)
    disp('calibration data not found')
    return
elseif length(datDir) > 1
    dirId = arrayfun(@(d) d.name(7), datDir, 'UniformOutput', false);
    idx = find(strcmp(dirId, 'B'));
    datDir = [calDir filesep datDir(idx).name];
else
    datDir = [calDir filesep datDir(1).name];
end

% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);
Fs = rhdInfo.Fs;

% load data segment
tR = [0.5 3.5];
data = LoadAuxData(datDir, 'timeRange', tR);

v0z1_y = mean(data.a(1,:));
v0z2_y = mean(data.a(4,:));
v0x1_y = mean(data.a(3,:));
v0x2_y = mean(data.a(6,:));
vgy1 = mean(data.a(2,:));
vgy2 = mean(data.a(5,:));

%% load calibration data: z

% locate calibration data
fileDat = dir([calDir filesep 'z*']);
if isempty(fileDat)
    disp('calibration data not found')
    return
end
datDir = [calDir filesep fileDat(1).name];

% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);
Fs = rhdInfo.Fs;

% load data segment
tR = [0.5 3];
data = LoadAuxData(datDir, 'timeRange', tR);

vgz1 = mean(data.a(1,:));
vgz2 = mean(data.a(4,:));
v0x1_z = mean(data.a(3,:));
v0x2_z = mean(data.a(6,:));
v0y1_z = mean(data.a(2,:));
v0y2_z = mean(data.a(5,:));

%% compute calibration parameters

cal.v0x1 = mean([v0x1_y v0x1_z]);
cal.v0x2 = mean([v0x2_y v0x2_z]);
cal.v0y1 = mean([v0y1_x v0y1_z]);
cal.v0y2 = mean([v0y2_x v0y2_z]);
cal.v0z1 = mean([v0z1_x v0z1_y]);
cal.v0z2 = mean([v0z2_x v0z2_y]);

cal.mx1 = 980 / (vgx1 - cal.v0x1);
cal.mx2 = 980 / (vgx2 - cal.v0x2);
cal.my1 = 980 / (vgy1 - cal.v0y1);
cal.my2 = 980 / (vgy2 - cal.v0y2);
cal.mz1 = 980 / (vgz1 - cal.v0z1);
cal.mz2 = 980 / (vgz2 - cal.v0z2);

