% this is just to deal with a situation where one drive has the raw data
% and another drive has the spike sort results
% For most situations, "analyze laser.m" is the better choice
rawRoot = '/Volumes/Seagate Backup Plus Drive/Recordings/';
sortRoot = '/Volumes/LaCie/Farries recordings/';
rat = 'IM1261';
sesListRaw = dir([rawRoot rat '/20*']);
sesListRaw = arrayfun(@(x) x.name, sesListRaw, 'UniformOutput', false);

sesListSort = dir([sortRoot rat '/20*']);
sesListSort = arrayfun(@(x) x.name, sesListSort, 'UniformOutput', false);
sorted = cellfun(@(s) exist([sortRoot rat filesep s filesep 'unitDat.mat'], 'file') == 2, sesListSort);
sesListSort = sesListSort(sorted);

for i = 9:11%length(sesListSort)
    fprintf('%d) %s\n', i, sesListSort{i})
    [~,rawIdx] = ismember(sesListSort{i}, sesListRaw);
    sesDirSort = [sortRoot rat filesep sesListSort{i} filesep];
    sesDirRaw = [rawRoot rat filesep sesListRaw{rawIdx} filesep];
    
    % identify data directories for laser sessions
    laserDir = dir([sesDirRaw]);
    laserDir = arrayfun(@(x) x.name, laserDir, 'UniformOutput', false);
    keep = cellfun(@(l) length(l)>9, laserDir);
    laserDir = laserDir(keep);
    lsr = cellfun(@(l) strcmp(l(8:10), 'las'), laserDir);
    laserDir = laserDir(lsr);
    
    % loop through laser data directories
    pow = cellfun(@(l) l(13:16), laserDir, 'UniformOutput', false);
    e = cellfun(@(p) strfind(p, 'm'), pow)-1;
    power = arrayfun(@(k) str2num(pow{k}(1:e(k))), 1:length(e));
    laserLogs = dir([sesDirSort '*laser.log']);
    laserLogs = arrayfun(@(x) x.name, laserLogs, 'UniformOutput', false);
    logInfo = cellfun(@(l) strsplit(l, '_'), laserLogs, 'UniformOutput', false);
    logTime = cellfun(@(l) l{3}, logInfo, 'UniformOutput', false);
    logTime = cellfun(@(l) strjoin(strsplit(l, '-'),''), logTime, 'UniformOutput', false);
    logTime = cellfun(@(l) 60*str2num(l(1:2))+str2num(l(3:4))+str2num(l(5:6))/60, logTime);
    
    folderInfo = cellfun(@(f) strsplit(f, {'-', '_'}), laserDir, 'UniformOutput', false);
    task = cellfun(@(f) f{2}, folderInfo, 'UniformOutput', false);
    boxFileTime = cellfun(@(f) f{end}, folderInfo, 'UniformOutput', false);
    boxFileTime = cellfun(@(b) 60*str2num(b(1:2))+str2num(b(3:4))+str2num(b(5:6))/60, boxFileTime);
    
    [boxFileTime, iSort] = sort(boxFileTime);
    laserDir = laserDir(iSort);
    power = power(iSort);
    
    if any(abs(logTime - boxFileTime) > 1)
        disp(['WARNING: problem matching log files to box files in ' sesListSort{i}]);
    end

    laser_log = cell(1, length(laserDir));
    laser_ts = cell(1, length(laserDir));
    for j = 1:length(laserDir)
        
        [laser_log{j} laser_ts{j}] = ExtractBehavior([sesDirRaw laserDir{j}], [sesDirSort laserLogs{j}], 'laser');
        laser_log{j} = rmfield(laser_log{j}, 'current');
        laser_log{j} = rmfield(laser_log{j}, 'voltage');
        for k = 1:length(laser_log{j})
            laser_log{j}(k).power = power(j);
        end
    end
    
    % load unit data
    load([sesDirSort '/unitDat.mat'])

    postBoutWait = 5; % seconds

    laserResponse = [];
    % loop through units
    laserIdx = find(cellfun(@(x) ~isempty(strfind(x, 'laser')), unit(1).taskList));
    for u = 1:length(unit)
    
        lR.name = unit(u).name;
        lR.block = cell(1, length(laser_log));
    
        % loop through laser blocks
        for i = 1:length(laser_log)
        
            t1 = unit(u).taskStart(laserIdx(i));
            t2 = unit(u).taskEnd(laserIdx(i));
            spk = unit(u).spkTimes;
            spk = unique(spk(spk > t1 & spk < t2) - t1);
        
            % loop through laser bouts
            for k = 1:length(laser_log{i})
                lB.taskIdx = laserIdx(i);
                lB.taskName = unit(u).taskList{laserIdx(i)};
                lB.laserPower = laser_log{i}(k).power;
                lB.pulseFrequency = laser_log{i}(k).frequency;
                lB.pulseOnset = laser_ts{i}(k).onset;
                lB.pulseDur = 1000*laser_ts{i}(k).duration;    % pulse duration is in ms
                lB.preIsi = diff(spk(spk < lB.pulseOnset(1)));
                lB.postIsi = [];
                nPulses = length(lB.pulseOnset);
                lB.latency = nan(1, nPulses);
                lB.negLat = nan(1, nPulses);
                lB.responseIsi = cell(1, nPulses);
            
                % loop through laser pulses
                for p = 1:nPulses
                    s = spk(spk > lB.pulseOnset(p) & spk < lB.pulseOnset(p) + 1/lB.pulseFrequency);
                    if ~isempty(s)
                        lB.latency(p) = s(1) - lB.pulseOnset(p);
                        lB.responseIsi{p} = diff(s);
                    end
                    s = spk(spk > lB.pulseOnset(p) - 1/lB.pulseFrequency & spk <= lB.pulseOnset(p));
                    if ~isempty(s)
                        lB.negLat(p) = lB.pulseOnset(p) - s(end);
                    end
                end
                
                spk(spk <= lB.pulseOnset(end) + lB.pulseDur(end) + postBoutWait) = [];
                if k == length(laser_log{i})
                    lB.postIsi = diff(spk);
                end
                lR.block{i} = [lR.block{i} lB];
            end
        
        end
    
        laserResponse = [laserResponse lR];
    
    end
    
    save([sesDirSort '/laserDat.mat'], 'laserResponse', '-v7.3')
    
end



