datRoot = '/Volumes/Seagate Backup Plus Drive/Recordings/';
rat = 'IM1261';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false);
sorted = cellfun(@(s) exist([datRoot rat filesep s filesep 'unitDat.mat'], 'file') == 2, sesList);
sesList = sesList(sorted);
for i = 1:length(sesList)
    fprintf('%d) %s\n', i, sesList{i})
end

iSes = 1; % choose session
sesDir = [datRoot rat filesep sesList{iSes} filesep]

%% extract laser info, log laser power

% identify log files for laser sessions
laserLogs = dir([sesDir '*laser.log']);
laserLogs = arrayfun(@(x) x.name, laserLogs, 'UniformOutput', false)

logInfo = cellfun(@(l) strsplit(l, '_'), laserLogs, 'UniformOutput', false);
logTime = cellfun(@(l) l{3}, logInfo, 'UniformOutput', false);
logTime = cellfun(@(l) strjoin(strsplit(l, '-'),''), logTime, 'UniformOutput', false);
logTime = cellfun(@(l) 60*str2num(l(1:2))+str2num(l(3:4))+str2num(l(5:6))/60, logTime);

% identify Intan data directories for laser sessions
fileDat = dir([sesDir 'IM*']);
idx = arrayfun(@(f) f.isdir, fileDat);
folder = arrayfun(@(f) f.name, fileDat(idx), 'UniformOutput', false);
folderInfo = cellfun(@(f) strsplit(f, {'-', '_'}), folder, 'UniformOutput', false);
task = cellfun(@(f) f{2}, folderInfo, 'UniformOutput', false);
laserIdx = find(cellfun(@(t) strcmp(lower(t), 'laser'), task));
laserDir = folder(laserIdx)
boxFileTime = cellfun(@(f) f{end}, folderInfo(laserIdx), 'UniformOutput', false);
boxFileTime = cellfun(@(b) 60*str2num(b(1:2))+str2num(b(3:4))+str2num(b(5:6))/60, boxFileTime);

[boxFileTime, iSort] = sort(boxFileTime);
laserIdx = laserIdx(iSort);
laserDir = folder(laserIdx)

if any(abs(logTime - boxFileTime) > 1)
    disp('WARNING: problem matching log files to box files');
end

% extract laser pulse data from log and dat files
laser_log = cell(1, length(laserLogs));
laser_ts = cell(1, length(laserLogs));
for  i = 1:length(laserLogs)
    [laser_log{i} laser_ts{i}] = ExtractBehavior([sesDir laserDir{i}], [sesDir laserLogs{i}], 'laser');
end

% examine "current" field of laser log, record the corresponding laser power
pow = cell(1,length(laser_log));
for i = 1:length(laser_log)
    str = sprintf('\nsession %d, current:', i);
    pow{i} = arrayfun(@(l) l.current, laser_log{i});
    for k = 1:length(laser_log{i})
        str = [str ' ' num2str(pow{i}(k))];
    end
    fprintf('%s\n', str)
end

% log laser power here; it will replace "current" in the laser_log structure
pow{1}(:) = 0.5;
pow{2}(:) = 1;
pow{3}(:) = 2;
pow{4}(:) = 10;
pow{5}(:) = 15;
pow{6}(:) = 2;
pow{7}(:) = 2;
pow{8}(:) = 2;

% replace "current" field with "power" (and remove "voltage")
for i = 1:length(laser_log)
    laser_log{i} = rmfield(laser_log{i}, 'current');
    laser_log{i} = rmfield(laser_log{i}, 'voltage');
    for k = 1:length(laser_log{i})
        laser_log{i}(k).power = pow{i}(k);
    end
end

% load unit data
load([sesDir '/unitDat.mat'])

postBoutWait = 5; % seconds

laserResponse = [];
% loop through units
laserIdx = find(cellfun(@(x) ~isempty(strfind(x, 'laser')), unit(1).taskList));
for u = 1:length(unit)
    
    lR.name = unit(u).name;
    lR.block = cell(1, length(laser_log));
    
    % loop through laser blocks
    for i = 1:length(laser_log)
        
        t1 = unit(u).taskStart(laserIdx(i));
        t2 = unit(u).taskEnd(laserIdx(i));
        spk = unit(u).spkTimes;
        spk = unique(spk(spk > t1 & spk < t2) - t1);
        
        % loop through laser bouts
        for k = 1:length(laser_log{i})
            lB.taskIdx = laserIdx(i);
            lB.taskName = unit(u).taskList{laserIdx(i)};
            lB.laserPower = laser_log{i}(k).power;
            lB.pulseFrequency = laser_log{i}(k).frequency;
            lB.pulseOnset = laser_ts{i}(k).onset;
            lB.pulseDur = 1000*laser_ts{i}(k).duration;    % pulse duration is in ms
            lB.preIsi = diff(spk(spk < lB.pulseOnset(1)));
            lB.postIsi = [];
            nPulses = length(lB.pulseOnset);
            lB.latency = nan(1, nPulses);
            lB.negLat = nan(1, nPulses);
            lB.responseIsi = cell(1, nPulses);
            
            % loop through laser pulses
            for p = 1:nPulses
                s = spk(spk > lB.pulseOnset(p) & spk < lB.pulseOnset(p) + 1/lB.pulseFrequency);
                if ~isempty(s)
                    lB.latency(p) = s(1) - lB.pulseOnset(p);
                    lB.responseIsi{p} = diff(s);
                end
                s = spk(spk > lB.pulseOnset(p) - 1/lB.pulseFrequency & spk <= lB.pulseOnset(p));
                if ~isempty(s)
                    lB.negLat(p) = lB.pulseOnset(p) - s(end);
                end
            end
            
            spk(spk <= lB.pulseOnset(end) + lB.pulseDur(end) + postBoutWait) = [];
            if k == length(laser_log{i})
                lB.postIsi = diff(spk);
            end
            lR.block{i} = [lR.block{i} lB];
        end
        
    end
    
    laserResponse = [laserResponse lR];
    
end

save([sesDir '/laserDat.mat'], 'laserResponse', '-v7.3')
