datRoot = '/Volumes/LaCie/Farries recordings/';
rat = 'IM1025';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false)

iSes = 6;
sesDir = [datRoot rat filesep sesList{iSes} filesep]
load([sesDir 'behavior - RL.mat'])
rwd = TrialFilter(tsRL, 'x1', 'L');

fileDat = dir([sesDir rat '-RL*']);
datDir = [sesDir fileDat(1).name]

% load data segment (ECoG)
tR = [-5 125] + tsRL.firstFoodPoke(rwd(1));
r = tsRL.Side_NI(rwd);
fp = tsRL.firstFoodPoke(rwd);
r = r(r>tR(1) & r < tR(2));
fp = fp(fp>tR(1) & fp < tR(2));
d = PlotIntanData(datDir, 'trode', 'I-t03', 'returnData', true, 'makePlot', true, 'timeRange', tR);
hold on
yR = ylim;
for x = r'
    plot([x x], yR, 'r', 'LineWidth', 2)
end
for x = fp'
    plot([x x], yR, 'g', 'LineWidth', 2)
end

fRange = [0 2000];
fRes = 10;
cRange = [-5 12];
Fs = 30000;
[b freq t] = specgram(d.v(1,:), round(Fs/fRes), Fs);
t = t + d.t(1);
fLoc = freq >= fRange(1) & freq <= fRange(2);
freq = freq(fLoc);
p = log(abs(b(fLoc,:)).^2);
figure
imagesc(t, freq, p, cRange)
set(gca,'Yscale','lin','Ydir','normal')
xlabel(['time (sec)'])
ylabel('frequency (Hz)')
colormap(jet(200))

% design filter 1
filtOrder = 500;
b1 = fir1(filtOrder, 2*pi*[100 800] / Fs);

% filter LFP to specificed frequency band, normalize by median power
c1 = filtfilt(b1, 1, d.v(1,:));
p1 = abs(hilbert(c1)) .^ 2;
p1 = p1 / median(p1);
figure
plot(d.t, p1)
xlim([d.t(1) d.t(end)])
hold on
yR = ylim;
for x = r'
    plot([x x], yR, 'r', 'LineWidth', 2)
end
for x = fp'
    plot([x x], yR, 'g', 'LineWidth', 2)
end

fRange = [0 20];
fRes = 1;
cRange = [15 30];
Fs = 30000;
[b freq t] = specgram(p1, round(Fs/fRes), Fs);
t = t + d.t(1);
fLoc = freq >= fRange(1) & freq <= fRange(2);
freq = freq(fLoc);
p = log(abs(b(fLoc,:)).^2);
figure
imagesc(t, freq, p, cRange)
set(gca,'Yscale','lin','Ydir','normal')
xlabel(['time (sec)'])
ylabel('frequency (Hz)')
colormap(jet(200))

% design filter 2
filtOrder = 500;
b2 = fir1(filtOrder, 2*pi*[3 8] / Fs);

% filter LFP band power to second band
c2 = filtfilt(b2, 1, p1);
p2 = abs(hilbert(c2)) .^ 2;
figure
plot(d.t, p2)
xlim([d.t(1) d.t(end)])
hold on
yR = ylim;
for x = r'
    plot([x x], yR, 'r', 'LineWidth', 2)
end
for x = fp'
    plot([x x], yR, 'g', 'LineWidth', 2)
end

biteThr = 10000;
minBiteInt = 0.01;
maxBiteInt = 0.5;
minBiteDur = 0.01;
maxBiteDur = 0.5;
bite = p2 > biteThr;
biteStart = find(diff(bite) > 0);
biteEnd = find(diff(bite) < 0);
bite = [d.t(biteStart)' d.t(biteEnd)'];
biteDur = bite(:,2) - bite(:,1);

% eliminate long "bites"
delIdx = find(biteDur > maxBiteDur);
bite(delIdx,:) = [];
biteStart(delIdx) = [];
biteEnd(delIdx) = [];
biteDur = bite(:,2) - bite(:,1);
biteInt = bite(2:end,1) - bite(1:end-1,2);

% merge bites separated by short intervals
merge = find(biteInt < minBiteInt);
if ~isempty(merge)
    endLocs = find(diff(merge) > 1); % locations of the ends of short interval sequences
    startLocs = endLocs + 1; % locations of the starts of short interval sequences
    endLocs = [merge(endLocs); merge(end)] + 1;
    startLocs = [merge(1); merge(startLocs)];
else
    startLocs = [];
end
biteEnd(startLocs) = biteEnd(endLocs);
bite(startLocs, 2) = bite(endLocs, 2);
delIdx = [];
for i = 1:length(startLocs)
    delIdx = [delIdx startLocs(i)+1:endLocs(i)];
end
bite(delIdx, :) = [];
biteStart(delIdx) = [];
biteEnd(delIdx) = [];
biteDur = bite(:,2) - bite(:,1);
biteInt = bite(2:end,1) - bite(1:end-1,2);

% eliminate short "bites"
delIdx = find(biteDur < minBiteDur);
bite(delIdx,:) = [];
biteStart(delIdx) = [];
biteEnd(delIdx) = [];
biteDur = bite(:,2) - bite(:,1);
biteInt = bite(2:end,1) - bite(1:end-1,2);

biteAmpl = arrayfun(@(i) mean(p2(biteStart(i):biteEnd(i))), 1:length(biteStart));

% identify chewing bouts
merge = find(biteInt < maxBiteInt);
if ~isempty(merge)
    endLocs = find(diff(merge) > 1); % locations of the ends of chewing bouts
    startLocs = endLocs + 1; % locations of the starts of chewing bouts
    endLocs = [merge(endLocs); merge(end)] + 1;
    startLocs = [merge(1); merge(startLocs)];
else
    startLocs = [];
end
chew = [bite(startLocs,1) bite(endLocs,2)];

for i = 1:size(bite, 1)
    plot(bite(i,:), [biteThr biteThr], 'm', 'LineWidth', 3)
end
for i = 1:size(chew, 1)
    plot(chew(i,:), 2*[biteThr biteThr], 'c', 'LineWidth', 3)
end
ylim([-10 4*biteThr])