scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
datRoot = '/Volumes/LaCie/Farries recordings/';

% choose rat
rat = 'IM1056';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false)

% choose session
iSes = 2;
sesList{iSes}
datDir = [datRoot rat '/' sesList{iSes} '/'];

% load logged sleep info and unit data
load([datDir 'rateDat.mat'])
load([datDir 'unitDat.mat'])
load([datDir 'sleepLog.mat'])

% plot rate data
wakeRate = arrayfun(@(r) r.wakeRate, rateDat);
wakeCv = arrayfun(@(r) r.wakeCv, rateDat);
swsRate = arrayfun(@(r) r.swsRate, rateDat);
swsCv = arrayfun(@(r) r.swsCv, rateDat);
dRate = 100 * (swsRate - wakeRate) ./ wakeRate;
figure('Position', [1640 1638 1740 420])
subplot('Position', [0.08 0.08 0.25 0.9])
scatter(wakeRate, wakeCv, 'filled')
xlabel('wake rate')
ylabel('wake CV')
xlim([0 100])
ylim([0 4])
set(gca, 'XTick', 0:20:100)
set(gca, 'YTick', 1:4)
subplot('Position', [0.41 0.08 0.25 0.9])
scatter(swsRate, swsCv, 'filled')
xlabel('SWS rate')
ylabel('SWS CV')
xlim([0 100])
ylim([0 4])
set(gca, 'XTick', 0:20:100)
set(gca, 'YTick', 1:4)
subplot('Position', [0.74 0.08 0.25 0.9])
hold on
scatter(swsRate, dRate, 'filled')
xlabel('SWS rate')
ylabel('wake-to-SWS rate change')
xlim([0 100])
ylim([-100 100])
plot([0 100], [0 0], 'k')
set(gca, 'XTick', 0:20:100)

% choose ECoG/LFP file
iECoG = 1;
chan = 1;
task = rateDat(1).task;
task = 'sleep';

taskIdx = find(cellfun(@(t) strcmp(t, task), unit(1).taskList))
lfpDir = [datRoot rat '/' sesList{iSes} '/LFP/' task]
ecogFiles = dir([lfpDir '/ECoG*.hsdf']);
lfpFile = ecogFiles(iECoG).name;
lfpFile = [lfpDir '/' lfpFile]
fprintf('\nnumber of available ECoG channels: %d\nselected ECoG file: %s\n\n', length(ecogFiles), lfpFile)

% plot ECoG/LFP specturm during task
hsdfHeader  = getHsdHeader_ver4(lfpFile);
hsdfInfo    = dir(lfpFile);
Fs = hsdfHeader.sampling_rate;
dataOffset = hsdfHeader.dataOffset;
nChan   = hsdfHeader.num_channels;   % total number of wires in the .hsd file
datalength = floor((hsdfInfo.bytes - dataOffset) / (2 * nChan));
recDur = datalength / Fs;
params.tapers = [3 5];
params.fpass = [1 100]; % frequency range
params.pad = 0;
params.err = [2 0.05];
params.trialave = 0;
params.Fs = Fs;
params.specWin = [2, 0.1]; % [FFT window width, dt]
lfpData = LoadSingleChannel(lfpFile, chan, 'timeRange', tRange);
tLfp = (0:length(lfpData) - 1) / Fs + tRange(1);
[S, t, f] = mtspecgramc(lfpData, params.specWin, params);
sDat = reshape(log(S), [1, numel(S)]);
cRange = [quantile(sDat, 0.1) quantile(sDat, 0.99)];
fig = figure('Position', [scrWidth/3 scrHeight/2 500 * 4 420 * 2]);
hold on
imagesc(t, f, log(S'), cRange)
set(gca,'Yscale','lin','Ydir','normal')
xlabel(['time (sec)'])
ylabel('frequency (Hz)')
colormap(jet(200))
xlim([t(1) t(end)])
ylim([f(1) f(end)])



timeRange = [2000 2050];
ShowSpikesLFP(unit(u), lfpFile, timeRange)
ShowSpikesLFP(unit(u), lfpFile, timeRange, 'lfpBand', [8 12])

% timeRange = [2292 2296];
% for u = 1:length(unit)
%     ShowSpikesLFP(unit(u), lfpFile, timeRange, 'var', 0.2)
% end

% filter ECoG
% band = [8 12];
% b = fir1(500, 2*band / Fs);     % design filter
% dat = filtfilt(b, 1, lfpData);     % filter data
% c = hilbert(dat);                  % Hilbert transform
% phi = angle(c);                    % extract phase
% pow = abs(c) .^ 2;                 % extract power

% test detection of high voltage spindles
%timeRange = [1150 1250];
hvsIdx = mean(S(:,19:22),2) ./ mean(S(:,1:2),2);
pkThr = 0.15;
hvsThr = 2;
hvs = DetectSpikes(lfpData, pkThr, 'deadTime', 10, 'spkDetectSignal', 'norm');
hvs = hvs/Fs;
hvs(hvs < t(1) | hvs > t(end)) = [];
hvsLoc = round((hvs - t(1))/params.specWin(2)) + 1;
hvs(hvsIdx(hvsLoc) < hvsThr) = [];
fig = figure('Position', [scrWidth/3 scrHeight/2 500 * 4 420 * 2]);
subplot('Position', [0.03 0.3 0.96 0.68])
imagesc(t, f, log(S'), cRange)
set(gca,'Yscale','lin','Ydir','normal')
set(gca, 'XTick', [])
ylabel('frequency (Hz)')
colormap(jet(200))
xlim([t(1) t(end)])
ylim([f(1) f(end)])
subplot('Position', [0.03 0.02 0.96 0.27])
histogram(hvs, t(1):2:t(end))
xlim([t(1) t(end)])
xlabel(['time (sec)'])
set(gca, 'YTick', [])

timeRange = [2000 2020];
fig = figure('Position', [scrWidth/3 scrHeight/2 500 * 4 420 * 2]);
subplot('Position', [0.03 0.3 0.96 0.68])
imagesc(t, f, log(S'), cRange)
set(gca,'Yscale','lin','Ydir','normal')
set(gca, 'XTick', [])
ylabel('frequency (Hz)')
colormap(jet(200))
xlim(timeRange)
ylim([f(1) f(end)])
subplot('Position', [0.03 0.02 0.96 0.27])
plot(tLfp, lfpData, 'k')
hold on
scatter(hvs, lfpData(round(hvs*Fs)), 'r', 'filled')
xlim(timeRange)
xlabel(['time (sec)'])
ylim([-0.75 0.75])
set(gca, 'YTick', [-0.5 0 0.5])


% spikes fired relative to HVS
% check unit activity during wake/sleep
binEdges = -51:2:51;
binCenters = binEdges(2:end) - diff(binEdges)/2;
pathParts = strsplit(lfpFile, {filesep});
task = pathParts{end-1};
taskIdx = find(cellfun(@(t) strcmp(t, task), unit(1).taskList));
t0 = unit(1).taskStart(taskIdx);
for u = 1:length(unit)
    spk = unit(u).spkTimes - t0;
    spk = spk(spk > t(1) + binEdges(1) & spk < t(end) + binEdges(end));
    psth = zeros(size(binCenters));
    for k = 1:length(hvs)
        psth = psth + histcounts(spk - hvs(k), binEdges/1000);
    end
    psth = 10*psth/sum(psth);
    titleStr = sprintf('%d) wake: %3.1f Hz, %3.1f CV    SWS: %3.1f Hz, %3.1f CV', u, wakeRate(u), wakeCv(u),swsRate(u), swsCv(u));  
    figure('Name', titleStr, 'NumberTitle', 'off')
    plot(binCenters, psth, 'LineWidth', 2)
    ylim([0 1.1*max(psth)])
end