scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
datRoot = '/Volumes/LaCie/Farries recordings/';

% choose rat
rat = 'IM1130';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false)

% choose session
iSes = 3;
sesList{iSes}
datDir = [datRoot rat '/' sesList{iSes} '/'];

% load logged sleep info and unit data
load([datDir 'rateDat.mat'])
load([datDir 'unitDat.mat'])
load([datDir 'sleepLog.mat'])

% plot rate data
wakeRate = arrayfun(@(r) r.wakeRate, rateDat);
wakeCv = arrayfun(@(r) r.wakeCv, rateDat);
swsRate = arrayfun(@(r) r.swsRate, rateDat);
swsCv = arrayfun(@(r) r.swsCv, rateDat);
dRate = 100 * (swsRate - wakeRate) ./ wakeRate;
figure('Position', [1640 1638 1740 420])
subplot('Position', [0.08 0.08 0.25 0.9])
scatter(wakeRate, wakeCv, 'filled')
xlabel('wake rate')
ylabel('wake CV')
xlim([0 100])
ylim([0 4])
set(gca, 'XTick', 0:20:100)
set(gca, 'YTick', 1:4)
subplot('Position', [0.41 0.08 0.25 0.9])
scatter(swsRate, swsCv, 'filled')
xlabel('SWS rate')
ylabel('SWS CV')
xlim([0 100])
ylim([0 4])
set(gca, 'XTick', 0:20:100)
set(gca, 'YTick', 1:4)
subplot('Position', [0.74 0.08 0.25 0.9])
hold on
scatter(swsRate, dRate, 'filled')
xlabel('SWS rate')
ylabel('wake-to-SWS rate change')
xlim([0 100])
ylim([-100 100])
plot([0 100], [0 0], 'k')
set(gca, 'XTick', 0:20:100)

% choose ECoG/LFP file
iECoG = 1;
task = rateDat(1).task;
taskIdx = find(cellfun(@(t) strcmp(t, task), unit(1).taskList))
lfpDir = [datRoot rat '/' sesList{iSes} '/LFP/' task]
ecogFiles = dir([lfpDir '/ECoG*.hsdf']);
lfpFile = ecogFiles(iECoG).name;
lfpFile = [lfpDir '/' lfpFile]
fprintf('\nnumber of available ECoG channels: %d\nselected ECoG file: %s\n\n', length(ecogFiles), lfpFile)

% plot ECoG/LFP specturm during task
fRange = [0 100];
fRes = 0.2;
cRange = [0.2 8];
hsdfHeader  = getHsdHeader_ver4(lfpFile);
hsdfInfo    = dir(lfpFile);
Fs = hsdfHeader.sampling_rate;
dataOffset = hsdfHeader.dataOffset;
nChan   = hsdfHeader.num_channels;   % total number of wires in the .hsd file
[sws spindle unplug] = SleepLog(lfpFile, chan, []);
datalength = floor((hsdfInfo.bytes - dataOffset) / (2 * nChan));
recDur = datalength / Fs;
tRange = [0 recDur];
startSample = ceil(tRange(1) * Fs);
numSamples = floor(range(tRange) * Fs);
eegData = LoadSingleChannel(lfpFile, chan, 'timeRange', tRange);
[b freq t] = specgram(eegData, round(Fs/fRes), Fs);
t = t + tRange(1);
fLoc = freq >= fRange(1) & freq <= fRange(2);
freq = freq(fLoc);
p = log(abs(b(fLoc,:)).^2);
fig = figure('Position', [scrWidth/3 scrHeight/2 500 * 4 420 * 2]);
hold on
imagesc(t, freq, p, cRange)
set(gca,'Yscale','lin','Ydir','normal')
xlabel(['time (sec)'])
ylabel('frequency (Hz)')
xlim(tRange)
ylim(fRange)
colormap(jet(200))
plot([rateDat(1).swsTaskTime(1) rateDat(1).swsTaskTime(1)], [fRange(1)+0.25 fRange(2)-0.25], 'w', 'LineWidth', 2)
plot([rateDat(1).swsTaskTime(1) rateDat(1).swsTaskTime(2)], [fRange(1)+0.25 fRange(1)+0.25], 'w', 'LineWidth', 2)
plot([rateDat(1).swsTaskTime(1) rateDat(1).swsTaskTime(2)], [fRange(2)-0.25 fRange(2)-0.25], 'w', 'LineWidth', 2)
plot([rateDat(1).swsTaskTime(2) rateDat(1).swsTaskTime(2)], [fRange(1)+0.25 fRange(2)-0.25], 'w', 'LineWidth', 2)
plot([rateDat(1).wakeTaskTime(1) rateDat(1).wakeTaskTime(1)], [fRange(1)+0.25 fRange(2)-0.25], 'g', 'LineWidth', 2)
plot([rateDat(1).wakeTaskTime(1) rateDat(1).wakeTaskTime(2)], [fRange(1)+0.25 fRange(1)+0.25], 'g', 'LineWidth', 2)
plot([rateDat(1).wakeTaskTime(1) rateDat(1).wakeTaskTime(2)], [fRange(2)-0.25 fRange(2)-0.25], 'g', 'LineWidth', 2)
plot([rateDat(1).wakeTaskTime(2) rateDat(1).wakeTaskTime(2)], [fRange(1)+0.25 fRange(2)-0.25], 'g', 'LineWidth', 2)

% check unit activity during wake/sleep
u = 25;
fprintf('wake rate: %3.1f spikes/sec, wake CV: %3.1f\n',wakeRate(u), wakeCv(u))
fprintf('sleep rate: %3.1f spikes/sec, sleep CV: %3.1f\n',swsRate(u), swsCv(u))

timeRange = [130 140];
ShowSpikesLFP(unit(u), lfpFile, timeRange, 'var', 0.2)

timeRange = [260 270];
ShowSpikesLFP(unit(u), lfpFile, timeRange, 'var', 0.2)

