scrsz = get(0,'ScreenSize');
scrWidth = scrsz(3);
scrHeight = scrsz(4);
datRoot = '/Volumes/LaCie/Farries recordings/';

% choose rat
rat = 'IM1153';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false);
for i = 1:length(sesList)
    fprintf('%d) %s\n', i, sesList{i})
end

% choose session
iSes = 5;
sesList{iSes}
datDir = [datRoot rat '/' sesList{iSes} '/'];

% load sleep log and unit data
clear sleepLog
clear unit
load([datDir 'sleepLog.mat'])
load([datDir 'unitDat.mat'])

% summarize sleep log data
for i = 1:length(sleepLog)
    if isempty(sleepLog(i).sws)
        swsDur = 0;
    else
        swsDur = round(diff(sleepLog(i).sws));
    end
    if isempty(sleepLog(i).wake)
        wakeDur = 0;
    else
        wakeDur = round(diff(sleepLog(i).wake));
    end
    fprintf('%d) %s SWS: %d sec, wake %d sec\n', i, sleepLog(i).task, swsDur, wakeDur);
end

% choose task for sleep analysis
task = 4;

taskIdx = find(cellfun(@(t) strcmp(lower(t), lower(sleepLog(task).task)), unit(1).taskList));

taskStart = unit(1).taskStart(taskIdx);
swsTime = sleepLog(task).sws + taskStart;
wakeTime = sleepLog(task).wake + taskStart;

clear rateDat
for u = 1:length(unit)
    rateDat(u).name = unit(u).name;
    rateDat(u).task = sleepLog(task).task;
    rateDat(u).wakeTaskTime = sleepLog(task).wake;
    rateDat(u).swsTaskTime = sleepLog(task).sws;
    rateDat(u).wakeTime = wakeTime;
    rateDat(u).swsTime = swsTime;
    wakeSpk = unit(u).spkTimes(unit(u).spkTimes > wakeTime(1) & unit(u).spkTimes < wakeTime(2));
    swsSpk = unit(u).spkTimes(unit(u).spkTimes > swsTime(1) & unit(u).spkTimes < swsTime(2));
    isi = diff(wakeSpk);
    rateDat(u).wakeRate = 1 / mean(isi);
    rateDat(u).wakeCv = std(isi) / mean(isi);
    isi = diff(swsSpk);
    rateDat(u).swsRate = 1 / mean(isi);
    rateDat(u).swsCv = std(isi) / mean(isi);
end

swsRate = arrayfun(@(r) r.swsRate, rateDat);
wakeRate = arrayfun(@(r) r.wakeRate, rateDat);
swsCv = arrayfun(@(r) r.swsCv, rateDat);
wakeCv = arrayfun(@(r) r.wakeCv, rateDat);
dRate = 100*(swsRate - wakeRate) ./ wakeRate;

% goodCells = intersect(find(~isnan(dRate)), find(~isnan(swsCv)));
% dRate = dRate(goodCells);
% wakeRate = wakeRate(goodCells);
% wakeCv = wakeCv(goodCells);
% swsRate = swsRate(goodCells);
% swsCv = swsCv(goodCells);

% classification plot
vertSpace = 35;
horizSpace = 50;
plotWidth = 325;
plotHeight = 325;
nRows = 2;
nCols = 2;
panelHeight = vertSpace + nRows * (vertSpace + plotHeight);
panelWidth = horizSpace + nCols * (horizSpace + plotWidth);
spV = vertSpace/panelHeight;
spH = horizSpace/panelWidth;
wd = plotWidth/panelWidth;
ht = plotHeight/panelHeight;

titleStr = [rat ', ' sesList{iSes} ', ' sleepLog(task).task];
fig = figure('Position', [100 500 panelWidth panelHeight], 'Name', titleStr, 'NumberTitle', 'off'); %[left bottom width height];

col=1;
row=1;
subplot('Position', [spH+(col-1)*(wd+spH) spV+(nRows-row)*(ht+spV)  wd ht]) %[left bottom width height]
hold on
scatter(wakeRate, wakeCv, 'k', 'filled')
yMax = ceil(max(wakeCv));
xMax = 10*ceil(max(wakeRate)/10);
ylim([0 yMax])
xlim([0 xMax])
set(gca, 'YTick', 1:yMax)
xlabel('firing rate (wake)')
ylabel('CV (wake)')

col=2;
row=1;
subplot('Position', [spH+(col-1)*(wd+spH) spV+(nRows-row)*(ht+spV)  wd ht]) %[left bottom width height]
hold on
scatter(swsRate, swsCv, 'k', 'filled')
yMax = ceil(max(swsCv));
xMax = 10*ceil(max(swsRate)/10);
ylim([0 yMax])
xlim([0 xMax])
set(gca, 'YTick', 1:yMax)
xlabel('firing rate (SWS)')
ylabel('CV (SWS)')

col=1;
row=2;
subplot('Position', [spH+(col-1)*(wd+spH) spV+(nRows-row)*(ht+spV)  wd ht]) %[left bottom width height]
hold on
scatter(wakeRate, dRate, 'k', 'filled')
xMax = 10*ceil(max(wakeRate)/10);
yMin = 10*floor(min(dRate)/10);
yMax = 10*ceil(max(dRate)/10);
plot([0 xMax], [0 0], 'color', 'k')
xlim([0 xMax])
ylim([yMin yMax])
ylabel('% change in rate from wake to SWS')
xlabel('firing rate (wake)')

col=2;
row=2;
subplot('Position', [spH+(col-1)*(wd+spH) spV+(nRows-row)*(ht+spV)  wd ht]) %[left bottom width height]
hold on
scatter(swsRate, dRate, 'k', 'filled')
xMax = 10*ceil(max(swsRate)/10);
yMin = 10*floor(min(dRate)/10);
yMax = 10*ceil(max(dRate)/10);
plot([0 xMax], [0 0], 'color', 'k')
xlim([0 xMax])
ylim([yMin yMax])
ylabel('% change in rate from wake to SWS')
xlabel('firing rate (SWS)')



save([datDir 'rateDat'], 'rateDat')
close all